"""

        Client Library for Rainbow Robotics' Cobot RB-Series
        ----------------------------------------------------

        .. currentmodule:: rbpodo

        .. autosummary::
           :toctree: _generate

           Cobot
           CobotData
    
"""
from __future__ import annotations
import collections.abc
import numpy
import numpy.typing
import typing
from . import asyncio
__all__ = ['BlendingOption', 'Cobot', 'CobotData', 'CollisionFollowUpMode', 'CollisionMode', 'ControlBoxInfo', 'DigitalIOMode', 'Endian', 'ErrorCodeMessage', 'GripperConnectionPoint', 'GripperModel', 'ICE_INFO_AMBI_HIGH', 'ICE_INFO_AMBI_LOW', 'ICE_INFO_CONNECTED', 'ICE_INFO_MODE_COMM', 'ICE_INFO_MODE_CUP', 'ICE_INFO_REQUESTING', 'ICE_INFO_TIME_ICE', 'ICE_INFO_TIME_WATER', 'ICE_INFO_TMEP_AMBI', 'ICE_INFO_TMEP_CONDEN', 'ICE_INFO_TMEP_EVAPO', 'ICE_INFO_USING', 'ICE_INFO_VECSIZE', 'ICE_STATE_COMM_MODE', 'ICE_STATE_COMP_WORK', 'ICE_STATE_CUP_LEVEL', 'ICE_STATE_ERR_1', 'ICE_STATE_ERR_2', 'ICE_STATE_ERR_3', 'ICE_STATE_ERR_4', 'ICE_STATE_ERR_CODE', 'ICE_STATE_FULL_ICE', 'ICE_STATE_LAST_ICE_NO', 'ICE_STATE_LAST_ICE_YES', 'ICE_STATE_MOTOR_WORK', 'ICE_STATE_OUT_SOL', 'ICE_STATE_RD', 'JRT_ENCODER', 'JRT_JEGB', 'JRT_JEGG', 'Message', 'MoveCOrientationOption', 'MoveCRotationOption', 'MoveITPLOption', 'MoveLBOption', 'MoveLCOption', 'MoveLCProperty', 'MovePBOption', 'MoveServoTOption', 'OR_2FG7_MAX_EXT', 'OR_2FG7_MAX_INT', 'OR_2FG7_MIN_EXT', 'OR_2FG7_MIN_INT', 'OR_2FG7_POS_EXT', 'OR_2FG7_POS_INT', 'OR_2FG7_STATE', 'OR_3FG_BUSY', 'OR_3FG_CALIB', 'OR_3FG_FORCE', 'OR_3FG_FORCE_GRIP', 'OR_3FG_GRIP', 'OR_3FG_MAX_D', 'OR_3FG_MIN_D', 'OR_3FG_RAW_D', 'OR_3FG_REAL_D', 'OR_EYE_COUNT', 'OR_EYE_ERROR', 'OR_EYE_INSPECT_MATCH', 'OR_EYE_INSPECT_RESULT', 'OR_EYE_POS', 'OR_EYE_RX', 'OR_EYE_RY', 'OR_EYE_RZ', 'OR_EYE_X', 'OR_EYE_Y', 'OR_EYE_Z', 'OR_MG10_ERROR', 'OR_MG10_STATUS', 'OR_MG10_STRENGTH', 'OR_RG_BUSY', 'OR_RG_ERROR', 'OR_RG_GRIP', 'OR_RG_S1_PUSHED', 'OR_RG_S1_TRIGGERED', 'OR_RG_S2_PUSHED', 'OR_RG_S2_TRIGGERED', 'OR_RG_WIDTH', 'OR_SD_BUTTON', 'OR_SD_ERROR', 'OR_SD_MOTOR_RUNNING', 'OR_SD_MOTOR_STOPPED', 'OR_SD_RAMP_DW', 'OR_SD_RAMP_UP', 'OR_SD_RPM', 'OR_SD_RPM_DEV', 'OR_SD_RPM_TAR', 'OR_SD_STATUS', 'OR_SD_VIBRATION', 'OR_SD_WARNING', 'OR_SG_MAX_WIDTH', 'OR_SG_MIN_WIDTH', 'OR_SG_STATUS', 'OR_SG_WIDTH', 'OR_VGP20_A', 'OR_VGP20_A_GRIP', 'OR_VGP20_A_RELEASE', 'OR_VGP20_B', 'OR_VGP20_BUSY', 'OR_VGP20_B_GRIP', 'OR_VGP20_B_RELEASE', 'OR_VGP20_C', 'OR_VGP20_C_GRIP', 'OR_VGP20_C_RELEASE', 'OR_VGP20_D', 'OR_VGP20_D_GRIP', 'OR_VGP20_D_RELEASE', 'OR_VGP20_ERROR', 'OR_VG_A', 'OR_VG_B', 'OperationMode', 'PICKIT_BUILD_BKG_CLOUD_FAILED', 'PICKIT_BUILD_BKG_CLOUD_OK', 'PICKIT_CONFIG_FAILED', 'PICKIT_CONFIG_OK', 'PICKIT_EMPTY_ROI', 'PICKIT_FIND_CALIB_PLATE_FAILED', 'PICKIT_FIND_CALIB_PLATE_OK', 'PICKIT_GET_PICK_POINT_DATA_FAILED', 'PICKIT_GET_PICK_POINT_DATA_OK', 'PICKIT_IDLE_MODE', 'PICKIT_IMAGE_CAPTURED', 'PICKIT_M0', 'PICKIT_M1', 'PICKIT_NO_IMAGE_CAPTURED', 'PICKIT_NO_OBJECTS', 'PICKIT_OBJECT_FOUND', 'PICKIT_P0', 'PICKIT_P0F', 'PICKIT_P1', 'PICKIT_P1F', 'PICKIT_P2', 'PICKIT_P2F', 'PICKIT_P3', 'PICKIT_P3F', 'PICKIT_P4', 'PICKIT_P4F', 'PICKIT_P5', 'PICKIT_P5F', 'PICKIT_POS', 'PICKIT_ROBOTTYPE', 'PICKIT_ROBOT_MODE', 'PICKIT_RX', 'PICKIT_RY', 'PICKIT_RZ', 'PICKIT_SAVE_SNAPSHOT_FAILED', 'PICKIT_SAVE_SNAPSHOT_OK', 'PICKIT_STATUS', 'PICKIT_TYPE_BLOB', 'PICKIT_TYPE_CIRCLE', 'PICKIT_TYPE_CYLINDER', 'PICKIT_TYPE_ELLIPSE', 'PICKIT_TYPE_POINTCLOUD', 'PICKIT_TYPE_RECTANGLE', 'PICKIT_TYPE_SPHERE', 'PICKIT_TYPE_SQUARE', 'PICKIT_UNKNOWN_COMMAND', 'PICKIT_VERSION', 'PICKIT_X', 'PICKIT_Y', 'PICKIT_Z', 'RC_PICKIT_CAPTURE_IMAGE', 'RC_PICKIT_CHECK_MODE', 'RC_PICKIT_CONFIGURE', 'RC_PICKIT_FIND_CALIB_PLATE', 'RC_PICKIT_GET_PICK_POINT_DATA', 'RC_PICKIT_LOOK_FOR_OBJECTS', 'RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES', 'RC_PICKIT_NEXT_OBJECT', 'RC_PICKIT_NO_COMMAND', 'RC_PICKIT_PROCESS_IMAGE', 'RC_PICKIT_SAVE_SCENE', 'RC_PICKIT_SET_CYLINDER_DIM', 'RC_SAVE_ACTIVE_PRODUCT', 'RC_SAVE_ACTIVE_SETUP', 'RC_SAVE_BUILD_BACKGROUND', 'ReferenceFrame', 'Response', 'ResponseCollector', 'ReturnType', 'RobotState', 'SD_ARM_POWER', 'SD_BEGIN_J0', 'SD_BEGIN_J1', 'SD_BEGIN_J2', 'SD_BEGIN_J3', 'SD_BEGIN_J4', 'SD_BEGIN_J5', 'SD_BIT_0_11', 'SD_BIT_0_15', 'SD_BIT_0_3', 'SD_BIT_0_7', 'SD_BIT_12_15', 'SD_BIT_4_7', 'SD_BIT_8_11', 'SD_COLLISION_DETECT_STATE', 'SD_CONV_POS_TICK', 'SD_CONV_VEL_TICK', 'SD_CURRENT_DELTA', 'SD_DEFAULT_SPEED', 'SD_DIGITAL_IN_CONFIG_0', 'SD_DIGITAL_IN_CONFIG_1', 'SD_DWELD_A', 'SD_DWELD_ARC', 'SD_DWELD_F', 'SD_DWELD_SET_A', 'SD_DWELD_TOUCH', 'SD_DWELD_V', 'SD_EMG_BUTTON_STATE', 'SD_FINISH_AT_EVENT', 'SD_FORCE_TRAVEL_DIS', 'SD_HAND_TOKTOK', 'SD_ID_NUMBER', 'SD_INBOX_CHECK_MODE_0', 'SD_INBOX_CHECK_MODE_1', 'SD_INBOX_TRAP_FLAG_0', 'SD_INBOX_TRAP_FLAG_1', 'SD_INIT_ERR', 'SD_INIT_STATE_INFO', 'SD_IS_BEGIN', 'SD_IS_FREE_DRIVE_MODE', 'SD_IS_HOME', 'SD_IS_INTENDED_STOP', 'SD_IS_IN_MAIN', 'SD_IS_RUN_IN_MAKE', 'SD_IS_RUN_IN_PLAY', 'SD_IS_TPU_CONNECT', 'SD_J0_ANG', 'SD_J0_CUR', 'SD_J0_REF', 'SD_J0_VEL', 'SD_J1_ANG', 'SD_J1_CUR', 'SD_J1_REF', 'SD_J1_VEL', 'SD_J2_ANG', 'SD_J2_CUR', 'SD_J2_REF', 'SD_J2_VEL', 'SD_J3_ANG', 'SD_J3_CUR', 'SD_J3_REF', 'SD_J3_VEL', 'SD_J4_ANG', 'SD_J4_CUR', 'SD_J4_REF', 'SD_J4_VEL', 'SD_J5_ANG', 'SD_J5_CUR', 'SD_J5_REF', 'SD_J5_VEL', 'SD_MOTION_TIME', 'SD_MOVE_INDEX', 'SD_MOVE_INDEX_F', 'SD_MOVE_PROPERTY', 'SD_NO_ARC_STATE', 'SD_OP_STAT_COLLISION_OCCUR', 'SD_OP_STAT_EMS_FLAG', 'SD_OP_STAT_ESTOP_OCCUR', 'SD_OP_STAT_SELF_COLLISION', 'SD_OP_STAT_SOS_FLAG', 'SD_PG_MODE', 'SD_POWER_STATE', 'SD_ROBOT_STATE', 'SD_SOCK_IS_OPEN_0', 'SD_SOCK_IS_OPEN_1', 'SD_SOCK_IS_OPEN_2', 'SD_SOCK_IS_OPEN_3', 'SD_SOCK_IS_OPEN_4', 'SD_SOCK_LAST_READ_0', 'SD_SOCK_LAST_READ_1', 'SD_SOCK_LAST_READ_2', 'SD_SOCK_LAST_READ_3', 'SD_SOCK_LAST_READ_4', 'SD_TCP_RX', 'SD_TCP_RY', 'SD_TCP_RZ', 'SD_TCP_VEL_REF', 'SD_TCP_X', 'SD_TCP_Y', 'SD_TCP_Z', 'SD_TEMPERATURE_MC0', 'SD_TEMPERATURE_MC1', 'SD_TEMPERATURE_MC2', 'SD_TEMPERATURE_MC3', 'SD_TEMPERATURE_MC4', 'SD_TEMPERATURE_MC5', 'SD_TFB_ANALOG_IN_0', 'SD_TFB_ANALOG_IN_1', 'SD_TFB_DIGITAL_IN_0', 'SD_TFB_DIGITAL_IN_1', 'SD_TFB_DIGITAL_OUT_0', 'SD_TFB_DIGITAL_OUT_1', 'SD_TFB_VOLTAGE_OUT', 'SD_TF_LRF_DISTANCE', 'SD_TF_LRF_QUALITY', 'SD_TIME', 'SD_TIMER_0', 'SD_TIMER_1', 'SD_TIMER_2', 'SD_TIMER_3', 'SD_TIMER_4', 'SD_TIMER_5', 'SD_TIMER_6', 'SD_TIMER_7', 'SD_TIMER_8', 'SD_TIMER_9', 'SETECH_ALM', 'SETECH_BUSY', 'SETECH_COMP', 'SETECH_NG_ANGH', 'SETECH_NG_ANGL', 'SETECH_NG_CH1', 'SETECH_NG_CH16', 'SETECH_NG_CH2', 'SETECH_NG_CH4', 'SETECH_NG_CH8', 'SETECH_NG_MONI', 'SETECH_NG_TIME', 'SETECH_NG_TRQH', 'SETECH_NG_TRQL', 'SETECH_OK', 'SETECH_RDY', 'SystemState', 'SystemVariable', 'asyncio', 'to_string']
class BlendingOption:
    """
    Members:
    
      Ratio : Blend based on Ratio
    
      Distance : Blend based on Distance
    """
    Distance: typing.ClassVar[BlendingOption]  # value = <BlendingOption.Distance: 1>
    Ratio: typing.ClassVar[BlendingOption]  # value = <BlendingOption.Ratio: 0>
    __members__: typing.ClassVar[dict[str, BlendingOption]]  # value = {'Ratio': <BlendingOption.Ratio: 0>, 'Distance': <BlendingOption.Distance: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class Cobot:
    def __init__(self, address: str, port: typing.SupportsInt = 5000) -> None:
        """
        Class is for interacting with Rainbow Robotics Cobot.
        
        Parameters
        ----------
        address : str
            IP address for command channel (e.g. 10.0.2.7). You can set up via teaching pendant (UI)
        port : int
            a port number for command channel (default: 5000).
        
        Example
        -------
        >>> robot = rb.cobot("10.0.2.7")
        >>> rc = rb.ResponseCollector()
        >>> robot.set_operation_mode(rc, rb.OperationMode.Real)
        """
    def activate(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        """
        Turn on the power supply for the robot arm. If the robot is already activated or has some errors, it returns immediately.
        
        Warning
        -------
        The robot arm will power up. Be careful when you use this function.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    @typing.overload
    def calc_fk_tcp(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.ArrayLike, numpy.float64], j0: typing.SupportsFloat, j1: typing.SupportsFloat, j2: typing.SupportsFloat, j3: typing.SupportsFloat, j4: typing.SupportsFloat, j5: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Calculate TCP posture w.r.t. global (base) coordinate from six joint angles.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            TCP pose [x, y, z, rx, ry, rz] w.r.t. global (base) coordinate
        j0, j1, j2, j3, j4, j5: joint angles (unit: degree)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> pnt = np.zeros((6,))
        >>> res = robot.calc_fk_tcp(rc, pnt, 0, 0, 0, 0, 0, 0)
        """
    @typing.overload
    def calc_fk_tcp(self, response_collector: ResponseCollector, j0: typing.SupportsFloat, j1: typing.SupportsFloat, j2: typing.SupportsFloat, j3: typing.SupportsFloat, j4: typing.SupportsFloat, j5: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> tuple[ReturnType, typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"]]:
        """
        Calculate TCP posture w.r.t. global (base) coordinate from six joint angles.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        j0, j1, j2, j3, j4, j5: joint angles (unit: degree)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        numpy.ndarray(shape=(6, 1))
            TCP pose [x, y, z, rx, ry, rz] w.r.t. global (base) coordinate
        
        
        Examples
        --------
        >>> [res, pnt] = robot.calc_fk_tcp(rc, 0, 0, 0, 0, 0, 0, -1, False)
        """
    @typing.overload
    def calc_fk_tcp(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.ArrayLike, numpy.float64], joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Calculate TCP posture w.r.t. global (base) coordinate from six joint angles.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        [out] point : numpy.ndarray(shape=(6, 1))
            TCP pose [x, y, z, rx, ry, rz] w.r.t. global (base) coordinate
        joint : numpy.ndarray(shape=(6, 1))
            Single joint type variable which contains six joint-angles.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> pnt = np.zeros((6,))
        >>> res = robot.calc_fk_tcp(rc, pnt, np.zeros((6,)))
        """
    @typing.overload
    def calc_fk_tcp(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> tuple[ReturnType, typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"]]:
        """
        Calculate TCP posture w.r.t. global (base) coordinate from six joint angles.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        joint : numpy.ndarray(shape=(6, 1))
            Single joint type variable which contains six joint-angles.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        point : numpy.ndarray(shape=(6, 1))
            TCP pose [x, y, z, rx, ry, rz] w.r.t. global (base) coordinate
        
        Examples
        --------
        >>> [res, pnt] = robot.calc_fk_tcp(rc, np.zeros((6,)))
        """
    def disable_waiting_ack(self, response_collector: ResponseCollector) -> bool:
        ...
    def enable_waiting_ack(self, response_collector: ResponseCollector) -> bool:
        ...
    def eval(self, response_collector: ResponseCollector, script: str, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        A function that evaluates a script on the 'Cobot'.
        
        This function sends the given script to the 'Cobot' for evaluation and waits for the response from the 'Cobot'. In the case of failure, the function returns 'Timeout' or 'Error'.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        script : str
            The script to be evaluated.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def flush(self, response_collector: ResponseCollector) -> None:
        ...
    def get_control_box_info(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> tuple[ReturnType, ControlBoxInfo]:
        """
        Retrieves information about the control box.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        ControlBoxInfo
            Information including "system version" and "robot box type"
        
        Examples
        --------
        >>> res, info = robot.get_control_box_info(rc)
        >>> print(info)
        { "SystemVersion": 24021504, "RobotBoxType": 11 }
        """
    def get_robot_state(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> tuple[ReturnType, RobotState]:
        ...
    def get_system_variable(self, response_collector: ResponseCollector, system_variable: SystemVariable, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> tuple[ReturnType, float]:
        ...
    def get_tcp_info(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> tuple[ReturnType, typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"]]:
        """
        This function returns the TCP information of the current robot.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        numpy.ndarray(shape=(6, 1))
            TCP of the current robot with respect to the global coordinate system. (Unit: mm & degree)
        
        
        Examples
        --------
        >>> [res, pnt] = robot.get_tcp_info(rc)
        """
    def get_tfc_info(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> tuple[ReturnType, typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"]]:
        """
        This function returns the TFC (Tool flange center) information of the current robot.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        numpy.ndarray(shape=(6, 1))
            TFC of the current robot based on the global coordinate system. (Unit: mm & degree)
        
        
        Examples
        --------
        >>> [res, pnt] = robot.get_tfc_info(rc)
        """
    def gripper_koras_tooling_core_initialization(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, target_torque: typing.SupportsInt, target_speed: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_koras_tooling_finger_goto(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, target_position: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_koras_tooling_finger_initialization(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_koras_tooling_finger_open_close(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, finger_open_close: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_koras_tooling_vaccum_control(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, vaccum_on_off: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_rts_rhp12rn_force_control(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, target_force_ratio: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_rts_rhp12rn_position_control(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, target_position_ratio: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_rts_rhp12rn_select_mode(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, force: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def gripper_rts_rhp12rn_set_force_limit(self, response_collector: ResponseCollector, conn_point: GripperConnectionPoint, limit: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def move_c_axis(self, response_collector: ResponseCollector, center: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], x_axis: typing.SupportsFloat, y_axis: typing.SupportsFloat, z_axis: typing.SupportsFloat, angle: typing.SupportsFloat, speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, option: MoveCRotationOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function performs a movement that draws an arc through via & target points.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        center : numpy.ndarray(shape=(6, 1))
            Center of the rotation (Unit: mm)
        x_axis : float
            Rotation axis's x axis vector
        y_axis : float
            Rotation axis's y axis vector
        z_axis : float
            Rotation axis's z axis vector
        angle : float
            Rotation angle (Unit: deg)
        speed : float
            Speed (Unit: mm/s)
        acceleration : float
            Acceleration (Unit: mm/s^2)
        option : MoveCRotationOption
            Rotation options. (0 : Intended, 1 : Constant, 2 : Radial)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.move_c_axis(rc, {200, 200, 200, 0, 0, 0}, 1, 0, 0, 180, 50, 10, 2)
        >>> # Rotate 180 degrees around the x-axis. Center of rotation is '{200, 200, 200, 0, 0, 0}'. Based on the center point of the rotation, the orientation of the TCP is changed together.
        """
    def move_c_points(self, response_collector: ResponseCollector, via_point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], target_point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, option: MoveCOrientationOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function performs a movement that draws an arc through via & target points.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        via_point : numpy.ndarray(shape=(6, 1))
            via Point TCP posture.
        target_point: numpy.ndarray(shape=(6, 1))
            target Point TCP posture.
        speed : float
            Speed (Unit: mm/s)
        acceleration : float
            Acceleration (Unit: mm/s^2)
        option : MoveCOrientationOption
            Orientation options. (0 : Intended, 1 : Constant, 2 : Radial, 3 : Smooth)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_itpl_add(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function adds the points used in MoveITPL to the list.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP posture. (Point)
        speed : float
            Speed (Unit: mm/s)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_itpl_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        Initialize (Clear) the point list to be used in MoveITPL.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_itpl_run(self, response_collector: ResponseCollector, acceleration: typing.SupportsFloat, option: MoveITPLOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function executes MoveITPL using the points added in move_itpl_add.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        acceleration : float
            Acceleration
        option : MoveITPLOption
            Orientation/motion option. (CA : Combined Arc mode)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_j(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_err: bool = False) -> ReturnType:
        """
        Move the robot arm to the target joint angle in joint space.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        joint : numpy.ndarray(shape=(6, 1))
            Target joint angles. (Joint)
        speed : float
            Speed (Unit: deg/s)
        acceleration : float
            Acceleration (Unit: deg/s^2)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.move_j(rc, {0, 0, 90, 0, 90, 0}, 60, 80) // move joint angles to (0,0,90,0,90,0) degree with speed/acceleration = 60/80.
        """
    def move_jb2_add(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, blending_value: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_err: bool = False) -> ReturnType:
        ...
    def move_jb2_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1, return_on_err: bool = False) -> ReturnType:
        ...
    def move_jb2_run(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1, return_on_err: bool = False) -> ReturnType:
        ...
    def move_jb_add(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function adds the joint-angles used in MoveJB to the list.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        joint : numpy.ndarray(shape=(6, 1))
            Target joint angles (Unit: deg)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_jb_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        Initialize (Clear) the point list to be used in MoveJB.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_jb_run(self, response_collector: ResponseCollector, speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function executes MoveJB using the points added in move_jb_add.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        speed : float
            Speed (Unit: deg/s)
        acceleration : float
            Acceleration (Unit: deg/s^2)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_jl(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_err: bool = False) -> ReturnType:
        """
        This function moves to the target point using the move_j method rather than a straight line.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP posture. (Point)
        speed : float
            Speed (Unit: deg/s)
        acceleration : float
            Acceleration (Unit: deg/s^2)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.move_jl(rc, {100, 200, 300, 0, 0, 0}, 20, 5) // Move TCP to '{x = 100, y = 200, z = 300, rx = 0, ry = 0, rz = 0}' via MoveJ method.
        """
    def move_l(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_err: bool = False) -> ReturnType:
        """
        A function that makes TCP to move in a straight line to the target point.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP pose
        speed : float
            Speed (unit: mm/s)
        acceleration : float
            Acceleration (unit: mm/s^2)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> my_point1 = np.array([100, 200, 300, 0, 0, 0])
        >>> my_point2 = np.array([100, 150, 100, 0, 90, 0])
        >>> robot.move_l(rc, my_point1, 20, 5)
        >>> robot.move_l(rc, my_point2, 20, 5)
        """
    def move_l_rel(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, frame: ReferenceFrame, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        A function that makes TCP to move in a straight line to the target point.
        Enter the target point as a value relative to the current TCP value.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP pose
        speed : float
            Speed (unit: mm/s)
        acceleration : float
            Acceleration (unit: mm/s^2)
        frame : ReferenceFrame
            Reference frame for the relative point value.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> target_point = np.array([0, 100, -200, 0, 0, 0])
        >>> robot.move_l_rel(rc, target_point, 300, 400, rb.ReferenceFrame.Base) # move TCP (0,100,-200) w.r.t. Base coordinate (speed/acceleration = 300 / 400)
        """
    def move_lb_add(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], blend_distance: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function adds the points used in MoveLB to the list.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP posture. (Point)
        blend_distance : float
            Blend distance. (Unit: mm)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_lb_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        Initialize (Clear) the point list to be used in MoveLB.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_lb_run(self, response_collector: ResponseCollector, speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, option: MoveLBOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function executes MoveLB using the points added in move_lb_add.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        speed : float
            Speed (Unit: mm/s)
        acceleration : float
            Acceleration (Unit: mm/s^2)
        option : MoveLBOption
            Orientation options. (0 : Intended, 1 : Constant)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_lc_add(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, property: MoveLCProperty, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function adds the points used in MoveLC to the list.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP posture. (Point)
        speed : float
            Speed (Unit: mm/s)
        property : MoveLCProperty
            0 or 1 (0 : Pass through linear motion, 1 : Pass through circular motion)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_lc_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        Initialize (Clear) the point list to be used in MoveLC.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_lc_run(self, response_collector: ResponseCollector, acceleration: typing.SupportsFloat, option: MoveLCOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function executes MoveITPL using the points added in move_itpl_add.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        acceleration : float
            Acceleration
        option : MoveLCOption
            Orientation options
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_pb_add(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], speed: typing.SupportsFloat, option: BlendingOption, blending_value: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        This function adds the points used in MovePB to the list.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            Target TCP posture. (Point)
        speed : float
            Speed (Unit: mm/s)
        option : BlendingOption
            Blending option (0: blend based on ratio, 1: blend based on distance.)
        blending_value : float
            Blending value (0~1 in ratio option or distance in distance option (Unit: mm)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.move_pb_clear(rc)
        >>> robot.move_pb_add(rc, np.array([100, 200, 200, 90, 0, 0]), 200.0, rb.BlendingOption.Ratio, 0.5)
        >>> robot.move_pb_add(rc, np.array([300, 300, 400, 0, 0, 0]), 400.0, rb.BlendingOption.Ratio, 0.5)
        >>> robot.move_pb_add(rc, np.array([0, 200, 400, 90, 0, 0]), 200.0, rb.BlendingOption.Ratio, 0.5)
        >>> robot.move_pb_run(rc, 800, rb.MovePBOption.Intended)
        """
    def move_pb_clear(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        Initialize (Clear) the point list to be used in MovePB.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_pb_run(self, response_collector: ResponseCollector, acceleration: typing.SupportsFloat, option: MovePBOption, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        """
        This function executes MovePB using the points added in move_pb_add.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        acceleration : float
            Acceleration (Unit: mm/s^2)
        option : MovePBOption
            Orientation option (0: Intended, 1: Constant)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def move_servo_j(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], t1: typing.SupportsFloat, t2: typing.SupportsFloat, gain: typing.SupportsFloat, alpha: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def move_servo_l(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], t1: typing.SupportsFloat, t2: typing.SupportsFloat, gain: typing.SupportsFloat, alpha: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def move_servo_t(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], t1: typing.SupportsFloat, t2: typing.SupportsFloat, compensation: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def move_speed_j(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], t1: typing.SupportsFloat, t2: typing.SupportsFloat, gain: typing.SupportsFloat, alpha: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def move_speed_l(self, response_collector: ResponseCollector, joint: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], t1: typing.SupportsFloat, t2: typing.SupportsFloat, gain: typing.SupportsFloat, alpha: typing.SupportsFloat, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def print_variable(self, response_collector: ResponseCollector, variable_name: str, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> tuple[ReturnType, str]:
        ...
    def rt_script(self, response_collector: ResponseCollector, single_command: str, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def rt_script_onoff(self, response_collector: ResponseCollector, on: bool, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def set_acc_multiplier(self, response_collector: ResponseCollector, multiplier: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Sets the overall acceleration multiplier.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        multiplier : float
            Multiply variable. (0~2) Default value is 1.0.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_box_aout(self, response_collector: ResponseCollector, port: typing.SupportsInt, voltage: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the analog output of the control box.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        port : int
            Port number for the analog output. (0~15)
        voltage : float
            Desired output voltage (0~10V, Unit: V)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_box_dout(self, response_collector: ResponseCollector, port: typing.SupportsInt, mode: DigitalIOMode, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the digital output of the control box.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        port : int
            Port number for the digital output.
        mode : DigitalIOMode
            Output mode selection
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_box_dout_toggle(self, response_collector: ResponseCollector, port: typing.SupportsInt, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Toggles the current digital output of the control box.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        port : int
            Port number for the analog output. (0~15)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_collision_after(self, response_collector: ResponseCollector, mode: CollisionFollowUpMode, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the program flow direction after the collision detection.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        mode : CollisionReactionMode
            A variable represents a stop mode.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_collision_mode(self, response_collector: ResponseCollector, mode: CollisionMode, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the stop-mode after the collision detection.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        mode : CollisionMode
            The variable represents a stop mode.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_collision_onoff(self, response_collector: ResponseCollector, on: bool, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        This function turns on/off the collision detection function.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        on : bool
            The variable represents an on/off state, where 0 is off and 1 is on.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_collision_threshold(self, response_collector: ResponseCollector, threshold: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Sets the collision sensitivity (threshold).
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        threshold : float
            The variable represents an threshold value. The lower the value, the more sensitive to collision. (0~1)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_dout_bit_combination(self, response_collector: ResponseCollector, first_port: typing.SupportsInt, last_port: typing.SupportsInt, value: typing.SupportsInt, mode: Endian, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the digital outputs of the control box simultaneously.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        first_port : int
            First port number (0~15)
        last_port : int
            Last port number (0~15)
            last_port must be greater or equal than first_port.
        value : int
            Output value for digital ports (bit combination)
            If mode is LittleEndian and value is 5, then port 0 and port 2 will be high.
        mode : rbpodo.Endian
            Endian selection
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.set_dout_bit_combination(rc, 0, 15, 5, rb.Endian.LittleEndian)  # Port 0 and 2 will be high, while port 1 and 3 are low
        >>> robot.set_dout_bit_combination(rc, 0, 15, 10, rb.Endian.LittleEndian) # Port 1 and 3 will be high, while port 0 and 2 are low
        """
    def set_freedrive_mode(self, response_collector: ResponseCollector, on: bool, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        ...
    def set_operation_mode(self, response_collector: ResponseCollector, mode: OperationMode, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Change the operation mode between real and simulation modes.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        mode : rbpodo.OperationMode
            If set to OperationMode.Real, the robot moves when commanded.
            If set to OperationMode.Simulation, the robot does not moves but the internal reference values changes.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_payload_info(self, response_collector: ResponseCollector, weight: typing.SupportsFloat, com_x: typing.SupportsFloat, com_y: typing.SupportsFloat, com_z: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the tool payload w.r.t. the manufacturer’s default tool coordinate system.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        weight : float
            payload weight (Unit: Kg)
        com_x : float
            payload center of mass x-axis value with respect to the manufacturer's default coordinate system. (Unit: mm)
        com_y : float
            payload center of mass y-axis value with respect to the manufacturer's default coordinate system. (Unit: mm)
        com_z : float
            payload center of mass z-axis value with respect to the manufacturer's default coordinate system. (Unit: mm)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_serial_box(self, response_collector: ResponseCollector, baud_rate: typing.SupportsInt, stop_bit: typing.SupportsInt, parity_bit: typing.SupportsInt, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the serial communication (RS232/485) provided by the control box.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        baud_rate : int
            Communication speed (Baud rate)
        stop_bit : int
            Stop bit, (0 or 1, Default value is 1)
        parity_bit : int
            Parity bit, (0: none, 1: odd, 2: even, Default value is 0)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_serial_tool(self, response_collector: ResponseCollector, baud_rate: typing.SupportsInt, stop_bit: typing.SupportsInt, parity_bit: typing.SupportsInt, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the serial communication (RS232/485) provided by the Tool Flange of the robot arm.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        baud_rate : int
            Communication speed (Baud rate)
        stop_bit : int
            Stop bit, (0 or 1, Default value is 1)
        parity_bit : int
            Parity bit, (0: none, 1: odd, 2: even, Default value is 0)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> robot.set_serial_tool(rc, 115200, 1, 0) # Set tool-flange serial comm. : baud rate = 115200 / stop bit = 1 / parity = none
        """
    def set_speed_acc_j(self, response_collector: ResponseCollector, speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Sets fixed joint velocity/acceleration for J-series motions (MoveJ, MoveJB, MoveJL).
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        speed : float
            Speed/velocity (Unit: deg/s). Does not use negative value.
        acceleration : float
            Acceleration (Unit: deg/s^2). Does not use negative value.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_speed_acc_l(self, response_collector: ResponseCollector, speed: typing.SupportsFloat, acceleration: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Sets fixed linear velocity/acceleration for L-series motions (MoveL, MovePB, MoveLB, MoveITPL).
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        speed : float
            Speed/velocity (Unit: mm/s)
        acceleration : float
            Acceleration (Unit: mm/s^2)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_speed_bar(self, response_collector: ResponseCollector, speed: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the overall speed control bar. (bottom speed control bar in UI).
        
        Warning
        -------
        When running a program on the UI Make page, this function does not work if the safety slide bar option is turned on.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        speed : float
            Desired speed control bar position (0~1)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_speed_multiplier(self, response_collector: ResponseCollector, multiplier: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Sets the overall speed (velocity) multiplier.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        multiplier : float
            Multiply variable. (0~2) Default value is 1.0.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_tcp_info(self, response_collector: ResponseCollector, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the TCP position and orientation w.r.t. the manufacturer’s default tool coordinate system.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        point : numpy.ndarray(shape=(6, 1))
            position and orientation of tcp with respect to manufacturer's default tool coordinate system. (x, y, z, rx, ry, rz) (Unit: mm & degree)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_tool_box(self, response_collector: ResponseCollector, x_width: typing.SupportsFloat, y_width: typing.SupportsFloat, z_width: typing.SupportsFloat, x_offset: typing.SupportsFloat, y_offset: typing.SupportsFloat, z_offset: typing.SupportsFloat, timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set the tool box w.r.t. the manufacturer’s default tool coordinate system.
        
        Warning
        -------
        The value set in this function returns to the default value after the program ends.
        If this function is not called in program-flow, the value set in the Setup page is used.
        During program flow, the value set in this function is maintained until this function is called again.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        x_width : float
            width of tool along x-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        y_width : float
            width of tool along y-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        z_width : float
            width of tool along z-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        x_offset : float
            offset of box along x-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        y_offset : float
            offset of box along y-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        z_offset : float
            offset of box along z-axis with respect to the manufacturer's default tool coordinate system. (Unit: mm)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def set_tool_out(self, response_collector: ResponseCollector, voltage: typing.SupportsInt, signal_0: typing.SupportsInt, signal_1: typing.SupportsInt, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def set_user_coordinate(self, response_collector: ResponseCollector, id: typing.SupportsInt, point: typing.Annotated[numpy.typing.NDArray[numpy.float64], "[6, 1]"], timeout: typing.SupportsFloat = -1, return_on_error: bool = False) -> ReturnType:
        """
        Set user coordinate
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        id : int
            id of user coordinate to change (0~2)
        point : numpy.ndarray(shape=(6, 1))
            position and orientation of coordinate with respect to base frame. (x, y, z, rx, ry, rz) (Unit: mm & degree)
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def shutdown(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        """
        Turn off the power supply for the robot arm.
        
        Warning
        -------
        The robot arm powers up. Be careful when you use this function.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        """
    def task_load(self, response_collector: ResponseCollector, program_name: str, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def task_pause(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def task_play(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def task_resume(self, response_collector: ResponseCollector, collision: bool, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def task_stop(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def wait_for_move_finished(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        ...
    def wait_for_move_started(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        """
        Wait until the motion is started.
        
        More specifically, the program is waiting for the response message from control box ``info[motion_changed][X]`` where ``X`` is positive integer.
        
        Parameters
        ----------
        response_collector : ResponseCollector
            A collector object to accumulate and manage the response message.
        timeout : float
            The maximum duration (in seconds) to wait for a response before timing out.
        return_on_error : bool
            A boolean flag indicating whether the function should immediately return upon encountering an error.
        
        Returns
        -------
        ReturnType
        
        Examples
        --------
        >>> joint = np.array([0, 0, 0, 0, 0, 0])
        >>> robot.move_j(rc, joint, 60, 80)
        >>> rc = rc.error().throw_if_not_empty()
        >>> if robot.wait_for_move_started(rc).type() == rb.ReturnType.Success:
        >>>     robot.wait_for_move_finished(rc)
        """
    def wait_for_task_finished(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        ...
    def wait_for_task_loaded(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        ...
    def wait_for_task_started(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = True) -> ReturnType:
        ...
    def wait_until(self, response_collector: ResponseCollector, func: collections.abc.Callable[[Response], bool], timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
    def wait_until_ack_message(self, response_collector: ResponseCollector, timeout: typing.SupportsFloat = -1.0, return_on_error: bool = False) -> ReturnType:
        ...
class CobotData:
    def __init__(self, address: str, port: typing.SupportsInt = 5001) -> None:
        ...
    def request_data(self, timeout: typing.SupportsFloat = -1.0) -> SystemState | None:
        ...
class CollisionFollowUpMode:
    """
    Members:
    
      PauseProgram : Pause the program
    
      StopProgram : Halt/stop the program flow
    """
    PauseProgram: typing.ClassVar[CollisionFollowUpMode]  # value = <CollisionFollowUpMode.PauseProgram: 0>
    StopProgram: typing.ClassVar[CollisionFollowUpMode]  # value = <CollisionFollowUpMode.StopProgram: 1>
    __members__: typing.ClassVar[dict[str, CollisionFollowUpMode]]  # value = {'PauseProgram': <CollisionFollowUpMode.PauseProgram: 0>, 'StopProgram': <CollisionFollowUpMode.StopProgram: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class CollisionMode:
    """
    Members:
    
      GeneralStop : General Stop
    
      EvasionStop : Evasion Stop
    """
    EvasionStop: typing.ClassVar[CollisionMode]  # value = <CollisionMode.EvasionStop: 1>
    GeneralStop: typing.ClassVar[CollisionMode]  # value = <CollisionMode.GeneralStop: 0>
    __members__: typing.ClassVar[dict[str, CollisionMode]]  # value = {'GeneralStop': <CollisionMode.GeneralStop: 0>, 'EvasionStop': <CollisionMode.EvasionStop: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class ControlBoxInfo:
    def __repr__(self) -> str:
        ...
    @property
    def robot_box_type(self) -> int:
        ...
    @property
    def system_version(self) -> int:
        ...
class DigitalIOMode:
    """
    Members:
    
      Bypass : Bypass
    
      Low : Low
    
      High : High
    """
    Bypass: typing.ClassVar[DigitalIOMode]  # value = <DigitalIOMode.Bypass: -1>
    High: typing.ClassVar[DigitalIOMode]  # value = <DigitalIOMode.High: 1>
    Low: typing.ClassVar[DigitalIOMode]  # value = <DigitalIOMode.Low: 0>
    __members__: typing.ClassVar[dict[str, DigitalIOMode]]  # value = {'Bypass': <DigitalIOMode.Bypass: -1>, 'Low': <DigitalIOMode.Low: 0>, 'High': <DigitalIOMode.High: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class Endian:
    """
    Members:
    
      LittleEndian
    
      BigEndian
    """
    BigEndian: typing.ClassVar[Endian]  # value = <Endian.BigEndian: 1>
    LittleEndian: typing.ClassVar[Endian]  # value = <Endian.LittleEndian: 0>
    __members__: typing.ClassVar[dict[str, Endian]]  # value = {'LittleEndian': <Endian.LittleEndian: 0>, 'BigEndian': <Endian.BigEndian: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class GripperConnectionPoint:
    """
    Members:
    
      ToolFlange
    
      ControlBox
    
      ToolFlange_Advanced
    """
    ControlBox: typing.ClassVar[GripperConnectionPoint]  # value = <GripperConnectionPoint.ControlBox: 1>
    ToolFlange: typing.ClassVar[GripperConnectionPoint]  # value = <GripperConnectionPoint.ToolFlange: 0>
    ToolFlange_Advanced: typing.ClassVar[GripperConnectionPoint]  # value = <GripperConnectionPoint.ToolFlange_Advanced: 2>
    __members__: typing.ClassVar[dict[str, GripperConnectionPoint]]  # value = {'ToolFlange': <GripperConnectionPoint.ToolFlange: 0>, 'ControlBox': <GripperConnectionPoint.ControlBox: 1>, 'ToolFlange_Advanced': <GripperConnectionPoint.ToolFlange_Advanced: 2>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class GripperModel:
    """
    Members:
    
      Robotiq_Hand_E
    
      Robotiq_2F_85
    
      Robotiq_2F1_40
    
      Robotiq_E_Pick
    
      Robotis_RH_P12_RN
    
      JRT_JEGB_4285
    
      JRT_JEGB_42140
    
      DH_AG_95
    
      Setech_NutRunner
    
      OnRobot2FG7
    
      JRT_JEGG
    
      RB_5FDG
    
      OnRobot_RG2
    
      OnRobot_RG6
    
      OnRobot_VG10
    
      OnRobot_VGC10
    
      OnRobot_3FG15
    
      OnRobot_Sander
    
      OnRobot_VGP20
    
      OnRobot_MG10
    
      OnRobot_SoftGripper
    
      JRT_JEGC
    
      Schunk_Coact
    
      Baumer_Laser_Sensor
    
      Mighty_12LF
    
      JRT_JEGH_3520
    
      SeeN_Grip
    
      TESOLLO_DG_3F
    
      KORAS_Tooling
    """
    Baumer_Laser_Sensor: typing.ClassVar[GripperModel]  # value = <GripperModel.Baumer_Laser_Sensor: 23>
    DH_AG_95: typing.ClassVar[GripperModel]  # value = <GripperModel.DH_AG_95: 7>
    JRT_JEGB_42140: typing.ClassVar[GripperModel]  # value = <GripperModel.JRT_JEGB_42140: 6>
    JRT_JEGB_4285: typing.ClassVar[GripperModel]  # value = <GripperModel.JRT_JEGB_4285: 5>
    JRT_JEGC: typing.ClassVar[GripperModel]  # value = <GripperModel.JRT_JEGC: 21>
    JRT_JEGG: typing.ClassVar[GripperModel]  # value = <GripperModel.JRT_JEGG: 10>
    JRT_JEGH_3520: typing.ClassVar[GripperModel]  # value = <GripperModel.JRT_JEGH_3520: 25>
    KORAS_Tooling: typing.ClassVar[GripperModel]  # value = <GripperModel.KORAS_Tooling: 28>
    Mighty_12LF: typing.ClassVar[GripperModel]  # value = <GripperModel.Mighty_12LF: 24>
    OnRobot2FG7: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot2FG7: 9>
    OnRobot_3FG15: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_3FG15: 16>
    OnRobot_MG10: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_MG10: 19>
    OnRobot_RG2: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_RG2: 12>
    OnRobot_RG6: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_RG6: 13>
    OnRobot_Sander: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_Sander: 17>
    OnRobot_SoftGripper: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_SoftGripper: 20>
    OnRobot_VG10: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_VG10: 14>
    OnRobot_VGC10: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_VGC10: 15>
    OnRobot_VGP20: typing.ClassVar[GripperModel]  # value = <GripperModel.OnRobot_VGP20: 18>
    RB_5FDG: typing.ClassVar[GripperModel]  # value = <GripperModel.RB_5FDG: 11>
    Robotiq_2F1_40: typing.ClassVar[GripperModel]  # value = <GripperModel.Robotiq_2F1_40: 2>
    Robotiq_2F_85: typing.ClassVar[GripperModel]  # value = <GripperModel.Robotiq_2F_85: 1>
    Robotiq_E_Pick: typing.ClassVar[GripperModel]  # value = <GripperModel.Robotiq_E_Pick: 3>
    Robotiq_Hand_E: typing.ClassVar[GripperModel]  # value = <GripperModel.Robotiq_Hand_E: 0>
    Robotis_RH_P12_RN: typing.ClassVar[GripperModel]  # value = <GripperModel.Robotis_RH_P12_RN: 4>
    Schunk_Coact: typing.ClassVar[GripperModel]  # value = <GripperModel.Schunk_Coact: 22>
    SeeN_Grip: typing.ClassVar[GripperModel]  # value = <GripperModel.SeeN_Grip: 26>
    Setech_NutRunner: typing.ClassVar[GripperModel]  # value = <GripperModel.Setech_NutRunner: 8>
    TESOLLO_DG_3F: typing.ClassVar[GripperModel]  # value = <GripperModel.TESOLLO_DG_3F: 27>
    __members__: typing.ClassVar[dict[str, GripperModel]]  # value = {'Robotiq_Hand_E': <GripperModel.Robotiq_Hand_E: 0>, 'Robotiq_2F_85': <GripperModel.Robotiq_2F_85: 1>, 'Robotiq_2F1_40': <GripperModel.Robotiq_2F1_40: 2>, 'Robotiq_E_Pick': <GripperModel.Robotiq_E_Pick: 3>, 'Robotis_RH_P12_RN': <GripperModel.Robotis_RH_P12_RN: 4>, 'JRT_JEGB_4285': <GripperModel.JRT_JEGB_4285: 5>, 'JRT_JEGB_42140': <GripperModel.JRT_JEGB_42140: 6>, 'DH_AG_95': <GripperModel.DH_AG_95: 7>, 'Setech_NutRunner': <GripperModel.Setech_NutRunner: 8>, 'OnRobot2FG7': <GripperModel.OnRobot2FG7: 9>, 'JRT_JEGG': <GripperModel.JRT_JEGG: 10>, 'RB_5FDG': <GripperModel.RB_5FDG: 11>, 'OnRobot_RG2': <GripperModel.OnRobot_RG2: 12>, 'OnRobot_RG6': <GripperModel.OnRobot_RG6: 13>, 'OnRobot_VG10': <GripperModel.OnRobot_VG10: 14>, 'OnRobot_VGC10': <GripperModel.OnRobot_VGC10: 15>, 'OnRobot_3FG15': <GripperModel.OnRobot_3FG15: 16>, 'OnRobot_Sander': <GripperModel.OnRobot_Sander: 17>, 'OnRobot_VGP20': <GripperModel.OnRobot_VGP20: 18>, 'OnRobot_MG10': <GripperModel.OnRobot_MG10: 19>, 'OnRobot_SoftGripper': <GripperModel.OnRobot_SoftGripper: 20>, 'JRT_JEGC': <GripperModel.JRT_JEGC: 21>, 'Schunk_Coact': <GripperModel.Schunk_Coact: 22>, 'Baumer_Laser_Sensor': <GripperModel.Baumer_Laser_Sensor: 23>, 'Mighty_12LF': <GripperModel.Mighty_12LF: 24>, 'JRT_JEGH_3520': <GripperModel.JRT_JEGH_3520: 25>, 'SeeN_Grip': <GripperModel.SeeN_Grip: 26>, 'TESOLLO_DG_3F': <GripperModel.TESOLLO_DG_3F: 27>, 'KORAS_Tooling': <GripperModel.KORAS_Tooling: 28>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class Message:
    def __repr__(self) -> str:
        ...
    @property
    def en(self) -> str:
        ...
    @property
    def ko(self) -> str:
        ...
class MoveCOrientationOption:
    """
    Members:
    
      Intended : Intended (Follows the rotation value taught by the user)
    
      Constant : Constant (Keep the rotation value of the starting position)
    
      Radial : Radial (Rotate the TCP according to the rotation of the circle)
    
      Smooth : Smooth (Similar to Intended, but with a smooth rate of rotation change)
    """
    Constant: typing.ClassVar[MoveCOrientationOption]  # value = <MoveCOrientationOption.Constant: 1>
    Intended: typing.ClassVar[MoveCOrientationOption]  # value = <MoveCOrientationOption.Intended: 0>
    Radial: typing.ClassVar[MoveCOrientationOption]  # value = <MoveCOrientationOption.Radial: 2>
    Smooth: typing.ClassVar[MoveCOrientationOption]  # value = <MoveCOrientationOption.Smooth: 3>
    __members__: typing.ClassVar[dict[str, MoveCOrientationOption]]  # value = {'Intended': <MoveCOrientationOption.Intended: 0>, 'Constant': <MoveCOrientationOption.Constant: 1>, 'Radial': <MoveCOrientationOption.Radial: 2>, 'Smooth': <MoveCOrientationOption.Smooth: 3>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveCRotationOption:
    """
    Members:
    
      Intended : Intended (rotate the same way as the Constant below.)
    
      Constant : Constant (Keep the rotation value of the starting position)
    
      Radial : Radial (Rotate the TCP according to the rotation of the circle)
    """
    Constant: typing.ClassVar[MoveCRotationOption]  # value = <MoveCRotationOption.Constant: 1>
    Intended: typing.ClassVar[MoveCRotationOption]  # value = <MoveCRotationOption.Intended: 0>
    Radial: typing.ClassVar[MoveCRotationOption]  # value = <MoveCRotationOption.Radial: 2>
    __members__: typing.ClassVar[dict[str, MoveCRotationOption]]  # value = {'Intended': <MoveCRotationOption.Intended: 0>, 'Constant': <MoveCRotationOption.Constant: 1>, 'Radial': <MoveCRotationOption.Radial: 2>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveITPLOption:
    """
    Members:
    
      Intended : Intended (Follows the rotation value taught by the user)
    
      Constant : Constant (Keep the rotation value of the starting position)
    
      Smooth : Smooth (Similar to Intended, but with a smooth rate of rotation change)
    
      CAIntended : CA-Intended (CA mode Intended)
    
      CAConstant : CA-Constant (CA mode Constant)
    
      CASmooth : CA-Smooth (CA mode Smooth)
    """
    CAConstant: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.CAConstant: 6>
    CAIntended: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.CAIntended: 5>
    CASmooth: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.CASmooth: 8>
    Constant: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.Constant: 1>
    Intended: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.Intended: 0>
    Smooth: typing.ClassVar[MoveITPLOption]  # value = <MoveITPLOption.Smooth: 3>
    __members__: typing.ClassVar[dict[str, MoveITPLOption]]  # value = {'Intended': <MoveITPLOption.Intended: 0>, 'Constant': <MoveITPLOption.Constant: 1>, 'Smooth': <MoveITPLOption.Smooth: 3>, 'CAIntended': <MoveITPLOption.CAIntended: 5>, 'CAConstant': <MoveITPLOption.CAConstant: 6>, 'CASmooth': <MoveITPLOption.CASmooth: 8>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveLBOption:
    """
    Members:
    
      Intended : Intended (Follows the rotation value taught by the user)
    
      Constant : Constant (Keep the rotation value of the starting position)
    """
    Constant: typing.ClassVar[MoveLBOption]  # value = <MoveLBOption.Constant: 1>
    Intended: typing.ClassVar[MoveLBOption]  # value = <MoveLBOption.Intended: 0>
    __members__: typing.ClassVar[dict[str, MoveLBOption]]  # value = {'Intended': <MoveLBOption.Intended: 0>, 'Constant': <MoveLBOption.Constant: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveLCOption:
    """
    Members:
    
      Intended : Intended (Follows the rotation value taught by the user)
    
      Constant : Constant (Keep the rotation value of the starting position)
    
      Smooth : Smooth (Similar to Intended, but with a smooth rate of rotation change)
    """
    Constant: typing.ClassVar[MoveLCOption]  # value = <MoveLCOption.Constant: 1>
    Intended: typing.ClassVar[MoveLCOption]  # value = <MoveLCOption.Intended: 0>
    Smooth: typing.ClassVar[MoveLCOption]  # value = <MoveLCOption.Smooth: 3>
    __members__: typing.ClassVar[dict[str, MoveLCOption]]  # value = {'Intended': <MoveLCOption.Intended: 0>, 'Constant': <MoveLCOption.Constant: 1>, 'Smooth': <MoveLCOption.Smooth: 3>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveLCProperty:
    """
    Members:
    
      LinearMotion : Pass through linear motion
    
      CircularMotion : Pass through circular motion
    """
    CircularMotion: typing.ClassVar[MoveLCProperty]  # value = <MoveLCProperty.CircularMotion: 1>
    LinearMotion: typing.ClassVar[MoveLCProperty]  # value = <MoveLCProperty.LinearMotion: 0>
    __members__: typing.ClassVar[dict[str, MoveLCProperty]]  # value = {'LinearMotion': <MoveLCProperty.LinearMotion: 0>, 'CircularMotion': <MoveLCProperty.CircularMotion: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MovePBOption:
    """
    Members:
    
      Intended : Intended (Follows the rotation value taught by the user)
    
      Constant : Constant (Keep the rotation value of the starting position)
    
      Smooth : Smooth (Similar to Intended, but with a smooth rate of rotation change)
    """
    Constant: typing.ClassVar[MovePBOption]  # value = <MovePBOption.Constant: 1>
    Intended: typing.ClassVar[MovePBOption]  # value = <MovePBOption.Intended: 0>
    Smooth: typing.ClassVar[MovePBOption]  # value = <MovePBOption.Smooth: 3>
    __members__: typing.ClassVar[dict[str, MovePBOption]]  # value = {'Intended': <MovePBOption.Intended: 0>, 'Constant': <MovePBOption.Constant: 1>, 'Smooth': <MovePBOption.Smooth: 3>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MoveServoTOption:
    """
    Members:
    
      NoCompensation
    
      GravityCompensation
    
      FrictionCompensation
    """
    FrictionCompensation: typing.ClassVar[MoveServoTOption]  # value = <MoveServoTOption.FrictionCompensation: 2>
    GravityCompensation: typing.ClassVar[MoveServoTOption]  # value = <MoveServoTOption.GravityCompensation: 1>
    NoCompensation: typing.ClassVar[MoveServoTOption]  # value = <MoveServoTOption.NoCompensation: 0>
    __members__: typing.ClassVar[dict[str, MoveServoTOption]]  # value = {'NoCompensation': <MoveServoTOption.NoCompensation: 0>, 'GravityCompensation': <MoveServoTOption.GravityCompensation: 1>, 'FrictionCompensation': <MoveServoTOption.FrictionCompensation: 2>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class OperationMode:
    """
    Members:
    
      Real
    
      Simulation
    """
    Real: typing.ClassVar[OperationMode]  # value = <OperationMode.Real: 0>
    Simulation: typing.ClassVar[OperationMode]  # value = <OperationMode.Simulation: 1>
    __members__: typing.ClassVar[dict[str, OperationMode]]  # value = {'Real': <OperationMode.Real: 0>, 'Simulation': <OperationMode.Simulation: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class ReferenceFrame:
    """
    Members:
    
      Base : Base (Global) coordinate
    
      Tool : Tool (Local) coordinate
    
      User0 : User coordinate 0
    
      User1 : User coordinate 1
    
      User2 : User coordinate 2
    """
    Base: typing.ClassVar[ReferenceFrame]  # value = <ReferenceFrame.Base: 0>
    Tool: typing.ClassVar[ReferenceFrame]  # value = <ReferenceFrame.Tool: 1>
    User0: typing.ClassVar[ReferenceFrame]  # value = <ReferenceFrame.User0: 2>
    User1: typing.ClassVar[ReferenceFrame]  # value = <ReferenceFrame.User1: 3>
    User2: typing.ClassVar[ReferenceFrame]  # value = <ReferenceFrame.User2: 4>
    __members__: typing.ClassVar[dict[str, ReferenceFrame]]  # value = {'Base': <ReferenceFrame.Base: 0>, 'Tool': <ReferenceFrame.Tool: 1>, 'User0': <ReferenceFrame.User0: 2>, 'User1': <ReferenceFrame.User1: 3>, 'User2': <ReferenceFrame.User2: 4>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class Response:
    class Type:
        """
        Members:
        
          ACK
        
          Info
        
          Warn
        
          Error
        
          Unknown
        """
        ACK: typing.ClassVar[Response.Type]  # value = <Type.ACK: 0>
        Error: typing.ClassVar[Response.Type]  # value = <Type.Error: 3>
        Info: typing.ClassVar[Response.Type]  # value = <Type.Info: 1>
        Unknown: typing.ClassVar[Response.Type]  # value = <Type.Unknown: 4>
        Warn: typing.ClassVar[Response.Type]  # value = <Type.Warn: 2>
        __members__: typing.ClassVar[dict[str, Response.Type]]  # value = {'ACK': <Type.ACK: 0>, 'Info': <Type.Info: 1>, 'Warn': <Type.Warn: 2>, 'Error': <Type.Error: 3>, 'Unknown': <Type.Unknown: 4>}
        def __eq__(self, other: typing.Any) -> bool:
            ...
        def __getstate__(self) -> int:
            ...
        def __hash__(self) -> int:
            ...
        def __index__(self) -> int:
            ...
        def __init__(self, value: typing.SupportsInt) -> None:
            ...
        def __int__(self) -> int:
            ...
        def __ne__(self, other: typing.Any) -> bool:
            ...
        def __repr__(self) -> str:
            ...
        def __setstate__(self, state: typing.SupportsInt) -> None:
            ...
        def __str__(self) -> str:
            ...
        @property
        def name(self) -> str:
            ...
        @property
        def value(self) -> int:
            ...
    def __repr__(self) -> str:
        ...
    def category(self) -> str:
        ...
    def msg(self) -> str:
        ...
    def raw(self) -> str:
        ...
    def type(self) -> Response.Type:
        ...
class ResponseCollector:
    class ConfigFlag:
        """
        Members:
        
          Default
        
          EnableCheckOldResponses
        
          RemoveAckAutomatically
        """
        Default: typing.ClassVar[ResponseCollector.ConfigFlag]  # value = <ConfigFlag.Default: 2>
        EnableCheckOldResponses: typing.ClassVar[ResponseCollector.ConfigFlag]  # value = <ConfigFlag.EnableCheckOldResponses: 1>
        RemoveAckAutomatically: typing.ClassVar[ResponseCollector.ConfigFlag]  # value = <ConfigFlag.Default: 2>
        __members__: typing.ClassVar[dict[str, ResponseCollector.ConfigFlag]]  # value = {'Default': <ConfigFlag.Default: 2>, 'EnableCheckOldResponses': <ConfigFlag.EnableCheckOldResponses: 1>, 'RemoveAckAutomatically': <ConfigFlag.Default: 2>}
        def __eq__(self, other: typing.Any) -> bool:
            ...
        def __getstate__(self) -> int:
            ...
        def __hash__(self) -> int:
            ...
        def __index__(self) -> int:
            ...
        def __init__(self, value: typing.SupportsInt) -> None:
            ...
        def __int__(self) -> int:
            ...
        def __ne__(self, other: typing.Any) -> bool:
            ...
        def __repr__(self) -> str:
            ...
        def __setstate__(self, state: typing.SupportsInt) -> None:
            ...
        def __str__(self) -> str:
            ...
        @property
        def name(self) -> str:
            ...
        @property
        def value(self) -> int:
            ...
    def __init__(self, flag: typing.SupportsInt = 2) -> None:
        ...
    def __iter__(self) -> collections.abc.Iterator[Response]:
        ...
    def __len__(self) -> int:
        ...
    def __repr__(self) -> str:
        ...
    def ack(self, remain: bool = False) -> ResponseCollector:
        ...
    def add(self, response: Response) -> None:
        ...
    def category_filter(self, filter: str, remain: bool = False) -> ResponseCollector:
        ...
    def clear(self) -> None:
        ...
    def clear_callback(self) -> None:
        ...
    def error(self, remain: bool = False) -> ResponseCollector:
        ...
    def flag(self) -> int:
        ...
    def has_error(self) -> bool:
        ...
    def info(self, remain: bool = False) -> ResponseCollector:
        ...
    def set_callback(self, callback: collections.abc.Callable[[Response], None]) -> None:
        ...
    def set_flag(self, arg0: typing.SupportsInt) -> None:
        ...
    def throw_if_not_empty(self) -> ResponseCollector:
        ...
    def type_filter(self, type: Response.Type, remain: bool = False) -> ResponseCollector:
        ...
    def warn(self, remain: bool = False) -> ResponseCollector:
        ...
class ReturnType:
    class Type:
        """
        Members:
        
          Undefined
        
          Success
        
          Timeout
        
          Error
        """
        Error: typing.ClassVar[ReturnType.Type]  # value = <Type.Error: 3>
        Success: typing.ClassVar[ReturnType.Type]  # value = <Type.Success: 1>
        Timeout: typing.ClassVar[ReturnType.Type]  # value = <Type.Timeout: 2>
        Undefined: typing.ClassVar[ReturnType.Type]  # value = <Type.Undefined: 0>
        __members__: typing.ClassVar[dict[str, ReturnType.Type]]  # value = {'Undefined': <Type.Undefined: 0>, 'Success': <Type.Success: 1>, 'Timeout': <Type.Timeout: 2>, 'Error': <Type.Error: 3>}
        def __eq__(self, other: typing.Any) -> bool:
            ...
        def __getstate__(self) -> int:
            ...
        def __hash__(self) -> int:
            ...
        def __index__(self) -> int:
            ...
        def __init__(self, value: typing.SupportsInt) -> None:
            ...
        def __int__(self) -> int:
            ...
        def __ne__(self, other: typing.Any) -> bool:
            ...
        def __repr__(self) -> str:
            ...
        def __setstate__(self, state: typing.SupportsInt) -> None:
            ...
        def __str__(self) -> str:
            ...
        @property
        def name(self) -> str:
            ...
        @property
        def value(self) -> int:
            ...
    Error: typing.ClassVar[ReturnType.Type]  # value = <Type.Error: 3>
    Success: typing.ClassVar[ReturnType.Type]  # value = <Type.Success: 1>
    Timeout: typing.ClassVar[ReturnType.Type]  # value = <Type.Timeout: 2>
    Undefined: typing.ClassVar[ReturnType.Type]  # value = <Type.Undefined: 0>
    def __init__(self, type: ReturnType.Type, remain_time: typing.SupportsFloat) -> None:
        ...
    def __repr__(self) -> str:
        ...
    def is_error(self) -> bool:
        ...
    def is_success(self) -> bool:
        ...
    def is_timeout(self) -> bool:
        ...
    def remain_time(self) -> float:
        ...
    def set_remain_time(self, remain_time: typing.SupportsFloat) -> None:
        ...
    def type(self) -> ReturnType.Type:
        ...
class RobotState:
    """
    Members:
    
      Unknown
    
      Idle
    
      Moving
    """
    Idle: typing.ClassVar[RobotState]  # value = <RobotState.Idle: 1>
    Moving: typing.ClassVar[RobotState]  # value = <RobotState.Moving: 2>
    Unknown: typing.ClassVar[RobotState]  # value = <RobotState.Unknown: 0>
    __members__: typing.ClassVar[dict[str, RobotState]]  # value = {'Unknown': <RobotState.Unknown: 0>, 'Idle': <RobotState.Idle: 1>, 'Moving': <RobotState.Moving: 2>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class SystemState:
    class Data:
        @property
        def aa_joint_ref(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Reference angle of each external-joint (auxiliary joint). (unit: degree)
            
            External joint number: 0~5
            """
        @property
        def analog_in(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Control box analog input measurement information of each channel (unit: Voltage)
            
            Channel number: 0~3
            """
        @property
        def analog_out(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Control box analog output information of each channel (unit: Voltage)
            
            Channel number: 0~3
            """
        @property
        def collision_detect_onoff(self) -> int:
            """
            Out collision detection On/Off State (1=On / 0 = Off)
            """
        @property
        def default_speed(self) -> float:
            """
            Default speed multiplier value of robot motion (=speed bar in UI) (value: 0 ~ 1)
            """
        @property
        def digital_in(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Control box digital input measurement information of each channel (value: 0 or 1)
            
            Channel number: 0~15
            """
        @property
        def digital_out(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Control box digital output information of each channel (value: 0 or 1)
            
            Channel number: 0~15
            """
        @property
        def eft_fx(self) -> float:
            """
            External F/T force sensor value. Fx (Unit: N)
            """
        @property
        def eft_fy(self) -> float:
            """
            External F/T force sensor value. Fy (Unit: N)
            """
        @property
        def eft_fz(self) -> float:
            """
            External F/T force sensor value. Fz (Unit: N)
            """
        @property
        def eft_mx(self) -> float:
            """
            External F/T torque sensor value. Mx (Unit: Nm)
            """
        @property
        def eft_my(self) -> float:
            """
            External F/T torque sensor value. My (Unit: Nm)
            """
        @property
        def eft_mz(self) -> float:
            """
            External F/T torque sensor value. Mz (Unit: Nm)
            """
        @property
        def extend_io1_analog_in(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Extended I/O board analog input measurement information of each channel (unit: Voltage)
            
            Channel number: 0~3
            """
        @property
        def extend_io1_analog_out(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Extended I/O board analog output information of each channel (unit: Voltage)
            
            Channel number: 0~3
            """
        @property
        def extend_io1_digital_info(self) -> int:
            """
            Extended I/O board digital input/output information. It consists of a combination of bits
            
            * (extend_io1_digital_info >> 0) & 0b01 = Extend I/O digital input # 0
            * (extend_io1_digital_info >> 1) & 0b01 = Extend I/O digital input # 1
            * ..
            * (extend_io1_digital_info >> 15) & 0b01 = Extend I/O digital input # 15
            * (extend_io1_digital_info >> 16) & 0b01 = Extend I/O digital output # 0
            * (extend_io1_digital_info >> 17) & 0b01 = Extend I/O digital output # 1
            * ..
            * (extend_io1_digital_info >> 31) & 0b01 = Extend I/O digital input # 15
            """
        @property
        def inbox_check_mode(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Check-function mode of Inbox #.
            
            # = In Box number: 0 or 1
            0 = None / 1 = Check Tool Flange center / 2 = Check TCP / 3 = Check Tool Box / 4 = Check all
            """
        @property
        def inbox_trap_flag(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Whether or not detected by the Inbox # check-function.
            
            # = In Box number: 0 or 1
            """
        @property
        def information_chunk_1(self) -> int:
            """
            Information chunk to deliver various state information (power and others). It consists of a combination of bits.
            
            * (information_chunk_1 >> 0) & 0b01 = Control Box's 48V input state
            * (information_chunk_1 >> 1) & 0b01 = Control Box's 48V output state
            * (information_chunk_1 >> 2) & 0b01 = Control Box's 24V input state
            * (information_chunk_1 >> 3) & 0b01 = Control Box's E-Stop state 1
            * (information_chunk_1 >> 4) & 0b01 = Control Box's User Switch state
            * (information_chunk_1 >> 5) & 0b01 = Control Box's E-Stop state 2
            * (information_chunk_1 >> 6) & 0b01 = Whether power is applied to the robot arm
            * (information_chunk_1 >> 7) & 0b01 = TFB’s Direct teaching button is pressed
            * (information_chunk_1 >> 30) & 0b01 = Program Load state
            * (Whenever the Program load process is successful, 1 and 0 are continuously converted.)
            * (information_chunk_1 >> 31) & 0b01 = Program Transmit state (via TCP/IP Tablet UI, not for user)
            """
        @property
        def information_chunk_2(self) -> int:
            """
            Information chunk to deliver various state information. It consists of a combination of bits.
            
            * (information_chunk_2 >> 0) & 0b11 = Config digital input 16 (0 or 1) (Not for user)
            * (information_chunk_2 >> 2) & 0b1111111111111111 = Target welding voltage * 100
            """
        @property
        def information_chunk_3(self) -> int:
            """
            Information chunk to deliver various state information. It consists of a combination of bits.
            
            * (information_chunk_3 >> 0) & 0b11 = Config digital input 17 (0 or 1) (Not for user)
            """
        @property
        def information_chunk_4(self) -> int:
            """
            Information chunk to deliver various state information. It consists of a combination of bits.
            
            * (information_chunk_4 >> 0) & 0b11 = No-Arc Function On/Off (0 or 1)
            * (information_chunk_4 >> 2) & 0b111111 = Selected Tool List number
            * (information_chunk_4 >> 8) & 0b11 = External Joint (External axis) Jog On/Off (0 or 1)
            * (information_chunk_4 >> 10) & 0b01 = Tool Flange Digital Input 2
            * (information_chunk_4 >> 11) & 0b01 = Tool Flange Digital Input 3
            * (information_chunk_4 >> 12) & 0b01 = Tool Flange Digital Input 4
            * (information_chunk_4 >> 13) & 0b01 = Tool Flange Digital Input 5
            * (information_chunk_4 >> 14) & 0b01 = Arc Light On state (Not for user)
            * (information_chunk_4 >> 15) & 0b1111111111111 = Target welding current * 10
            * (information_chunk_4 >> 28) & 0b11 = Target welding voltage option (0 or 1)
            """
        @property
        def init_error(self) -> int:
            """
            Error code during the arm activation (return value for UI)
            """
        @property
        def init_state_info(self) -> int:
            """
            Robot arm activation (Initialization) stage info (0 -> 6)
            
            * 0: default
            * 1: Power check
            * 2: Device check
            * 3: Servo Initialization check
            * 4: Parameter check
            * 5: Payload check
            * 6: Activation done
            """
        @property
        def is_freedrive_mode(self) -> int:
            """
            Free-drive (Gravity-compensation) On/Off State (1=On / 0 = Off)
            """
        @property
        def jnt_ang(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Measured joint position. (Unit: deg)
            
            0 = Base / 1 = Shoulder / 2 = Elbow / 3 = Wrist1 / 4 = Wrist2 / 5 = Wrist3
            
            These values do not change in simulation mode.
            """
        @property
        def jnt_cur(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Measured joint current. (Unit: Amp)
            
            0 = Base / 1 = Shoulder / 2 = Elbow / 3 = Wrist1 / 4 = Wrist2 / 5 = Wrist3
            
            Note
            ----
            You can get joint torque by multiplying torque constant.
            """
        @property
        def jnt_info(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Basic state of each joint.
            
            0 = Base / 1 = Shoulder / 2 = Elbow / 3 = Wrist1 / 4 = Wrist2 / 5 = Wrist3
            
            * Each int (4byte) consists of a combination of bits.
            * (jnt_info[#] >> 0) & 0b01 = Joint #'s FET state
            * (jnt_info[#] >> 1) & 0b01 = Joint #'s RUN state
            * (jnt_info[#] >> 2) & 0b01 = Joint #'s INIT state
            * (jnt_info[#] >> 3) & 0b01 = Joint #'s MODE state
            * (jnt_info[#] >> 4) & 0b01 = Joint #'s encoder state (Nonius err)
            * (jnt_info[#] >> 5) & 0b01 = Joint #'s encoder state (LowBatt err)
            * (jnt_info[#] >> 6) & 0b01 = Joint #'s encoder state (Calibration mode)
            * (jnt_info[#] >> 7) & 0b01 = Joint #'s encoder state (Multi-turn err)
            * (jnt_info[#] >> 8) & 0b01 = Joint #'s Error state (JAM err)
            * (jnt_info[#] >> 9) & 0b01 = Joint #'s Error state (CUR err)
            * (jnt_info[#] >> 10) & 0b01 = Joint #'s Error state (BIG err)
            * (jnt_info[#] >> 11) & 0b01 = Joint #'s Error state (INP err)
            * (jnt_info[#] >> 12) & 0b01 = Joint #'s Error state (FLT err)
            * (jnt_info[#] >> 13) & 0b01 = Joint #'s Error state (TMP err)
            * (jnt_info[#] >> 14) & 0b01 = Joint #'s Error state (PS1 err)
            * (jnt_info[#] >> 15) & 0b01 = Joint #'s Error state (PS2 err)
            """
        @property
        def jnt_ref(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Reference (desired) joint position. (Unit: deg)
            
            0 = Base / 1 = Shoulder / 2 = Elbow / 3 = Wrist1 / 4 = Wrist2 / 5 = Wrist3
            """
        @property
        def jnt_temperature(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Measured temperature of each joint. (unit: celsius)
            
            0 = Base / 1 = Shoulder / 2 = Elbow / 3 = Wrist1 / 4 = Wrist2 / 5 = Wrist3
            """
        @property
        def op_stat_collision_occur(self) -> int:
            """
            Whether out-collision is detected (0 or 1)
            """
        @property
        def op_stat_ems_flag(self) -> int:
            """
            Software (kinematics) emergency stop situation
            
            0 = None / 1 = Arm Stretch / 2= Cartesian Limit / 3=Joint Limit / 4=Un-solvable
            """
        @property
        def op_stat_self_collision(self) -> int:
            """
            Whether self-collision is detected (0 or 1)
            """
        @property
        def op_stat_soft_estop_occur(self) -> int:
            """
            Pause state flag (0 or 1)
            """
        @property
        def op_stat_sos_flag(self) -> int:
            """
            Robot Arm device error code during operation.
            
            * 0 = None
            * 1 = Encoder err (PVL)
            * 2 = CPU err
            * 3 = Big err
            * 4 = Input err
            * 5 = JAM err
            * 6 = Over current err
            * 7 = Position bound err
            * 8 = Mode err
            * 9 = Match err
            * 10 = Over current/Low voltage err
            * 11 = Temperature err
            * 12 = Speed over err
            """
        @property
        def real_vs_simulation_mode(self) -> int:
            """
            Mode of operation: Simulation mode=1 / Real Robot mode=0
            """
        @property
        def reserved_1(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Reserved / Not used
            """
        @property
        def robot_state(self) -> int:
            """
            Move (motion) state
            
            * 1 = No motion command / Idle
            * 3 = Executing motion command(s)
            * 5 = No motion (Move) command + but executing Conveyor or Force control mode
            * 60+index = Under MovePB/ITPL/Pro command / index is passing waypoint number
            """
        @property
        def safety_board_stat_info(self) -> int:
            """
            Data chunk about the control box safety board
            """
        @property
        def task_pc(self) -> int:
            """
            Target program counter position during [STEP] function.
            """
        @property
        def task_repeat(self) -> int:
            """
            Target program execution number in [PLAY] page.
            """
        @property
        def task_run_id(self) -> int:
            """
            Running program counter position.
            """
        @property
        def task_run_num(self) -> int:
            """
            Current program execution number in [PLAY] page.
            """
        @property
        def task_run_time(self) -> int:
            """
            Time since the program started (unit: second)
            """
        @property
        def task_state(self) -> int:
            """
            Basic state of 'Program Execution'
            
            * 1 = Program not run / Idle
            * 3 = Program is running
            * 2 = Program is running + but ‘Paused’state
            """
        @property
        def tcp_pos(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            TCP posture info based on encoder-joint-angles (unit: mm & degree)
            
            0 = X / 1 = Y / 2 = Z / 3 = Rx / 4 = Ry / 5 = Rz
            
            Warning
            -------
            It is being transmitted overwritten based on the current reference.
            """
        @property
        def tcp_ref(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            TCP posture info based on reference-joint-angles (unit: mm & degree)
            
            0 = X / 1 = Y / 2 = Z / 3 = Rx / 4 = Ry / 5 = Rz
            """
        @property
        def tfb_analog_in(self) -> numpy.typing.NDArray[numpy.float32]:
            """
            Robot-Tool-Flange analog input measurement information of each channel (unit: Voltage)
            """
        @property
        def tfb_digital_in(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Robot-Tool-Flange digital input measurement information of each channel (value: 0 or 1)
            """
        @property
        def tfb_digital_out(self) -> numpy.typing.NDArray[numpy.int32]:
            """
            Robot-Tool-Flange digital output information of each channel (value: 0 or 1)
            """
        @property
        def tfb_voltage_out(self) -> float:
            """
            Robot-Tool-Flage output voltage level (unit: Voltage)
            """
        @property
        def time(self) -> float:
            """
            Basic timer. (Unit: sec)
            """
    @property
    def sdata(self) -> SystemState.Data:
        ...
class SystemVariable:
    """
    Members:
    
      SD_TIME
    
      SD_TIMER_0
    
      SD_TIMER_1
    
      SD_TIMER_2
    
      SD_TIMER_3
    
      SD_TIMER_4
    
      SD_TIMER_5
    
      SD_TIMER_6
    
      SD_TIMER_7
    
      SD_TIMER_8
    
      SD_TIMER_9
    
      SD_J0_REF
    
      SD_J1_REF
    
      SD_J2_REF
    
      SD_J3_REF
    
      SD_J4_REF
    
      SD_J5_REF
    
      SD_J0_ANG
    
      SD_J1_ANG
    
      SD_J2_ANG
    
      SD_J3_ANG
    
      SD_J4_ANG
    
      SD_J5_ANG
    
      SD_J0_VEL
    
      SD_J1_VEL
    
      SD_J2_VEL
    
      SD_J3_VEL
    
      SD_J4_VEL
    
      SD_J5_VEL
    
      SD_J0_CUR
    
      SD_J1_CUR
    
      SD_J2_CUR
    
      SD_J3_CUR
    
      SD_J4_CUR
    
      SD_J5_CUR
    
      SD_BEGIN_J0
    
      SD_BEGIN_J1
    
      SD_BEGIN_J2
    
      SD_BEGIN_J3
    
      SD_BEGIN_J4
    
      SD_BEGIN_J5
    
      SD_TEMPERATURE_MC0
    
      SD_TEMPERATURE_MC1
    
      SD_TEMPERATURE_MC2
    
      SD_TEMPERATURE_MC3
    
      SD_TEMPERATURE_MC4
    
      SD_TEMPERATURE_MC5
    
      SD_TCP_X
    
      SD_TCP_Y
    
      SD_TCP_Z
    
      SD_TCP_RX
    
      SD_TCP_RY
    
      SD_TCP_RZ
    
      SD_DEFAULT_SPEED
    
      SD_ROBOT_STATE
    
      SD_POWER_STATE
    
      SD_COLLISION_DETECT_STATE
    
      SD_IS_FREE_DRIVE_MODE
    
      SD_PG_MODE
    
      SD_INIT_STATE_INFO
    
      SD_INIT_ERR
    
      SD_TFB_ANALOG_IN_0
    
      SD_TFB_ANALOG_IN_1
    
      SD_TFB_DIGITAL_IN_0
    
      SD_TFB_DIGITAL_IN_1
    
      SD_TFB_DIGITAL_OUT_0
    
      SD_TFB_DIGITAL_OUT_1
    
      SD_TFB_VOLTAGE_OUT
    
      SD_OP_STAT_COLLISION_OCCUR
    
      SD_OP_STAT_SOS_FLAG
    
      SD_OP_STAT_SELF_COLLISION
    
      SD_OP_STAT_ESTOP_OCCUR
    
      SD_OP_STAT_EMS_FLAG
    
      SD_DIGITAL_IN_CONFIG_0
    
      SD_DIGITAL_IN_CONFIG_1
    
      SD_INBOX_TRAP_FLAG_0
    
      SD_INBOX_TRAP_FLAG_1
    
      SD_INBOX_CHECK_MODE_0
    
      SD_INBOX_CHECK_MODE_1
    
      SD_SOCK_IS_OPEN_0
    
      SD_SOCK_IS_OPEN_1
    
      SD_SOCK_IS_OPEN_2
    
      SD_SOCK_IS_OPEN_3
    
      SD_SOCK_IS_OPEN_4
    
      SD_SOCK_LAST_READ_0
    
      SD_SOCK_LAST_READ_1
    
      SD_SOCK_LAST_READ_2
    
      SD_SOCK_LAST_READ_3
    
      SD_SOCK_LAST_READ_4
    
      SD_HAND_TOKTOK
    
      SD_FINISH_AT_EVENT
    
      SD_TCP_VEL_REF
    
      SD_MOTION_TIME
    
      SD_ARM_POWER
    
      SD_IS_TPU_CONNECT
    
      SD_IS_RUN_IN_MAKE
    
      SD_IS_RUN_IN_PLAY
    
      SD_IS_INTENDED_STOP
    
      SD_MOVE_INDEX
    
      SD_MOVE_INDEX_F
    
      SD_MOVE_PROPERTY
    
      SD_CURRENT_DELTA
    
      SD_FORCE_TRAVEL_DIS
    
      SD_EMG_BUTTON_STATE
    
      SD_IS_IN_MAIN
    
      SD_IS_HOME
    
      SD_IS_BEGIN
    
      SD_ID_NUMBER
    
      SD_TF_LRF_DISTANCE
    
      SD_TF_LRF_QUALITY
    
      SD_BIT_0_3
    
      SD_BIT_4_7
    
      SD_BIT_8_11
    
      SD_BIT_12_15
    
      SD_BIT_0_7
    
      SD_BIT_0_11
    
      SD_BIT_0_15
    
      OR_2FG7_STATE
    
      OR_2FG7_POS_EXT
    
      OR_2FG7_POS_INT
    
      OR_2FG7_MIN_EXT
    
      OR_2FG7_MAX_EXT
    
      OR_2FG7_MIN_INT
    
      OR_2FG7_MAX_INT
    
      OR_RG_BUSY
    
      OR_RG_GRIP
    
      OR_RG_S1_PUSHED
    
      OR_RG_S1_TRIGGERED
    
      OR_RG_S2_PUSHED
    
      OR_RG_S2_TRIGGERED
    
      OR_RG_ERROR
    
      OR_RG_WIDTH
    
      OR_3FG_MIN_D
    
      OR_3FG_MAX_D
    
      OR_3FG_RAW_D
    
      OR_3FG_REAL_D
    
      OR_3FG_FORCE
    
      OR_3FG_BUSY
    
      OR_3FG_GRIP
    
      OR_3FG_FORCE_GRIP
    
      OR_3FG_CALIB
    
      OR_SD_STATUS
    
      OR_SD_WARNING
    
      OR_SD_RPM
    
      OR_SD_RPM_DEV
    
      OR_SD_VIBRATION
    
      OR_SD_ERROR
    
      OR_SD_RPM_TAR
    
      OR_SD_MOTOR_STOPPED
    
      OR_SD_MOTOR_RUNNING
    
      OR_SD_RAMP_UP
    
      OR_SD_RAMP_DW
    
      OR_SD_BUTTON
    
      OR_VG_A
    
      OR_VG_B
    
      OR_VGP20_A
    
      OR_VGP20_B
    
      OR_VGP20_C
    
      OR_VGP20_D
    
      OR_VGP20_A_GRIP
    
      OR_VGP20_A_RELEASE
    
      OR_VGP20_B_GRIP
    
      OR_VGP20_B_RELEASE
    
      OR_VGP20_C_GRIP
    
      OR_VGP20_C_RELEASE
    
      OR_VGP20_D_GRIP
    
      OR_VGP20_D_RELEASE
    
      OR_VGP20_BUSY
    
      OR_VGP20_ERROR
    
      OR_MG10_STATUS
    
      OR_MG10_ERROR
    
      OR_MG10_STRENGTH
    
      OR_SG_WIDTH
    
      OR_SG_MAX_WIDTH
    
      OR_SG_MIN_WIDTH
    
      OR_SG_STATUS
    
      OR_EYE_POS
    
      OR_EYE_ERROR
    
      OR_EYE_COUNT
    
      OR_EYE_INSPECT_RESULT
    
      OR_EYE_INSPECT_MATCH
    
      OR_EYE_X
    
      OR_EYE_Y
    
      OR_EYE_Z
    
      OR_EYE_RX
    
      OR_EYE_RY
    
      OR_EYE_RZ
    
      JRT_ENCODER
    
      JRT_JEGB
    
      JRT_JEGG
    
      PICKIT_POS
    
      RC_PICKIT_NO_COMMAND
    
      RC_PICKIT_CHECK_MODE
    
      RC_PICKIT_CAPTURE_IMAGE
    
      RC_PICKIT_PROCESS_IMAGE
    
      RC_PICKIT_LOOK_FOR_OBJECTS
    
      RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES
    
      RC_PICKIT_NEXT_OBJECT
    
      RC_PICKIT_GET_PICK_POINT_DATA
    
      RC_PICKIT_CONFIGURE
    
      RC_PICKIT_SET_CYLINDER_DIM
    
      RC_SAVE_ACTIVE_PRODUCT
    
      RC_SAVE_ACTIVE_SETUP
    
      RC_SAVE_BUILD_BACKGROUND
    
      RC_PICKIT_FIND_CALIB_PLATE
    
      RC_PICKIT_SAVE_SCENE
    
      PICKIT_STATUS
    
      PICKIT_VERSION
    
      PICKIT_ROBOTTYPE
    
      PICKIT_ROBOT_MODE
    
      PICKIT_IDLE_MODE
    
      PICKIT_OBJECT_FOUND
    
      PICKIT_NO_OBJECTS
    
      PICKIT_IMAGE_CAPTURED
    
      PICKIT_NO_IMAGE_CAPTURED
    
      PICKIT_EMPTY_ROI
    
      PICKIT_GET_PICK_POINT_DATA_OK
    
      PICKIT_GET_PICK_POINT_DATA_FAILED
    
      PICKIT_CONFIG_OK
    
      PICKIT_CONFIG_FAILED
    
      PICKIT_BUILD_BKG_CLOUD_OK
    
      PICKIT_BUILD_BKG_CLOUD_FAILED
    
      PICKIT_FIND_CALIB_PLATE_OK
    
      PICKIT_FIND_CALIB_PLATE_FAILED
    
      PICKIT_SAVE_SNAPSHOT_OK
    
      PICKIT_SAVE_SNAPSHOT_FAILED
    
      PICKIT_UNKNOWN_COMMAND
    
      PICKIT_TYPE_SQUARE
    
      PICKIT_TYPE_RECTANGLE
    
      PICKIT_TYPE_CIRCLE
    
      PICKIT_TYPE_ELLIPSE
    
      PICKIT_TYPE_CYLINDER
    
      PICKIT_TYPE_SPHERE
    
      PICKIT_TYPE_POINTCLOUD
    
      PICKIT_TYPE_BLOB
    
      PICKIT_X
    
      PICKIT_Y
    
      PICKIT_Z
    
      PICKIT_RX
    
      PICKIT_RY
    
      PICKIT_RZ
    
      PICKIT_P0
    
      PICKIT_P1
    
      PICKIT_P2
    
      PICKIT_P3
    
      PICKIT_P4
    
      PICKIT_P5
    
      PICKIT_P0F
    
      PICKIT_P1F
    
      PICKIT_P2F
    
      PICKIT_P3F
    
      PICKIT_P4F
    
      PICKIT_P5F
    
      PICKIT_M0
    
      PICKIT_M1
    
      ICE_INFO_CONNECTED
    
      ICE_INFO_REQUESTING
    
      ICE_INFO_USING
    
      ICE_INFO_VECSIZE
    
      ICE_INFO_MODE_COMM
    
      ICE_INFO_MODE_CUP
    
      ICE_INFO_TIME_ICE
    
      ICE_INFO_TIME_WATER
    
      ICE_INFO_AMBI_LOW
    
      ICE_INFO_AMBI_HIGH
    
      ICE_INFO_TMEP_AMBI
    
      ICE_INFO_TMEP_EVAPO
    
      ICE_INFO_TMEP_CONDEN
    
      ICE_STATE_LAST_ICE_NO
    
      ICE_STATE_LAST_ICE_YES
    
      ICE_STATE_COMP_WORK
    
      ICE_STATE_MOTOR_WORK
    
      ICE_STATE_OUT_SOL
    
      ICE_STATE_CUP_LEVEL
    
      ICE_STATE_COMM_MODE
    
      ICE_STATE_FULL_ICE
    
      ICE_STATE_ERR_1
    
      ICE_STATE_ERR_2
    
      ICE_STATE_ERR_3
    
      ICE_STATE_ERR_4
    
      ICE_STATE_ERR_CODE
    
      ICE_STATE_RD
    
      SETECH_RDY
    
      SETECH_ALM
    
      SETECH_BUSY
    
      SETECH_COMP
    
      SETECH_OK
    
      SETECH_NG_TRQH
    
      SETECH_NG_TRQL
    
      SETECH_NG_ANGH
    
      SETECH_NG_ANGL
    
      SETECH_NG_TIME
    
      SETECH_NG_MONI
    
      SETECH_NG_CH1
    
      SETECH_NG_CH2
    
      SETECH_NG_CH4
    
      SETECH_NG_CH8
    
      SETECH_NG_CH16
    
      SD_NO_ARC_STATE
    
      SD_DWELD_ARC
    
      SD_DWELD_TOUCH
    
      SD_DWELD_A
    
      SD_DWELD_V
    
      SD_DWELD_F
    
      SD_DWELD_SET_A
    
      SD_CONV_POS_TICK
    
      SD_CONV_VEL_TICK
    """
    ICE_INFO_AMBI_HIGH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_AMBI_HIGH: 264>
    ICE_INFO_AMBI_LOW: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_AMBI_LOW: 263>
    ICE_INFO_CONNECTED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_CONNECTED: 255>
    ICE_INFO_MODE_COMM: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_MODE_COMM: 259>
    ICE_INFO_MODE_CUP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_MODE_CUP: 260>
    ICE_INFO_REQUESTING: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_REQUESTING: 256>
    ICE_INFO_TIME_ICE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_TIME_ICE: 261>
    ICE_INFO_TIME_WATER: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_TIME_WATER: 262>
    ICE_INFO_TMEP_AMBI: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_TMEP_AMBI: 265>
    ICE_INFO_TMEP_CONDEN: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_TMEP_CONDEN: 267>
    ICE_INFO_TMEP_EVAPO: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_TMEP_EVAPO: 266>
    ICE_INFO_USING: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_USING: 257>
    ICE_INFO_VECSIZE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_INFO_VECSIZE: 258>
    ICE_STATE_COMM_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_COMM_MODE: 274>
    ICE_STATE_COMP_WORK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_COMP_WORK: 270>
    ICE_STATE_CUP_LEVEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_CUP_LEVEL: 273>
    ICE_STATE_ERR_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_ERR_1: 276>
    ICE_STATE_ERR_2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_ERR_2: 277>
    ICE_STATE_ERR_3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_ERR_3: 278>
    ICE_STATE_ERR_4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_ERR_4: 279>
    ICE_STATE_ERR_CODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_ERR_CODE: 280>
    ICE_STATE_FULL_ICE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_FULL_ICE: 275>
    ICE_STATE_LAST_ICE_NO: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_LAST_ICE_NO: 268>
    ICE_STATE_LAST_ICE_YES: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_LAST_ICE_YES: 269>
    ICE_STATE_MOTOR_WORK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_MOTOR_WORK: 271>
    ICE_STATE_OUT_SOL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_OUT_SOL: 272>
    ICE_STATE_RD: typing.ClassVar[SystemVariable]  # value = <SystemVariable.ICE_STATE_RD: 281>
    JRT_ENCODER: typing.ClassVar[SystemVariable]  # value = <SystemVariable.JRT_ENCODER: 187>
    JRT_JEGB: typing.ClassVar[SystemVariable]  # value = <SystemVariable.JRT_JEGB: 188>
    JRT_JEGG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.JRT_JEGG: 189>
    OR_2FG7_MAX_EXT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_MAX_EXT: 121>
    OR_2FG7_MAX_INT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_MAX_INT: 123>
    OR_2FG7_MIN_EXT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_MIN_EXT: 120>
    OR_2FG7_MIN_INT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_MIN_INT: 122>
    OR_2FG7_POS_EXT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_POS_EXT: 118>
    OR_2FG7_POS_INT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_POS_INT: 119>
    OR_2FG7_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_2FG7_STATE: 117>
    OR_3FG_BUSY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_BUSY: 137>
    OR_3FG_CALIB: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_CALIB: 140>
    OR_3FG_FORCE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_FORCE: 136>
    OR_3FG_FORCE_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_FORCE_GRIP: 139>
    OR_3FG_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_GRIP: 138>
    OR_3FG_MAX_D: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_MAX_D: 133>
    OR_3FG_MIN_D: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_MIN_D: 132>
    OR_3FG_RAW_D: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_RAW_D: 134>
    OR_3FG_REAL_D: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_3FG_REAL_D: 135>
    OR_EYE_COUNT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_COUNT: 178>
    OR_EYE_ERROR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_ERROR: 177>
    OR_EYE_INSPECT_MATCH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_INSPECT_MATCH: 180>
    OR_EYE_INSPECT_RESULT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_INSPECT_RESULT: 179>
    OR_EYE_POS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_POS: 176>
    OR_EYE_RX: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_RX: 184>
    OR_EYE_RY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_RY: 185>
    OR_EYE_RZ: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_RZ: 186>
    OR_EYE_X: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_X: 181>
    OR_EYE_Y: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_Y: 182>
    OR_EYE_Z: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_EYE_Z: 183>
    OR_MG10_ERROR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_MG10_ERROR: 170>
    OR_MG10_STATUS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_MG10_STATUS: 169>
    OR_MG10_STRENGTH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_MG10_STRENGTH: 171>
    OR_RG_BUSY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_BUSY: 124>
    OR_RG_ERROR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_ERROR: 130>
    OR_RG_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_GRIP: 125>
    OR_RG_S1_PUSHED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_S1_PUSHED: 126>
    OR_RG_S1_TRIGGERED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_S1_TRIGGERED: 127>
    OR_RG_S2_PUSHED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_S2_PUSHED: 128>
    OR_RG_S2_TRIGGERED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_S2_TRIGGERED: 129>
    OR_RG_WIDTH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_RG_WIDTH: 131>
    OR_SD_BUTTON: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_BUTTON: 152>
    OR_SD_ERROR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_ERROR: 146>
    OR_SD_MOTOR_RUNNING: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_MOTOR_RUNNING: 149>
    OR_SD_MOTOR_STOPPED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_MOTOR_STOPPED: 148>
    OR_SD_RAMP_DW: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_RAMP_DW: 151>
    OR_SD_RAMP_UP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_RAMP_UP: 150>
    OR_SD_RPM: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_RPM: 143>
    OR_SD_RPM_DEV: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_RPM_DEV: 144>
    OR_SD_RPM_TAR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_RPM_TAR: 147>
    OR_SD_STATUS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_STATUS: 141>
    OR_SD_VIBRATION: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_VIBRATION: 145>
    OR_SD_WARNING: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SD_WARNING: 142>
    OR_SG_MAX_WIDTH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SG_MAX_WIDTH: 173>
    OR_SG_MIN_WIDTH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SG_MIN_WIDTH: 174>
    OR_SG_STATUS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SG_STATUS: 175>
    OR_SG_WIDTH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_SG_WIDTH: 172>
    OR_VGP20_A: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_A: 155>
    OR_VGP20_A_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_A_GRIP: 159>
    OR_VGP20_A_RELEASE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_A_RELEASE: 160>
    OR_VGP20_B: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_B: 156>
    OR_VGP20_BUSY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_BUSY: 167>
    OR_VGP20_B_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_B_GRIP: 161>
    OR_VGP20_B_RELEASE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_B_RELEASE: 162>
    OR_VGP20_C: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_C: 157>
    OR_VGP20_C_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_C_GRIP: 163>
    OR_VGP20_C_RELEASE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_C_RELEASE: 164>
    OR_VGP20_D: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_D: 158>
    OR_VGP20_D_GRIP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_D_GRIP: 165>
    OR_VGP20_D_RELEASE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_D_RELEASE: 166>
    OR_VGP20_ERROR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VGP20_ERROR: 168>
    OR_VG_A: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VG_A: 153>
    OR_VG_B: typing.ClassVar[SystemVariable]  # value = <SystemVariable.OR_VG_B: 154>
    PICKIT_BUILD_BKG_CLOUD_FAILED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_BUILD_BKG_CLOUD_FAILED: 221>
    PICKIT_BUILD_BKG_CLOUD_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_BUILD_BKG_CLOUD_OK: 220>
    PICKIT_CONFIG_FAILED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_CONFIG_FAILED: 219>
    PICKIT_CONFIG_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_CONFIG_OK: 218>
    PICKIT_EMPTY_ROI: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_EMPTY_ROI: 215>
    PICKIT_FIND_CALIB_PLATE_FAILED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_FIND_CALIB_PLATE_FAILED: 223>
    PICKIT_FIND_CALIB_PLATE_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_FIND_CALIB_PLATE_OK: 222>
    PICKIT_GET_PICK_POINT_DATA_FAILED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_GET_PICK_POINT_DATA_FAILED: 217>
    PICKIT_GET_PICK_POINT_DATA_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_GET_PICK_POINT_DATA_OK: 216>
    PICKIT_IDLE_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_IDLE_MODE: 210>
    PICKIT_IMAGE_CAPTURED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_IMAGE_CAPTURED: 213>
    PICKIT_M0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_M0: 253>
    PICKIT_M1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_M1: 254>
    PICKIT_NO_IMAGE_CAPTURED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_NO_IMAGE_CAPTURED: 214>
    PICKIT_NO_OBJECTS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_NO_OBJECTS: 212>
    PICKIT_OBJECT_FOUND: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_OBJECT_FOUND: 211>
    PICKIT_P0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P0: 241>
    PICKIT_P0F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P0F: 247>
    PICKIT_P1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P1: 242>
    PICKIT_P1F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P1F: 248>
    PICKIT_P2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P2: 243>
    PICKIT_P2F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P2F: 249>
    PICKIT_P3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P3: 244>
    PICKIT_P3F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P3F: 250>
    PICKIT_P4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P4: 245>
    PICKIT_P4F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P4F: 251>
    PICKIT_P5: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P5: 246>
    PICKIT_P5F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_P5F: 252>
    PICKIT_POS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_POS: 190>
    PICKIT_ROBOTTYPE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_ROBOTTYPE: 208>
    PICKIT_ROBOT_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_ROBOT_MODE: 209>
    PICKIT_RX: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_RX: 238>
    PICKIT_RY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_RY: 239>
    PICKIT_RZ: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_RZ: 240>
    PICKIT_SAVE_SNAPSHOT_FAILED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_SAVE_SNAPSHOT_FAILED: 225>
    PICKIT_SAVE_SNAPSHOT_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_SAVE_SNAPSHOT_OK: 224>
    PICKIT_STATUS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_STATUS: 206>
    PICKIT_TYPE_BLOB: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_BLOB: 234>
    PICKIT_TYPE_CIRCLE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_CIRCLE: 229>
    PICKIT_TYPE_CYLINDER: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_CYLINDER: 231>
    PICKIT_TYPE_ELLIPSE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_ELLIPSE: 230>
    PICKIT_TYPE_POINTCLOUD: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_POINTCLOUD: 233>
    PICKIT_TYPE_RECTANGLE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_RECTANGLE: 228>
    PICKIT_TYPE_SPHERE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_SPHERE: 232>
    PICKIT_TYPE_SQUARE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_TYPE_SQUARE: 227>
    PICKIT_UNKNOWN_COMMAND: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_UNKNOWN_COMMAND: 226>
    PICKIT_VERSION: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_VERSION: 207>
    PICKIT_X: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_X: 235>
    PICKIT_Y: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_Y: 236>
    PICKIT_Z: typing.ClassVar[SystemVariable]  # value = <SystemVariable.PICKIT_Z: 237>
    RC_PICKIT_CAPTURE_IMAGE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_CAPTURE_IMAGE: 193>
    RC_PICKIT_CHECK_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_CHECK_MODE: 192>
    RC_PICKIT_CONFIGURE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_CONFIGURE: 199>
    RC_PICKIT_FIND_CALIB_PLATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_FIND_CALIB_PLATE: 204>
    RC_PICKIT_GET_PICK_POINT_DATA: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_GET_PICK_POINT_DATA: 198>
    RC_PICKIT_LOOK_FOR_OBJECTS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS: 195>
    RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES: 196>
    RC_PICKIT_NEXT_OBJECT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_NEXT_OBJECT: 197>
    RC_PICKIT_NO_COMMAND: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_NO_COMMAND: 191>
    RC_PICKIT_PROCESS_IMAGE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_PROCESS_IMAGE: 194>
    RC_PICKIT_SAVE_SCENE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_SAVE_SCENE: 205>
    RC_PICKIT_SET_CYLINDER_DIM: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_PICKIT_SET_CYLINDER_DIM: 200>
    RC_SAVE_ACTIVE_PRODUCT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_SAVE_ACTIVE_PRODUCT: 201>
    RC_SAVE_ACTIVE_SETUP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_SAVE_ACTIVE_SETUP: 202>
    RC_SAVE_BUILD_BACKGROUND: typing.ClassVar[SystemVariable]  # value = <SystemVariable.RC_SAVE_BUILD_BACKGROUND: 203>
    SD_ARM_POWER: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_ARM_POWER: 93>
    SD_BEGIN_J0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J0: 35>
    SD_BEGIN_J1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J1: 36>
    SD_BEGIN_J2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J2: 37>
    SD_BEGIN_J3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J3: 38>
    SD_BEGIN_J4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J4: 39>
    SD_BEGIN_J5: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BEGIN_J5: 40>
    SD_BIT_0_11: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_0_11: 115>
    SD_BIT_0_15: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_0_15: 116>
    SD_BIT_0_3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_0_3: 110>
    SD_BIT_0_7: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_0_7: 114>
    SD_BIT_12_15: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_12_15: 113>
    SD_BIT_4_7: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_4_7: 111>
    SD_BIT_8_11: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_BIT_8_11: 112>
    SD_COLLISION_DETECT_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_COLLISION_DETECT_STATE: 56>
    SD_CONV_POS_TICK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_CONV_POS_TICK: 305>
    SD_CONV_VEL_TICK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_CONV_VEL_TICK: 306>
    SD_CURRENT_DELTA: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_CURRENT_DELTA: 101>
    SD_DEFAULT_SPEED: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DEFAULT_SPEED: 53>
    SD_DIGITAL_IN_CONFIG_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DIGITAL_IN_CONFIG_0: 73>
    SD_DIGITAL_IN_CONFIG_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DIGITAL_IN_CONFIG_1: 74>
    SD_DWELD_A: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_A: 301>
    SD_DWELD_ARC: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_ARC: 299>
    SD_DWELD_F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_F: 303>
    SD_DWELD_SET_A: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_SET_A: 304>
    SD_DWELD_TOUCH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_TOUCH: 300>
    SD_DWELD_V: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_DWELD_V: 302>
    SD_EMG_BUTTON_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_EMG_BUTTON_STATE: 103>
    SD_FINISH_AT_EVENT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_FINISH_AT_EVENT: 90>
    SD_FORCE_TRAVEL_DIS: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_FORCE_TRAVEL_DIS: 102>
    SD_HAND_TOKTOK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_HAND_TOKTOK: 89>
    SD_ID_NUMBER: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_ID_NUMBER: 107>
    SD_INBOX_CHECK_MODE_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INBOX_CHECK_MODE_0: 77>
    SD_INBOX_CHECK_MODE_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INBOX_CHECK_MODE_1: 78>
    SD_INBOX_TRAP_FLAG_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INBOX_TRAP_FLAG_0: 75>
    SD_INBOX_TRAP_FLAG_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INBOX_TRAP_FLAG_1: 76>
    SD_INIT_ERR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INIT_ERR: 60>
    SD_INIT_STATE_INFO: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_INIT_STATE_INFO: 59>
    SD_IS_BEGIN: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_BEGIN: 106>
    SD_IS_FREE_DRIVE_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_FREE_DRIVE_MODE: 57>
    SD_IS_HOME: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_HOME: 105>
    SD_IS_INTENDED_STOP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_INTENDED_STOP: 97>
    SD_IS_IN_MAIN: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_IN_MAIN: 104>
    SD_IS_RUN_IN_MAKE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_RUN_IN_MAKE: 95>
    SD_IS_RUN_IN_PLAY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_RUN_IN_PLAY: 96>
    SD_IS_TPU_CONNECT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_IS_TPU_CONNECT: 94>
    SD_J0_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J0_ANG: 17>
    SD_J0_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J0_CUR: 29>
    SD_J0_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J0_REF: 11>
    SD_J0_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J0_VEL: 23>
    SD_J1_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J1_ANG: 18>
    SD_J1_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J1_CUR: 30>
    SD_J1_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J1_REF: 12>
    SD_J1_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J1_VEL: 24>
    SD_J2_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J2_ANG: 19>
    SD_J2_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J2_CUR: 31>
    SD_J2_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J2_REF: 13>
    SD_J2_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J2_VEL: 25>
    SD_J3_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J3_ANG: 20>
    SD_J3_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J3_CUR: 32>
    SD_J3_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J3_REF: 14>
    SD_J3_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J3_VEL: 26>
    SD_J4_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J4_ANG: 21>
    SD_J4_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J4_CUR: 33>
    SD_J4_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J4_REF: 15>
    SD_J4_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J4_VEL: 27>
    SD_J5_ANG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J5_ANG: 22>
    SD_J5_CUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J5_CUR: 34>
    SD_J5_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J5_REF: 16>
    SD_J5_VEL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_J5_VEL: 28>
    SD_MOTION_TIME: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_MOTION_TIME: 92>
    SD_MOVE_INDEX: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_MOVE_INDEX: 98>
    SD_MOVE_INDEX_F: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_MOVE_INDEX_F: 99>
    SD_MOVE_PROPERTY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_MOVE_PROPERTY: 100>
    SD_NO_ARC_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_NO_ARC_STATE: 298>
    SD_OP_STAT_COLLISION_OCCUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_OP_STAT_COLLISION_OCCUR: 68>
    SD_OP_STAT_EMS_FLAG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_OP_STAT_EMS_FLAG: 72>
    SD_OP_STAT_ESTOP_OCCUR: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_OP_STAT_ESTOP_OCCUR: 71>
    SD_OP_STAT_SELF_COLLISION: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_OP_STAT_SELF_COLLISION: 70>
    SD_OP_STAT_SOS_FLAG: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_OP_STAT_SOS_FLAG: 69>
    SD_PG_MODE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_PG_MODE: 58>
    SD_POWER_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_POWER_STATE: 55>
    SD_ROBOT_STATE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_ROBOT_STATE: 54>
    SD_SOCK_IS_OPEN_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_IS_OPEN_0: 79>
    SD_SOCK_IS_OPEN_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_IS_OPEN_1: 80>
    SD_SOCK_IS_OPEN_2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_IS_OPEN_2: 81>
    SD_SOCK_IS_OPEN_3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_IS_OPEN_3: 82>
    SD_SOCK_IS_OPEN_4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_IS_OPEN_4: 83>
    SD_SOCK_LAST_READ_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_LAST_READ_0: 84>
    SD_SOCK_LAST_READ_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_LAST_READ_1: 85>
    SD_SOCK_LAST_READ_2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_LAST_READ_2: 86>
    SD_SOCK_LAST_READ_3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_LAST_READ_3: 87>
    SD_SOCK_LAST_READ_4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_SOCK_LAST_READ_4: 88>
    SD_TCP_RX: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_RX: 50>
    SD_TCP_RY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_RY: 51>
    SD_TCP_RZ: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_RZ: 52>
    SD_TCP_VEL_REF: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_VEL_REF: 91>
    SD_TCP_X: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_X: 47>
    SD_TCP_Y: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_Y: 48>
    SD_TCP_Z: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TCP_Z: 49>
    SD_TEMPERATURE_MC0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC0: 41>
    SD_TEMPERATURE_MC1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC1: 42>
    SD_TEMPERATURE_MC2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC2: 43>
    SD_TEMPERATURE_MC3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC3: 44>
    SD_TEMPERATURE_MC4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC4: 45>
    SD_TEMPERATURE_MC5: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TEMPERATURE_MC5: 46>
    SD_TFB_ANALOG_IN_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_ANALOG_IN_0: 61>
    SD_TFB_ANALOG_IN_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_ANALOG_IN_1: 62>
    SD_TFB_DIGITAL_IN_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_DIGITAL_IN_0: 63>
    SD_TFB_DIGITAL_IN_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_DIGITAL_IN_1: 64>
    SD_TFB_DIGITAL_OUT_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_DIGITAL_OUT_0: 65>
    SD_TFB_DIGITAL_OUT_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_DIGITAL_OUT_1: 66>
    SD_TFB_VOLTAGE_OUT: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TFB_VOLTAGE_OUT: 67>
    SD_TF_LRF_DISTANCE: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TF_LRF_DISTANCE: 108>
    SD_TF_LRF_QUALITY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TF_LRF_QUALITY: 109>
    SD_TIME: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIME: 0>
    SD_TIMER_0: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_0: 1>
    SD_TIMER_1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_1: 2>
    SD_TIMER_2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_2: 3>
    SD_TIMER_3: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_3: 4>
    SD_TIMER_4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_4: 5>
    SD_TIMER_5: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_5: 6>
    SD_TIMER_6: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_6: 7>
    SD_TIMER_7: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_7: 8>
    SD_TIMER_8: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_8: 9>
    SD_TIMER_9: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SD_TIMER_9: 10>
    SETECH_ALM: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_ALM: 283>
    SETECH_BUSY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_BUSY: 284>
    SETECH_COMP: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_COMP: 285>
    SETECH_NG_ANGH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_ANGH: 289>
    SETECH_NG_ANGL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_ANGL: 290>
    SETECH_NG_CH1: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_CH1: 293>
    SETECH_NG_CH16: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_CH16: 297>
    SETECH_NG_CH2: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_CH2: 294>
    SETECH_NG_CH4: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_CH4: 295>
    SETECH_NG_CH8: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_CH8: 296>
    SETECH_NG_MONI: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_MONI: 292>
    SETECH_NG_TIME: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_TIME: 291>
    SETECH_NG_TRQH: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_TRQH: 287>
    SETECH_NG_TRQL: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_NG_TRQL: 288>
    SETECH_OK: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_OK: 286>
    SETECH_RDY: typing.ClassVar[SystemVariable]  # value = <SystemVariable.SETECH_RDY: 282>
    __members__: typing.ClassVar[dict[str, SystemVariable]]  # value = {'SD_TIME': <SystemVariable.SD_TIME: 0>, 'SD_TIMER_0': <SystemVariable.SD_TIMER_0: 1>, 'SD_TIMER_1': <SystemVariable.SD_TIMER_1: 2>, 'SD_TIMER_2': <SystemVariable.SD_TIMER_2: 3>, 'SD_TIMER_3': <SystemVariable.SD_TIMER_3: 4>, 'SD_TIMER_4': <SystemVariable.SD_TIMER_4: 5>, 'SD_TIMER_5': <SystemVariable.SD_TIMER_5: 6>, 'SD_TIMER_6': <SystemVariable.SD_TIMER_6: 7>, 'SD_TIMER_7': <SystemVariable.SD_TIMER_7: 8>, 'SD_TIMER_8': <SystemVariable.SD_TIMER_8: 9>, 'SD_TIMER_9': <SystemVariable.SD_TIMER_9: 10>, 'SD_J0_REF': <SystemVariable.SD_J0_REF: 11>, 'SD_J1_REF': <SystemVariable.SD_J1_REF: 12>, 'SD_J2_REF': <SystemVariable.SD_J2_REF: 13>, 'SD_J3_REF': <SystemVariable.SD_J3_REF: 14>, 'SD_J4_REF': <SystemVariable.SD_J4_REF: 15>, 'SD_J5_REF': <SystemVariable.SD_J5_REF: 16>, 'SD_J0_ANG': <SystemVariable.SD_J0_ANG: 17>, 'SD_J1_ANG': <SystemVariable.SD_J1_ANG: 18>, 'SD_J2_ANG': <SystemVariable.SD_J2_ANG: 19>, 'SD_J3_ANG': <SystemVariable.SD_J3_ANG: 20>, 'SD_J4_ANG': <SystemVariable.SD_J4_ANG: 21>, 'SD_J5_ANG': <SystemVariable.SD_J5_ANG: 22>, 'SD_J0_VEL': <SystemVariable.SD_J0_VEL: 23>, 'SD_J1_VEL': <SystemVariable.SD_J1_VEL: 24>, 'SD_J2_VEL': <SystemVariable.SD_J2_VEL: 25>, 'SD_J3_VEL': <SystemVariable.SD_J3_VEL: 26>, 'SD_J4_VEL': <SystemVariable.SD_J4_VEL: 27>, 'SD_J5_VEL': <SystemVariable.SD_J5_VEL: 28>, 'SD_J0_CUR': <SystemVariable.SD_J0_CUR: 29>, 'SD_J1_CUR': <SystemVariable.SD_J1_CUR: 30>, 'SD_J2_CUR': <SystemVariable.SD_J2_CUR: 31>, 'SD_J3_CUR': <SystemVariable.SD_J3_CUR: 32>, 'SD_J4_CUR': <SystemVariable.SD_J4_CUR: 33>, 'SD_J5_CUR': <SystemVariable.SD_J5_CUR: 34>, 'SD_BEGIN_J0': <SystemVariable.SD_BEGIN_J0: 35>, 'SD_BEGIN_J1': <SystemVariable.SD_BEGIN_J1: 36>, 'SD_BEGIN_J2': <SystemVariable.SD_BEGIN_J2: 37>, 'SD_BEGIN_J3': <SystemVariable.SD_BEGIN_J3: 38>, 'SD_BEGIN_J4': <SystemVariable.SD_BEGIN_J4: 39>, 'SD_BEGIN_J5': <SystemVariable.SD_BEGIN_J5: 40>, 'SD_TEMPERATURE_MC0': <SystemVariable.SD_TEMPERATURE_MC0: 41>, 'SD_TEMPERATURE_MC1': <SystemVariable.SD_TEMPERATURE_MC1: 42>, 'SD_TEMPERATURE_MC2': <SystemVariable.SD_TEMPERATURE_MC2: 43>, 'SD_TEMPERATURE_MC3': <SystemVariable.SD_TEMPERATURE_MC3: 44>, 'SD_TEMPERATURE_MC4': <SystemVariable.SD_TEMPERATURE_MC4: 45>, 'SD_TEMPERATURE_MC5': <SystemVariable.SD_TEMPERATURE_MC5: 46>, 'SD_TCP_X': <SystemVariable.SD_TCP_X: 47>, 'SD_TCP_Y': <SystemVariable.SD_TCP_Y: 48>, 'SD_TCP_Z': <SystemVariable.SD_TCP_Z: 49>, 'SD_TCP_RX': <SystemVariable.SD_TCP_RX: 50>, 'SD_TCP_RY': <SystemVariable.SD_TCP_RY: 51>, 'SD_TCP_RZ': <SystemVariable.SD_TCP_RZ: 52>, 'SD_DEFAULT_SPEED': <SystemVariable.SD_DEFAULT_SPEED: 53>, 'SD_ROBOT_STATE': <SystemVariable.SD_ROBOT_STATE: 54>, 'SD_POWER_STATE': <SystemVariable.SD_POWER_STATE: 55>, 'SD_COLLISION_DETECT_STATE': <SystemVariable.SD_COLLISION_DETECT_STATE: 56>, 'SD_IS_FREE_DRIVE_MODE': <SystemVariable.SD_IS_FREE_DRIVE_MODE: 57>, 'SD_PG_MODE': <SystemVariable.SD_PG_MODE: 58>, 'SD_INIT_STATE_INFO': <SystemVariable.SD_INIT_STATE_INFO: 59>, 'SD_INIT_ERR': <SystemVariable.SD_INIT_ERR: 60>, 'SD_TFB_ANALOG_IN_0': <SystemVariable.SD_TFB_ANALOG_IN_0: 61>, 'SD_TFB_ANALOG_IN_1': <SystemVariable.SD_TFB_ANALOG_IN_1: 62>, 'SD_TFB_DIGITAL_IN_0': <SystemVariable.SD_TFB_DIGITAL_IN_0: 63>, 'SD_TFB_DIGITAL_IN_1': <SystemVariable.SD_TFB_DIGITAL_IN_1: 64>, 'SD_TFB_DIGITAL_OUT_0': <SystemVariable.SD_TFB_DIGITAL_OUT_0: 65>, 'SD_TFB_DIGITAL_OUT_1': <SystemVariable.SD_TFB_DIGITAL_OUT_1: 66>, 'SD_TFB_VOLTAGE_OUT': <SystemVariable.SD_TFB_VOLTAGE_OUT: 67>, 'SD_OP_STAT_COLLISION_OCCUR': <SystemVariable.SD_OP_STAT_COLLISION_OCCUR: 68>, 'SD_OP_STAT_SOS_FLAG': <SystemVariable.SD_OP_STAT_SOS_FLAG: 69>, 'SD_OP_STAT_SELF_COLLISION': <SystemVariable.SD_OP_STAT_SELF_COLLISION: 70>, 'SD_OP_STAT_ESTOP_OCCUR': <SystemVariable.SD_OP_STAT_ESTOP_OCCUR: 71>, 'SD_OP_STAT_EMS_FLAG': <SystemVariable.SD_OP_STAT_EMS_FLAG: 72>, 'SD_DIGITAL_IN_CONFIG_0': <SystemVariable.SD_DIGITAL_IN_CONFIG_0: 73>, 'SD_DIGITAL_IN_CONFIG_1': <SystemVariable.SD_DIGITAL_IN_CONFIG_1: 74>, 'SD_INBOX_TRAP_FLAG_0': <SystemVariable.SD_INBOX_TRAP_FLAG_0: 75>, 'SD_INBOX_TRAP_FLAG_1': <SystemVariable.SD_INBOX_TRAP_FLAG_1: 76>, 'SD_INBOX_CHECK_MODE_0': <SystemVariable.SD_INBOX_CHECK_MODE_0: 77>, 'SD_INBOX_CHECK_MODE_1': <SystemVariable.SD_INBOX_CHECK_MODE_1: 78>, 'SD_SOCK_IS_OPEN_0': <SystemVariable.SD_SOCK_IS_OPEN_0: 79>, 'SD_SOCK_IS_OPEN_1': <SystemVariable.SD_SOCK_IS_OPEN_1: 80>, 'SD_SOCK_IS_OPEN_2': <SystemVariable.SD_SOCK_IS_OPEN_2: 81>, 'SD_SOCK_IS_OPEN_3': <SystemVariable.SD_SOCK_IS_OPEN_3: 82>, 'SD_SOCK_IS_OPEN_4': <SystemVariable.SD_SOCK_IS_OPEN_4: 83>, 'SD_SOCK_LAST_READ_0': <SystemVariable.SD_SOCK_LAST_READ_0: 84>, 'SD_SOCK_LAST_READ_1': <SystemVariable.SD_SOCK_LAST_READ_1: 85>, 'SD_SOCK_LAST_READ_2': <SystemVariable.SD_SOCK_LAST_READ_2: 86>, 'SD_SOCK_LAST_READ_3': <SystemVariable.SD_SOCK_LAST_READ_3: 87>, 'SD_SOCK_LAST_READ_4': <SystemVariable.SD_SOCK_LAST_READ_4: 88>, 'SD_HAND_TOKTOK': <SystemVariable.SD_HAND_TOKTOK: 89>, 'SD_FINISH_AT_EVENT': <SystemVariable.SD_FINISH_AT_EVENT: 90>, 'SD_TCP_VEL_REF': <SystemVariable.SD_TCP_VEL_REF: 91>, 'SD_MOTION_TIME': <SystemVariable.SD_MOTION_TIME: 92>, 'SD_ARM_POWER': <SystemVariable.SD_ARM_POWER: 93>, 'SD_IS_TPU_CONNECT': <SystemVariable.SD_IS_TPU_CONNECT: 94>, 'SD_IS_RUN_IN_MAKE': <SystemVariable.SD_IS_RUN_IN_MAKE: 95>, 'SD_IS_RUN_IN_PLAY': <SystemVariable.SD_IS_RUN_IN_PLAY: 96>, 'SD_IS_INTENDED_STOP': <SystemVariable.SD_IS_INTENDED_STOP: 97>, 'SD_MOVE_INDEX': <SystemVariable.SD_MOVE_INDEX: 98>, 'SD_MOVE_INDEX_F': <SystemVariable.SD_MOVE_INDEX_F: 99>, 'SD_MOVE_PROPERTY': <SystemVariable.SD_MOVE_PROPERTY: 100>, 'SD_CURRENT_DELTA': <SystemVariable.SD_CURRENT_DELTA: 101>, 'SD_FORCE_TRAVEL_DIS': <SystemVariable.SD_FORCE_TRAVEL_DIS: 102>, 'SD_EMG_BUTTON_STATE': <SystemVariable.SD_EMG_BUTTON_STATE: 103>, 'SD_IS_IN_MAIN': <SystemVariable.SD_IS_IN_MAIN: 104>, 'SD_IS_HOME': <SystemVariable.SD_IS_HOME: 105>, 'SD_IS_BEGIN': <SystemVariable.SD_IS_BEGIN: 106>, 'SD_ID_NUMBER': <SystemVariable.SD_ID_NUMBER: 107>, 'SD_TF_LRF_DISTANCE': <SystemVariable.SD_TF_LRF_DISTANCE: 108>, 'SD_TF_LRF_QUALITY': <SystemVariable.SD_TF_LRF_QUALITY: 109>, 'SD_BIT_0_3': <SystemVariable.SD_BIT_0_3: 110>, 'SD_BIT_4_7': <SystemVariable.SD_BIT_4_7: 111>, 'SD_BIT_8_11': <SystemVariable.SD_BIT_8_11: 112>, 'SD_BIT_12_15': <SystemVariable.SD_BIT_12_15: 113>, 'SD_BIT_0_7': <SystemVariable.SD_BIT_0_7: 114>, 'SD_BIT_0_11': <SystemVariable.SD_BIT_0_11: 115>, 'SD_BIT_0_15': <SystemVariable.SD_BIT_0_15: 116>, 'OR_2FG7_STATE': <SystemVariable.OR_2FG7_STATE: 117>, 'OR_2FG7_POS_EXT': <SystemVariable.OR_2FG7_POS_EXT: 118>, 'OR_2FG7_POS_INT': <SystemVariable.OR_2FG7_POS_INT: 119>, 'OR_2FG7_MIN_EXT': <SystemVariable.OR_2FG7_MIN_EXT: 120>, 'OR_2FG7_MAX_EXT': <SystemVariable.OR_2FG7_MAX_EXT: 121>, 'OR_2FG7_MIN_INT': <SystemVariable.OR_2FG7_MIN_INT: 122>, 'OR_2FG7_MAX_INT': <SystemVariable.OR_2FG7_MAX_INT: 123>, 'OR_RG_BUSY': <SystemVariable.OR_RG_BUSY: 124>, 'OR_RG_GRIP': <SystemVariable.OR_RG_GRIP: 125>, 'OR_RG_S1_PUSHED': <SystemVariable.OR_RG_S1_PUSHED: 126>, 'OR_RG_S1_TRIGGERED': <SystemVariable.OR_RG_S1_TRIGGERED: 127>, 'OR_RG_S2_PUSHED': <SystemVariable.OR_RG_S2_PUSHED: 128>, 'OR_RG_S2_TRIGGERED': <SystemVariable.OR_RG_S2_TRIGGERED: 129>, 'OR_RG_ERROR': <SystemVariable.OR_RG_ERROR: 130>, 'OR_RG_WIDTH': <SystemVariable.OR_RG_WIDTH: 131>, 'OR_3FG_MIN_D': <SystemVariable.OR_3FG_MIN_D: 132>, 'OR_3FG_MAX_D': <SystemVariable.OR_3FG_MAX_D: 133>, 'OR_3FG_RAW_D': <SystemVariable.OR_3FG_RAW_D: 134>, 'OR_3FG_REAL_D': <SystemVariable.OR_3FG_REAL_D: 135>, 'OR_3FG_FORCE': <SystemVariable.OR_3FG_FORCE: 136>, 'OR_3FG_BUSY': <SystemVariable.OR_3FG_BUSY: 137>, 'OR_3FG_GRIP': <SystemVariable.OR_3FG_GRIP: 138>, 'OR_3FG_FORCE_GRIP': <SystemVariable.OR_3FG_FORCE_GRIP: 139>, 'OR_3FG_CALIB': <SystemVariable.OR_3FG_CALIB: 140>, 'OR_SD_STATUS': <SystemVariable.OR_SD_STATUS: 141>, 'OR_SD_WARNING': <SystemVariable.OR_SD_WARNING: 142>, 'OR_SD_RPM': <SystemVariable.OR_SD_RPM: 143>, 'OR_SD_RPM_DEV': <SystemVariable.OR_SD_RPM_DEV: 144>, 'OR_SD_VIBRATION': <SystemVariable.OR_SD_VIBRATION: 145>, 'OR_SD_ERROR': <SystemVariable.OR_SD_ERROR: 146>, 'OR_SD_RPM_TAR': <SystemVariable.OR_SD_RPM_TAR: 147>, 'OR_SD_MOTOR_STOPPED': <SystemVariable.OR_SD_MOTOR_STOPPED: 148>, 'OR_SD_MOTOR_RUNNING': <SystemVariable.OR_SD_MOTOR_RUNNING: 149>, 'OR_SD_RAMP_UP': <SystemVariable.OR_SD_RAMP_UP: 150>, 'OR_SD_RAMP_DW': <SystemVariable.OR_SD_RAMP_DW: 151>, 'OR_SD_BUTTON': <SystemVariable.OR_SD_BUTTON: 152>, 'OR_VG_A': <SystemVariable.OR_VG_A: 153>, 'OR_VG_B': <SystemVariable.OR_VG_B: 154>, 'OR_VGP20_A': <SystemVariable.OR_VGP20_A: 155>, 'OR_VGP20_B': <SystemVariable.OR_VGP20_B: 156>, 'OR_VGP20_C': <SystemVariable.OR_VGP20_C: 157>, 'OR_VGP20_D': <SystemVariable.OR_VGP20_D: 158>, 'OR_VGP20_A_GRIP': <SystemVariable.OR_VGP20_A_GRIP: 159>, 'OR_VGP20_A_RELEASE': <SystemVariable.OR_VGP20_A_RELEASE: 160>, 'OR_VGP20_B_GRIP': <SystemVariable.OR_VGP20_B_GRIP: 161>, 'OR_VGP20_B_RELEASE': <SystemVariable.OR_VGP20_B_RELEASE: 162>, 'OR_VGP20_C_GRIP': <SystemVariable.OR_VGP20_C_GRIP: 163>, 'OR_VGP20_C_RELEASE': <SystemVariable.OR_VGP20_C_RELEASE: 164>, 'OR_VGP20_D_GRIP': <SystemVariable.OR_VGP20_D_GRIP: 165>, 'OR_VGP20_D_RELEASE': <SystemVariable.OR_VGP20_D_RELEASE: 166>, 'OR_VGP20_BUSY': <SystemVariable.OR_VGP20_BUSY: 167>, 'OR_VGP20_ERROR': <SystemVariable.OR_VGP20_ERROR: 168>, 'OR_MG10_STATUS': <SystemVariable.OR_MG10_STATUS: 169>, 'OR_MG10_ERROR': <SystemVariable.OR_MG10_ERROR: 170>, 'OR_MG10_STRENGTH': <SystemVariable.OR_MG10_STRENGTH: 171>, 'OR_SG_WIDTH': <SystemVariable.OR_SG_WIDTH: 172>, 'OR_SG_MAX_WIDTH': <SystemVariable.OR_SG_MAX_WIDTH: 173>, 'OR_SG_MIN_WIDTH': <SystemVariable.OR_SG_MIN_WIDTH: 174>, 'OR_SG_STATUS': <SystemVariable.OR_SG_STATUS: 175>, 'OR_EYE_POS': <SystemVariable.OR_EYE_POS: 176>, 'OR_EYE_ERROR': <SystemVariable.OR_EYE_ERROR: 177>, 'OR_EYE_COUNT': <SystemVariable.OR_EYE_COUNT: 178>, 'OR_EYE_INSPECT_RESULT': <SystemVariable.OR_EYE_INSPECT_RESULT: 179>, 'OR_EYE_INSPECT_MATCH': <SystemVariable.OR_EYE_INSPECT_MATCH: 180>, 'OR_EYE_X': <SystemVariable.OR_EYE_X: 181>, 'OR_EYE_Y': <SystemVariable.OR_EYE_Y: 182>, 'OR_EYE_Z': <SystemVariable.OR_EYE_Z: 183>, 'OR_EYE_RX': <SystemVariable.OR_EYE_RX: 184>, 'OR_EYE_RY': <SystemVariable.OR_EYE_RY: 185>, 'OR_EYE_RZ': <SystemVariable.OR_EYE_RZ: 186>, 'JRT_ENCODER': <SystemVariable.JRT_ENCODER: 187>, 'JRT_JEGB': <SystemVariable.JRT_JEGB: 188>, 'JRT_JEGG': <SystemVariable.JRT_JEGG: 189>, 'PICKIT_POS': <SystemVariable.PICKIT_POS: 190>, 'RC_PICKIT_NO_COMMAND': <SystemVariable.RC_PICKIT_NO_COMMAND: 191>, 'RC_PICKIT_CHECK_MODE': <SystemVariable.RC_PICKIT_CHECK_MODE: 192>, 'RC_PICKIT_CAPTURE_IMAGE': <SystemVariable.RC_PICKIT_CAPTURE_IMAGE: 193>, 'RC_PICKIT_PROCESS_IMAGE': <SystemVariable.RC_PICKIT_PROCESS_IMAGE: 194>, 'RC_PICKIT_LOOK_FOR_OBJECTS': <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS: 195>, 'RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES': <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES: 196>, 'RC_PICKIT_NEXT_OBJECT': <SystemVariable.RC_PICKIT_NEXT_OBJECT: 197>, 'RC_PICKIT_GET_PICK_POINT_DATA': <SystemVariable.RC_PICKIT_GET_PICK_POINT_DATA: 198>, 'RC_PICKIT_CONFIGURE': <SystemVariable.RC_PICKIT_CONFIGURE: 199>, 'RC_PICKIT_SET_CYLINDER_DIM': <SystemVariable.RC_PICKIT_SET_CYLINDER_DIM: 200>, 'RC_SAVE_ACTIVE_PRODUCT': <SystemVariable.RC_SAVE_ACTIVE_PRODUCT: 201>, 'RC_SAVE_ACTIVE_SETUP': <SystemVariable.RC_SAVE_ACTIVE_SETUP: 202>, 'RC_SAVE_BUILD_BACKGROUND': <SystemVariable.RC_SAVE_BUILD_BACKGROUND: 203>, 'RC_PICKIT_FIND_CALIB_PLATE': <SystemVariable.RC_PICKIT_FIND_CALIB_PLATE: 204>, 'RC_PICKIT_SAVE_SCENE': <SystemVariable.RC_PICKIT_SAVE_SCENE: 205>, 'PICKIT_STATUS': <SystemVariable.PICKIT_STATUS: 206>, 'PICKIT_VERSION': <SystemVariable.PICKIT_VERSION: 207>, 'PICKIT_ROBOTTYPE': <SystemVariable.PICKIT_ROBOTTYPE: 208>, 'PICKIT_ROBOT_MODE': <SystemVariable.PICKIT_ROBOT_MODE: 209>, 'PICKIT_IDLE_MODE': <SystemVariable.PICKIT_IDLE_MODE: 210>, 'PICKIT_OBJECT_FOUND': <SystemVariable.PICKIT_OBJECT_FOUND: 211>, 'PICKIT_NO_OBJECTS': <SystemVariable.PICKIT_NO_OBJECTS: 212>, 'PICKIT_IMAGE_CAPTURED': <SystemVariable.PICKIT_IMAGE_CAPTURED: 213>, 'PICKIT_NO_IMAGE_CAPTURED': <SystemVariable.PICKIT_NO_IMAGE_CAPTURED: 214>, 'PICKIT_EMPTY_ROI': <SystemVariable.PICKIT_EMPTY_ROI: 215>, 'PICKIT_GET_PICK_POINT_DATA_OK': <SystemVariable.PICKIT_GET_PICK_POINT_DATA_OK: 216>, 'PICKIT_GET_PICK_POINT_DATA_FAILED': <SystemVariable.PICKIT_GET_PICK_POINT_DATA_FAILED: 217>, 'PICKIT_CONFIG_OK': <SystemVariable.PICKIT_CONFIG_OK: 218>, 'PICKIT_CONFIG_FAILED': <SystemVariable.PICKIT_CONFIG_FAILED: 219>, 'PICKIT_BUILD_BKG_CLOUD_OK': <SystemVariable.PICKIT_BUILD_BKG_CLOUD_OK: 220>, 'PICKIT_BUILD_BKG_CLOUD_FAILED': <SystemVariable.PICKIT_BUILD_BKG_CLOUD_FAILED: 221>, 'PICKIT_FIND_CALIB_PLATE_OK': <SystemVariable.PICKIT_FIND_CALIB_PLATE_OK: 222>, 'PICKIT_FIND_CALIB_PLATE_FAILED': <SystemVariable.PICKIT_FIND_CALIB_PLATE_FAILED: 223>, 'PICKIT_SAVE_SNAPSHOT_OK': <SystemVariable.PICKIT_SAVE_SNAPSHOT_OK: 224>, 'PICKIT_SAVE_SNAPSHOT_FAILED': <SystemVariable.PICKIT_SAVE_SNAPSHOT_FAILED: 225>, 'PICKIT_UNKNOWN_COMMAND': <SystemVariable.PICKIT_UNKNOWN_COMMAND: 226>, 'PICKIT_TYPE_SQUARE': <SystemVariable.PICKIT_TYPE_SQUARE: 227>, 'PICKIT_TYPE_RECTANGLE': <SystemVariable.PICKIT_TYPE_RECTANGLE: 228>, 'PICKIT_TYPE_CIRCLE': <SystemVariable.PICKIT_TYPE_CIRCLE: 229>, 'PICKIT_TYPE_ELLIPSE': <SystemVariable.PICKIT_TYPE_ELLIPSE: 230>, 'PICKIT_TYPE_CYLINDER': <SystemVariable.PICKIT_TYPE_CYLINDER: 231>, 'PICKIT_TYPE_SPHERE': <SystemVariable.PICKIT_TYPE_SPHERE: 232>, 'PICKIT_TYPE_POINTCLOUD': <SystemVariable.PICKIT_TYPE_POINTCLOUD: 233>, 'PICKIT_TYPE_BLOB': <SystemVariable.PICKIT_TYPE_BLOB: 234>, 'PICKIT_X': <SystemVariable.PICKIT_X: 235>, 'PICKIT_Y': <SystemVariable.PICKIT_Y: 236>, 'PICKIT_Z': <SystemVariable.PICKIT_Z: 237>, 'PICKIT_RX': <SystemVariable.PICKIT_RX: 238>, 'PICKIT_RY': <SystemVariable.PICKIT_RY: 239>, 'PICKIT_RZ': <SystemVariable.PICKIT_RZ: 240>, 'PICKIT_P0': <SystemVariable.PICKIT_P0: 241>, 'PICKIT_P1': <SystemVariable.PICKIT_P1: 242>, 'PICKIT_P2': <SystemVariable.PICKIT_P2: 243>, 'PICKIT_P3': <SystemVariable.PICKIT_P3: 244>, 'PICKIT_P4': <SystemVariable.PICKIT_P4: 245>, 'PICKIT_P5': <SystemVariable.PICKIT_P5: 246>, 'PICKIT_P0F': <SystemVariable.PICKIT_P0F: 247>, 'PICKIT_P1F': <SystemVariable.PICKIT_P1F: 248>, 'PICKIT_P2F': <SystemVariable.PICKIT_P2F: 249>, 'PICKIT_P3F': <SystemVariable.PICKIT_P3F: 250>, 'PICKIT_P4F': <SystemVariable.PICKIT_P4F: 251>, 'PICKIT_P5F': <SystemVariable.PICKIT_P5F: 252>, 'PICKIT_M0': <SystemVariable.PICKIT_M0: 253>, 'PICKIT_M1': <SystemVariable.PICKIT_M1: 254>, 'ICE_INFO_CONNECTED': <SystemVariable.ICE_INFO_CONNECTED: 255>, 'ICE_INFO_REQUESTING': <SystemVariable.ICE_INFO_REQUESTING: 256>, 'ICE_INFO_USING': <SystemVariable.ICE_INFO_USING: 257>, 'ICE_INFO_VECSIZE': <SystemVariable.ICE_INFO_VECSIZE: 258>, 'ICE_INFO_MODE_COMM': <SystemVariable.ICE_INFO_MODE_COMM: 259>, 'ICE_INFO_MODE_CUP': <SystemVariable.ICE_INFO_MODE_CUP: 260>, 'ICE_INFO_TIME_ICE': <SystemVariable.ICE_INFO_TIME_ICE: 261>, 'ICE_INFO_TIME_WATER': <SystemVariable.ICE_INFO_TIME_WATER: 262>, 'ICE_INFO_AMBI_LOW': <SystemVariable.ICE_INFO_AMBI_LOW: 263>, 'ICE_INFO_AMBI_HIGH': <SystemVariable.ICE_INFO_AMBI_HIGH: 264>, 'ICE_INFO_TMEP_AMBI': <SystemVariable.ICE_INFO_TMEP_AMBI: 265>, 'ICE_INFO_TMEP_EVAPO': <SystemVariable.ICE_INFO_TMEP_EVAPO: 266>, 'ICE_INFO_TMEP_CONDEN': <SystemVariable.ICE_INFO_TMEP_CONDEN: 267>, 'ICE_STATE_LAST_ICE_NO': <SystemVariable.ICE_STATE_LAST_ICE_NO: 268>, 'ICE_STATE_LAST_ICE_YES': <SystemVariable.ICE_STATE_LAST_ICE_YES: 269>, 'ICE_STATE_COMP_WORK': <SystemVariable.ICE_STATE_COMP_WORK: 270>, 'ICE_STATE_MOTOR_WORK': <SystemVariable.ICE_STATE_MOTOR_WORK: 271>, 'ICE_STATE_OUT_SOL': <SystemVariable.ICE_STATE_OUT_SOL: 272>, 'ICE_STATE_CUP_LEVEL': <SystemVariable.ICE_STATE_CUP_LEVEL: 273>, 'ICE_STATE_COMM_MODE': <SystemVariable.ICE_STATE_COMM_MODE: 274>, 'ICE_STATE_FULL_ICE': <SystemVariable.ICE_STATE_FULL_ICE: 275>, 'ICE_STATE_ERR_1': <SystemVariable.ICE_STATE_ERR_1: 276>, 'ICE_STATE_ERR_2': <SystemVariable.ICE_STATE_ERR_2: 277>, 'ICE_STATE_ERR_3': <SystemVariable.ICE_STATE_ERR_3: 278>, 'ICE_STATE_ERR_4': <SystemVariable.ICE_STATE_ERR_4: 279>, 'ICE_STATE_ERR_CODE': <SystemVariable.ICE_STATE_ERR_CODE: 280>, 'ICE_STATE_RD': <SystemVariable.ICE_STATE_RD: 281>, 'SETECH_RDY': <SystemVariable.SETECH_RDY: 282>, 'SETECH_ALM': <SystemVariable.SETECH_ALM: 283>, 'SETECH_BUSY': <SystemVariable.SETECH_BUSY: 284>, 'SETECH_COMP': <SystemVariable.SETECH_COMP: 285>, 'SETECH_OK': <SystemVariable.SETECH_OK: 286>, 'SETECH_NG_TRQH': <SystemVariable.SETECH_NG_TRQH: 287>, 'SETECH_NG_TRQL': <SystemVariable.SETECH_NG_TRQL: 288>, 'SETECH_NG_ANGH': <SystemVariable.SETECH_NG_ANGH: 289>, 'SETECH_NG_ANGL': <SystemVariable.SETECH_NG_ANGL: 290>, 'SETECH_NG_TIME': <SystemVariable.SETECH_NG_TIME: 291>, 'SETECH_NG_MONI': <SystemVariable.SETECH_NG_MONI: 292>, 'SETECH_NG_CH1': <SystemVariable.SETECH_NG_CH1: 293>, 'SETECH_NG_CH2': <SystemVariable.SETECH_NG_CH2: 294>, 'SETECH_NG_CH4': <SystemVariable.SETECH_NG_CH4: 295>, 'SETECH_NG_CH8': <SystemVariable.SETECH_NG_CH8: 296>, 'SETECH_NG_CH16': <SystemVariable.SETECH_NG_CH16: 297>, 'SD_NO_ARC_STATE': <SystemVariable.SD_NO_ARC_STATE: 298>, 'SD_DWELD_ARC': <SystemVariable.SD_DWELD_ARC: 299>, 'SD_DWELD_TOUCH': <SystemVariable.SD_DWELD_TOUCH: 300>, 'SD_DWELD_A': <SystemVariable.SD_DWELD_A: 301>, 'SD_DWELD_V': <SystemVariable.SD_DWELD_V: 302>, 'SD_DWELD_F': <SystemVariable.SD_DWELD_F: 303>, 'SD_DWELD_SET_A': <SystemVariable.SD_DWELD_SET_A: 304>, 'SD_CONV_POS_TICK': <SystemVariable.SD_CONV_POS_TICK: 305>, 'SD_CONV_VEL_TICK': <SystemVariable.SD_CONV_VEL_TICK: 306>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: typing.SupportsInt) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: typing.SupportsInt) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
def to_string(type: Response.Type) -> str:
    ...
ErrorCodeMessage: dict  # value = {0: { "English": "Power Down Detected. Re-initialize the robot!", "Korean": "로봇 팔의 전원이 꺼졌습니다. 다시 사용하려면 활성화를 수행하세요." }, 1: { "English": "Too Fast motion for Conveyor tracking!", "Korean": "컨베이어 트래킹을 함께 수행하기에는 설정된 동작 속도가 너무 빠릅니다." }, 2: { "English": "Condition fail for TCP orientation auto-alignment", "Korean": "자동 TCP 회전 정렬 기능을 사용할 수 있는 범주가 아닙니다." }, 3: { "English": "Program is Stopped because of Collision-Detection", "Korean": "프로그램이 충돌감지로 인해 종료되었습니다." }, 4: { "English": "Weaving path calculation Fail (type: AMP)", "Korean": "위빙 연산 오류 (type: AMP)" }, 5: { "English": "Weaving path calculation Fail (type: VEL)", "Korean": "위빙 연산 오류 (type: VEL)" }, 6: { "English": "Weaving path calculation Fail (type: TPA)", "Korean": "위빙 연산 오류 (type: TPA)" }, 7: { "English": "Weaving path calculation Fail (type: DRG)", "Korean": "위빙 연산 오류 (type: DRG)" }, 8: { "English": "Weaving path calculation Fail (type: OFF)", "Korean": "위빙 연산 오류 (type: OFF)" }, 9: { "English": "Weaving path calculation Fail (type: SCA)", "Korean": "위빙 연산 오류 (type: SCA)" }, 10: { "English": "Weaving path calculation Fail (type: UND)", "Korean": "위빙 연산 오류 (type: UND)" }, 11: { "English": "Weaving Setting Error: Cannot run this Command", "Korean": "위빙 설정 오류 : 허용되지 않는 명령어 입니다." }, 12: { "English": "Weaving Setting Error: Out of bounds (amplitude)", "Korean": "위빙 설정 오류 : 진폭 설정이 허용 범위 밖 입니다." }, 13: { "English": "Weaving Setting Error: Out of bounds (velocity)", "Korean": "위빙 설정 오류 : 속도 설정이 허용 범위 밖 입니다." }, 14: { "English": "Weaving Setting Error: Out of bounds (time)", "Korean": "위빙 설정 오류 : 시간 설정이 허용 범위 밖 입니다." }, 15: { "English": "Weaving Setting Error: Out of bounds (distortion rate)", "Korean": "위빙 설정 오류 : 왜곡률 설정이 허용 범위 밖 입니다." }, 16: { "English": "Weaving Setting Error: Set-points are too close", "Korean": "위빙 설정 오류 : 두 셋 포인트가 너무 가깝습니다." }, 17: { "English": "Brake is opened. Check the selected joint is released !", "Korean": "브레이크가 해제되었습니다. 선택된 관절이 풀렸는지 확인하세요 !" }, 18: { "English": "Selected Joint is Initialized. Reboot All system !", "Korean": "선택된 관절 초기화를 수행하였습니다. 전체 시스템을 재부팅하세요 !" }, 19: { "English": "Jog Button Get Info Fail (Out of index bound)", "Korean": "조그버튼 설정 가져오기 실패 (범주를 넘었습니다)" }, 20: { "English": "Jog Button Set Info Fail (Out of bound)", "Korean": "조그버튼 설정 변경하기 실패 (범주를 넘었습니다)" }, 21: { "English": "Pattern internal count is over its bound", "Korean": "패턴 내부 카운트가 범주를 넘어갑니다." }, 22: { "English": "Control Box Files are copied into \n(TabletStorage/Android/data/com.rainbow.cobot/files/CopyFrom_ControlBox)", "Korean": "제어박스 내부 파일이 이 경로로 복사되었습니다. \n(TabletStorage/Android/data/com.rainbow.cobot/files/CopyFrom_ControlBox)" }, 23: { "English": "Software Update Fail (type 1)\nCheck whether the UI App program is full-version\nPlease try again", "Korean": "소프트웨어 업데이트 실패 (타입 1) \nUI프로그램이 정식버전 인지 확인하세요\n재시도를 권장합니다" }, 24: { "English": "Software Update Fail (type 2)\nInternal files copy failure\nPlease try again", "Korean": "소프트웨어 업데이트 실패 (타입 2) \n내부 파일복사 기능 문제 발생\n재시도를 권장합니다" }, 25: { "English": "Software Update Fail (type 1)\nFile system checking failure\nPlease try again", "Korean": "소프트웨어 업데이트 실패 (타입 3) \n시스템 파일 체크 문제 발생\n재시도를 권장합니다" }, 26: { "English": "Software Update Success !!!\nSystem will be re-boot automatically\nPlease Wait...", "Korean": "소프트웨어 업데이트가 정상적으로 끝났습니다 ! \n시스템이 자동으로 재시작됩니다 \nPlease Wait..." }, 27: { "English": "Saved motion called does not exist.", "Korean": "호출된 저장 모션이 존재하지 않습니다." }, 28: { "English": "Grammer Error : Recorded Path Run", "Korean": "문법오류 : 녹화 모션 재생" }, 29: { "English": "Selected Orientation option is not supported", "Korean": "지원하지 않는 회전 옵션 입니다." }, 30: { "English": "MoveJB Error : Command can not be executed", "Korean": "MoveJB 에러 : 명령어 수행 불가능 구간에서 동작이 호출됩니다." }, 31: { "English": "MoveJB Error : Too Low Point number", "Korean": "MoveJB 에러 : 동작을 수행하기에 불가능한 포인트 개수 입니다." }, 32: { "English": "MoveJB Error : Joint Limit over", "Korean": "MoveJB 에러 : 범주를 벗어나는 포인트가 존재합니다." }, 33: { "English": "MoveJB Error : Imposible to adjust Set-Offset", "Korean": "MoveJB 에러 : 오프셋 설정이 불가능한 점이 존재합니다." }, 34: { "English": "MoveJB Error : Too Low Acceleration is set", "Korean": "MoveJB 에러 : 너무 낮은 가속도가 설정되어 있습니다." }, 35: { "English": "MoveJB Error : N/D", "Korean": "MoveJB 에러 : 정의되지 않음" }, 36: { "English": "MoveJB Error : N/D", "Korean": "MoveJB 에러 : 정의되지 않음" }, 37: { "English": "MoveJB Error : N/D", "Korean": "MoveJB 에러 : 정의되지 않음" }, 38: { "English": "Joy-Stick is connected", "Korean": "조이스틱 연결에 성공하였습니다." }, 39: { "English": "Joy-Stick is not connected !!", "Korean": "조이스틱 연결에 실패하였습니다." }, 40: { "English": "Wrong Password !!!", "Korean": "잘못된 암호를 입력하였습니다." }, 41: { "English": "All Settings are initialized.\nRe-boot All systems", "Korean": "모든 설정이 초기화되었습니다.\n시스템을 재부팅하세요." }, 42: { "English": "Save Done !", "Korean": "저장이 완료되었습니다." }, 43: { "English": "Do previous procedure first !!!", "Korean": "앞선 과정을 먼저 수행해야 합니다." }, 44: { "English": "Calculation Error !!!", "Korean": "연산 오류가 발생하였습니다." }, 45: { "English": "Cannot run this command.\nOther motion or program is running!", "Korean": "명령어 수행이 불가합니다.\n동작 또는 프로그램이 실행중입니다." }, 46: { "English": "Robot is Activated !! \nDe-activate robot first.", "Korean": "로봇이 활성화되어 있습니다. \n로봇을 먼저 비활성화 (끄기)하고 이 명령을 수행하세요." }, 47: { "English": "Wrong BNO (Board Number) input !!!", "Korean": "잘못된 제어기 번호 입력입니다." }, 48: { "English": "Input Parameters are out-of bound !!!", "Korean": "입력된 파라미터가 지원 범주를 벗어납니다." }, 49: { "English": "CAN Data Read Time-out !!!", "Korean": "CAN 데이터 읽기 시간초과 오류" }, 50: { "English": "Wrong Model-Key number !!!", "Korean": "잘못된 모델 코드 번호를 넣었습니다." }, 51: { "English": "Control Gains are changed !!!\nPlease double check !!!!", "Korean": "제어 게인이 변경되었습니다.\n원하는 값으로 변경되었는지 꼭 재확인하세요 !!!" }, 52: { "English": "Exceeds the maximum number of Threads that can be supported.", "Korean": "지원 가능한 최대 Thread (쓰레드) 개수를 넘어 섭니다." }, 53: { "English": "SubProgram called too deeply !!!", "Korean": "서브 프로그램 (Sub.P)이 과도하게 다단계로 열렸습니다." }, 54: { "English": "SubProgram called too much !!!", "Korean": "서브 프로그램 (Sub.P)이 과도하게 많이 열렸습니다." }, 55: { "English": "Brake is opened & DQ alignment is performed.\nMake sure whether Brake is opend and DQ is well-aligned", "Korean": "브레이크가 열리고, DQ 정렬이 수행되었습니다.\n브레이크가 잘 열렸고, DQ 정렬이 잘 되었는지 확인하세요 !" }, 56: { "English": "DQ Save done !! \nMake sure whether DQ is well-aligned", "Korean": "DQ Save (DQ 저장 완료) \nDQ 정렬이 잘 되었는지 확인하세요 !" }, 57: { "English": "Current Sensor Nulling done :)", "Korean": "전류 센서 초기화 (nulling) 완료 :)" }, 58: { "English": "Control Box SMPS Error\nCheck cable connection\nFuse may have been disconnected.", "Korean": "제어박스 SMPS 오류\n선 연결 상태를 확인하세요.\n퓨즈가 나갔을 가능성이 있습니다." }, 59: { "English": "Control Box 48V Switch Error\nCheck whether the supplied 48V switch terminal block is connected.", "Korean": "제어박스 48V 스위치 오류\n제공되는 48V 스위치 단자대의 커넥터 여부를 확인하세요." }, 60: { "English": "Control Box GP Switch Error\nCheck Protective stop connector (Din16/17)", "Korean": "제어박스 디지털 인풋의 보호 정지 커넥터 (16/17포트) 를 확인하세요." }, 61: { "English": "Control Box Power-switching Error\nIf the problem persists, contact the manufacturer.", "Korean": "제어박스 내부 파워 스위칭 오류\n문제가 지속되면 제조사에 문의하세요." }, 62: { "English": "Control Box FET switching Error\nIf the problem persists, contact the manufacturer.", "Korean": "제어박스 내부 FET 스위치 오류\n문제가 지속되면 제조사에 문의하세요." }, 63: { "English": "Check EMG (EMO) Switch or Reset Switch status", "Korean": "비상 스위치 (EMO/EMG switch) 및 리셋 스위치를 확인하세요." }, 64: { "English": "Check Cable-connection (between Robot and ControlBox) status", "Korean": "제어박스와 로봇의 케이블 연결 여부를 다시 확인하세요." }, 65: { "English": "Robot Motor Controller connection check Fail", "Korean": "로봇 모터 제어기 연결 검사 오류" }, 66: { "English": "Robot Tool Flange Board (TFB) connection check Fail", "Korean": "로봇 툴 플랜지 보드 연결 검사 오류" }, 67: { "English": "Robot Tool Flange DAQ time out", "Korean": "로봇 툴 플랜지 데이터 연결 시간 초과" }, 68: { "English": "Control Box 48 SMPS Error\nCheck cable connection\nFuse may have been disconnected.", "Korean": "제어박스 48 SMPS 오류\n선 연결 상태를 확인하세요.\n퓨즈가 나갔을 가능성이 있습니다." }, 69: { "English": "Control Box 24 SMPS Error\nCheck cable connection\nFuse may have been disconnected.", "Korean": "제어박스 24 SMPS 오류\n선 연결 상태를 확인하세요.\n퓨즈가 나갔을 가능성이 있습니다." }, 70: { "English": "Control Box 12 SMPS Error\nCheck cable connection\nFuse may have been disconnected.", "Korean": "제어박스 12 SMPS 오류\n선 연결 상태를 확인하세요.\n퓨즈가 나갔을 가능성이 있습니다." }, 71: { "English": "Control Box 5 SMPS Error\nCheck cable connection\nFuse may have been disconnected.", "Korean": "제어박스 5 SMPS 오류\n선 연결 상태를 확인하세요.\n퓨즈가 나갔을 가능성이 있습니다." }, 72: { "English": "Control Box L2C Error\nCheck the LAN cable between the Control-PC and the communication-interface-board", "Korean": "제어박스 L2C 연결 오류\n제어 PC와 통신 인터페이스 사이 LAN 케이블을 확인하세요." }, 73: { "English": "Control Box SafetyMCU connection error\nContact the manufacturer", "Korean": "제어박스 SafetyMCU 연결 오류\n제조사에 문의하세요." }, 74: { "English": "Robot Arm motor Controller Protection: ID check error type 101", "Korean": "로봇 모터 제어기 보호정지: ID 오류 타입 101" }, 75: { "English": "Robot Arm motor Controller Protection: ID check error type 102", "Korean": "로봇 모터 제어기 보호정지: ID 오류 타입 102" }, 76: { "English": "Not supported Function", "Korean": "지원되지 않는 기능입니다." }, 77: { "English": "Not supported Function\nAvailable after Firmware upgrad\nContact the manufacturer", "Korean": "지원되지 않는 기능입니다.\n펌웨어 업그레이드를 통해 사용가능합니다.\n제조사에 문의하세요." }, 78: { "English": "Laser Range Finder data time out", "Korean": "Laser Range Finder 데이터 획득 시간 초가" }, 79: { "English": "Another special function already exists on the port for which you want to use the pulse function.", "Korean": "Pulse 기능을 사용하려는 포트에 다른 특수 기능이 이미 존재합니다." }, 80: { "English": "Wrong setting values are saved.\nContact the manufacturer", "Korean": "잘못된 세팅 값이 저장되어 있습니다.\n제조사를 연락하여 문제를 확인하세요." }, 81: { "English": "Collision detection motion setting : General stop", "Korean": "충돌 감지 동작 모드 : 일반 정지로 설정되어 있습니다." }, 82: { "English": "Collision detection motion setting : Evasion stop", "Korean": "충돌 감지 동작 모드 : 회피 정지로 설정되어 있습니다." }, 83: { "English": "Collision detection motion setting : N/A", "Korean": "충돌 감지 동작 모드 : N/A" }, 84: { "English": "Collision detection motion setting : N/A", "Korean": "충돌 감지 동작 모드 : N/A" }, 85: { "English": "RB5 Accuracy setting is changed\nRe-boot all system\nRe-make all motions !!!", "Korean": "RB5 정밀도 세팅이 변경되었습니다.\n시스템을 재부팅하세요\n모든 모션을 다시 만드세요." }, 86: { "English": "AutoCOG : External F/T sensor is not attached", "Korean": "자동COG : 외부 F/T센서가 부착되어 있지 않습니다." }, 87: { "English": "AutoCOG : Current posture is saved", "Korean": "자동COG : 현재 자세가 저장되었습니다." }, 88: { "English": "AutoCOG : More data should be saved", "Korean": "자동COG : 데이터 획득 개수가 부족합니다." }, 89: { "English": "AutoCOG : Fail to calculate-mounting angle is changed during DAQ", "Korean": "자동COG : 데이터 획득 중간에 센서 마운팅이 변경되어, 계산 불가능합니다." }, 90: { "English": "AutoCOG : Fail to calculate-sensor type is changed during DAQ", "Korean": "자동COG : 데이터 획득 중간에 센서 타입이 변경되어, 계산 불가능합니다." }, 91: { "English": "AutoCOG : N/A", "Korean": "자동COG : 정의되지 않음" }, 92: { "English": "AutoCOG : N/A", "Korean": "자동COG : 정의되지 않음" }, 93: { "English": "Robotiq FT : Try Nulling again about this axis !!!", "Korean": "Robotiq FT : 선택된 축에 대해서 다시 초기화 (Nulling)을 수행하세요." }, 94: { "English": "Robotiq FT : Ok- Nulling about selected axis", "Korean": "Robotiq FT : 선택된 축에 대해 초기화 (Nulling)을 수행하였습니다." }, 95: { "English": "Robotiq FT : FT300 is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "Robotiq FT : 외부 F/T센서로 Robotiq FT300이 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 96: { "English": "Robotiq FT : N/A", "Korean": "Robotiq FT : 정의되지 않음" }, 97: { "English": "Robotiq FT : N/A", "Korean": "Robotiq FT : 정의되지 않음" }, 98: { "English": "Robotiq FT : N/A", "Korean": "Robotiq FT : 정의되지 않음" }, 99: { "English": "Conveyor : Encoder data is not detected", "Korean": "Conveyor : 엔코더가 연결되어있지 않습니다." }, 100: { "English": "Conveyor : Direction (Axis) settings have problem", "Korean": "Conveyor : 방향 (축) 설정 값이 올바르지 않습니다." }, 101: { "English": "Conveyor : N/A", "Korean": "Conveyor : 정의되지 않음" }, 102: { "English": "Conveyor : N/A", "Korean": "Conveyor : 정의되지 않음" }, 103: { "English": "Conveyor : N/A", "Korean": "Conveyor : 정의되지 않음" }, 104: { "English": "Conveyor : N/A", "Korean": "Conveyor : 정의되지 않음" }, 105: { "English": "Conveyor : N/A", "Korean": "Conveyor : 정의되지 않음" }, 106: { "English": "EMS Status : Unsorvable posture\n- Inverse kinematics calculation is not possible at this point.\n- It may be too close to the singularity / dead zone.\n- The set speed/acceleration may be excessively fast.\n- Require to re-generate the motion to avoid this condition.", "Korean": "EMS 상태 : 연산 불가능 지점\n- 현재 지점은 역기구학 연산이 불가능합니다.\n- 특이점/데드존과 너무 가까운 자세일 수 있습니다.\n- 설정된 동작 속도가 과도하게 빠를 수 있습니다.\n- 이를 피하도록 동작을 재생성하세요." }, 107: { "English": "EMS Status : Inverse kinematics numeric error\n- Inverse kinematics calculation error during cartesian motion.\n- It may be too close to the singularity / dead zone.\n- The set speed/acceleration may be excessively fast.\n- Require to re-generate the motion to avoid this condition.", "Korean": "EMS 상태 : 기구학 연산 오류\n- 관성 좌표계 동작 도중 역기구학 연산 오류가 발생합니다.\n- 특이점/데드존과 너무 가까운 자세일 수 있습니다.\n- 설정된 동작 속도가 과도하게 빠를 수 있습니다.\n- 이를 피하도록 동작을 재생성하세요." }, 108: { "English": "EMS Status : Arm-strech condition\n- Cartesian motion reached out a limit of reachable workspace.\n- It may be too close to the singularity / dead zone.\n- Require to re-generate the motion to avoid this condition.", "Korean": "EMS 상태 : 작업 가능 영역을 벗어납니다.\n- 관성 좌표계 동작 도중 작업 가능 영역을 넘어섭니다.\n- 특이점/데드존과 너무 가까운 자세일 수 있습니다.\n- 이를 피하도록 동작을 재생성하세요." }, 109: { "English": "EMS Status: Joint angle limit over\n- Joint angle is over its limits", "Korean": "EMS 상태 : 관절 제한 범위 벗어남\n- 관절 각도가 제한 범위를 벗어납니다." }, 110: { "English": "EMS Status : N/A", "Korean": "EMS 상태 : N/A" }, 111: { "English": "EMS Status : N/A", "Korean": "EMS 상태 : N/A" }, 112: { "English": "EMS Status : N/A", "Korean": "EMS 상태 : N/A" }, 113: { "English": "EMS Status : N/A", "Korean": "EMS 상태 : N/A" }, 114: { "English": "EMS Status : N/A", "Korean": "EMS 상태 : N/A" }, 115: { "English": "Rainbow FT : HWSFT sensor is not connected", "Korean": "Rainbow FT :HWSFT 센서가 연결되어 있지 않습니다." }, 116: { "English": "Rainbow FT :HWSFT sensor nulling is done", "Korean": "Rainbow FT :HWSFT 센서 초기화 (Nulling)을 수행하였습니다." }, 117: { "English": "Rainbow FT : HWSFT is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "Rainbow FT : 외부 F/T센서로 HWSFT가 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 118: { "English": "Rainbow FT : N/A", "Korean": "Rainbow FT : 정의되지 않음" }, 119: { "English": "Rainbow FT : N/A", "Korean": "Rainbow FT : 정의되지 않음" }, 120: { "English": "Rainbow FT : N/A", "Korean": "Rainbow FT : 정의되지 않음" }, 121: { "English": "Motion Record : Recorindg done.\nPress Save button if you want to save this record.", "Korean": "모션 레코딩 : 녹화가 종료되었습니다.\n저장을 원할 시 아래 버튼을 누르세요." }, 122: { "English": "Motion Record : File save done :)", "Korean": "모션 레코딩 : 파일 저장이 완료되었습니다." }, 123: { "English": "Motion Record : Please enter file name", "Korean": "모션 레코딩 : 파일 이름을 입력해야 합니다." }, 124: { "English": "Motion Record : Maximum Record time (100 sec) over.", "Korean": "모션 레코딩 : 녹화 최대 시간 (100초)를 넘어섭니다." }, 125: { "English": "Motion Record : Start Recording", "Korean": "모션 레코딩 : 녹화를 시작합니다." }, 126: { "English": "Motion Record : N/A", "Korean": "모션 레코딩 : 정의되지 않음" }, 127: { "English": "Motion Record : N/A", "Korean": "모션 레코딩 : 정의되지 않음" }, 128: { "English": "Robot TCP has arrived at that location.", "Korean": "로봇 TCP가 해당 위치에 도착했습니다." }, 129: { "English": "Robot Joint angles have arrived at that location.", "Korean": "로봇 관절각도가 해당 위치에 도착했습니다." }, 130: { "English": "Too Long String !!", "Korean": "문자열 길이가 너무 깁니다 !!" }, 131: { "English": "Too Long Monitoring String !!", "Korean": "모니터링 문자열 길이가 너무 깁니다 !!" }, 132: { "English": "No Serial Communication Device !!", "Korean": "사용 가능한 시리얼 통신 장비가 없습니다 !!" }, 133: { "English": "Fail to get Begin Angles !! [NO FILE]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [NO FILE]" }, 134: { "English": "Fail to get Begin Angles !! [WRONG SIZE]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [WRONG TSIZE]" }, 135: { "English": "Fail to get Begin Angles !! [WRONG FORMAT]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [WRONG FORMAT]" }, 136: { "English": "Fail to get Begin Angles !! [CRASHED]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [CRASHED]" }, 137: { "English": "Fail to get Begin Angles !! [N/A]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [N/A]" }, 138: { "English": "Fail to get Begin Angles !! [N/A]", "Korean": "Begin (시작 위치) 각도 획득에 실패하였습니다 !! [N/A]" }, 139: { "English": "Fine Zero Point for selected joint is RESET !!!! \nTurn Off and On again the power to adjust new angle", "Korean": "선택된 관절의 0점을 새롭게 설정하였습니다.\n이를 시스템에 반영하려면 로봇팔을 반드시 껐다 켜야 합니다." }, 140: { "English": "Fine Zero Fail : Condition is not permitted", "Korean": "관절 0점 재설정이 가능한 조건이 아닙니다." }, 141: { "English": "Number of function parameter is wrong", "Korean": "함수의 입력 인자 개수가 잘못되었습니다." }, 142: { "English": "Force Control: Tracking value bound over", "Korean": "힘제어: 목표 값이 가능한 범주를 넘어갑니다." }, 143: { "English": "Force Control: Speed limit bound over", "Korean": "힘제어: 목표 속도 값이 가능한 범주를 넘어갑니다." }, 144: { "English": "Force Control: Sensor is not detected", "Korean": "힘제어: 선택한 센서가 연결되지 않았습니다." }, 145: { "English": "Force Control: Wrong sensor selection", "Korean": "힘제어: 지원하지 않는 장비가 선택되었습니다." }, 146: { "English": "Force Control: Wrong frame selection", "Korean": "힘제어: 프레임 선택이 잘못되었습니다." }, 147: { "English": "Force Control: Cannot run this mode in Singular point", "Korean": "힘제어: 특이점 영역에서는 힘제어가 불가능 합니다." }, 148: { "English": "Force Control: N/A", "Korean": "힘제어: 정의되지 않음" }, 149: { "English": "Force Control: N/A", "Korean": "힘제어: 정의되지 않음" }, 150: { "English": "This command cannot be used when both analog and digital welding machines are set.", "Korean": "아날로그 용접기와 디지털 용접기가 모두 설정되어 있는 상태에서는 이 명령어 사용이 불가능 합니다." }, 151: { "English": "Direct Teaching: Cannot run this function", "Korean": "직접교시: 이 기능을 수행할 수 있는 환경 및 조건이 아닙니다." }, 152: { "English": "Arc: Time-out about the input signal checking", "Korean": "아크: 아크 발생 입력 신호 대시 시간 초과" }, 153: { "English": "Arc: Input value exceeds the setting boundary defined in Setup/Device.", "Korean": "아크: 입력 값이 Setup-Device의 설정 범주를 넘어 갑니다." }, 154: { "English": "Arc: Analog welding machine setting is not set in Setup/Device.", "Korean": "아크: Setup에서 아날로그 용접기 설정이되어 있지 않습니다." }, 155: { "English": "Arc: Wrong Time parameter", "Korean": "아크: 시간 설정이 잘못되었습니다." }, 156: { "English": "Arc: Initialization failure code appears in the control box voltage generator (DAC).", "Korean": "아크: 제어박스 전압 생성기 (DAC)에서 초기화 실패 코드가 나타납니다." }, 157: { "English": "You cannot put the same value for wire forward port and reverse port number.", "Korean": "와이어 전진 포트와 후진 포트 번호에 같은 값을 넣을 수 없습니다." }, 158: { "English": "The signal port for the selected wire control command is not set.", "Korean": "선택된 와이어 조작 명령에 대한 신호 포트가 설정되어있지 않습니다." }, 159: { "English": "Robotus FT : RFT806A is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "Robotus FT : 외부 F/T센서로 RFT806A 가 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 160: { "English": "Check whether the selected F/T sensor is connected", "Korean": "선택된 F/T 센서 연결 여부를 확인하세요." }, 161: { "English": "AutoTcp: Calculation Done. Check the calculated values !", "Korean": "AutoTcp: 계산이 완료되었습니다. 설정된 값을 재확인 하세요." }, 162: { "English": "AutoTcp: Fail to calculate TCP! Check follows:\nYou shouldn't have the same posture out of the 4 setup postures.\nOf the four setting postures, there should be no postures near the singularity/dead zone.", "Korean": "AutoTCP: 계산에 실패하였습니다. 다음과 같은 가능성을 확인하세요.\n4가지 설정 자세 중 같은 자세가 있으면 안됩니다.\n4가지 설정 자세 중 특이점/데드존 근처 자세가 있으면 안됩니다." }, 163: { "English": "TCP info change fail : TCP information changes are called at the same time.\nCheck the program architecture.", "Korean": "TCP 정보 변경 실패 : TCP 정보 변경이 동시에 일어납니다.\n프로그램 구조를 확인하세요." }, 164: { "English": "TCP info change fail : TCP information changes are called during the motion.\nCheck the program architecture.", "Korean": "TCP 정보 변경 실패 : 동작 중에 TCP 정보 변경이 일어납니다.\n프로그램 구조를 확인하세요." }, 165: { "English": "TCP info change fail : No matching data in Tool-List", "Korean": "TCP 정보 변경 실패 : 툴 리스트에 존재하지 않는 번호 입력입니다." }, 166: { "English": "TCP info change fail : Over payload (mass) input", "Korean": "TCP 정보 변경 실패 : 페이로드 (질량) 설정이 지원 범주를 넘어갑니다." }, 167: { "English": "TCP info change fail : Input parameter(s) is over its bound", "Korean": "TCP 정보 변경 실패 : 입력 값이 지원 범주를 넘어 갑니다." }, 168: { "English": "Bit Combination : Un-available port number is entered", "Korean": "비트조합 : 포트 번호가 사용 가능 범주를 벗어납니다." }, 169: { "English": "Bit Combination : End-port number must not be less than the Start-port number.", "Korean": "비트조합 : 마지막 포트 번호가 시작 포트 보다 작으면 안됩니다." }, 170: { "English": "Bit Combination : Target value should be positive number (or zero).", "Korean": "비트조합 : 입력된 값은 양수 값이 들어가야 합니다." }, 171: { "English": "Bit Combination : A value exceeded the possible range for the port combination.", "Korean": "비트조합 : 포트 조합으로 가능한 범주 이상의 값이 입력되었습니다." }, 172: { "English": "Bit Combination : One or more ports in the port range are already set as special function(s)", "Korean": "비트조합 : 포트 범위 중 하나 이상의 포트가 특수 기능으로 이미 설정되어 있습니다." }, 173: { "English": "Signal Toggle : Wrong command input", "Korean": "신호토글 : 잘못된 명령어 입력입니다." }, 174: { "English": "Signal Toggle : One or more ports you selected are already set as special function(s)", "Korean": "신호토글 : 선택된 포트에 특수 기능이 설정되어 있습니다." }, 175: { "English": "Unit Pulse : Un-available port number is entered", "Korean": "단위펄스 : 포트 번호가 사용 가능 범주를 벗어납니다." }, 176: { "English": "Unit Pulse : One or more ports you selected are already set as special function(s)", "Korean": "단위펄스 : 선택된 포트에 특수 기능이 설정되어 있습니다." }, 177: { "English": "Unit Pulse : Wrong command input", "Korean": "단위펄스 : 잘못된 명령어 입력입니다." }, 178: { "English": "Unit Pulse : Time parameter should be in 0~2 second range", "Korean": "단위펄스 : 시간 파라미터는 0~2 초 사이 값만 가능합니다." }, 179: { "English": "Name/String length exceeds the supported range. Or too short.", "Korean": "이름/문자열의 길이가 지원 범주를 넘어섭니다. 또는 너무 짧습니다." }, 180: { "English": "Name/String contains special characters/spaces that are not allowed.", "Korean": "이름/문자열에 사용 불가능한 특수 문자 / 공백이 포함되어 있습니다." }, 181: { "English": "This setting cannot be changed during program/robot operation.", "Korean": "해당 설정은 프로그램/로봇 운용 중에 바꾸지 못합니다." }, 182: { "English": "Communication Err : Robot internal communication or Motor controller can be damaged", "Korean": "통신에러 : 로봇 내부 통신 에러 또는 모터 제어기 에러가 의심됩니다.\n시스템을 전체 재부팅하세요." }, 183: { "English": "Communication Err : Check the I/O-Extention Board Connection", "Korean": "통신에러 : 확장 I/O 보드 연결을 확인하세요." }, 184: { "English": "Fail to get Loaded project file information", "Korean": "제어박스 프로젝트 정보 획득에 실패하였습니다." }, 185: { "English": "Program playback has been stopped.\n- The length of the program currently loaded in the'Control box' is too short.\n- Check if the desired program is correctly loaded in the'Control box'.", "Korean": "프로그램 재생을 중단하였습니다.\n- 현재 '제어 박스'에 로딩된 프로그램 길이가 너무 짧습니다.\n- 원하는 프로그램이 정확히 '제어 박스'에도 로드 되었는지 확인하세요." }, 186: { "English": "Real/Simulation Mode conversion Fail !\n- Fail to convert operation mode. Check the system operating status.\n- 'Real Mode' is only available when the robot arm is activated.", "Korean": "리얼/시뮬레이션 모드 전환 실패!\n- 운용 모드 전환에 실패하였습니다. 시스템의 운용상태를 점검하세요.\n- '리얼 모드'는 로봇 팔이 활성화되었을 때만 사용 가능합니다." }, 187: { "English": "Failed to load the program through digital input.\nThe load is not possible now (robot is operating, executing program, etc.).", "Korean": "디지털 입력을 통해서 프로그램 로드에 실패하였습니다.\n로드가 불가능한 상태 (동작 중, 프로그램 실행 중, 등)입니다." }, 188: { "English": "The program is loaded into the Control box via digital input.\nIt may not match the program loaded on the tablet Ui.", "Korean": "디지털 입력을 통해서 프로그램이 제어박스에 로드되었습니다.\n태블릿 Ui에 로드된 프로그램과 일치하지 않을 수 있습니다." }, 189: { "English": "Failure to reach the motion time constraint!\nDesired motion cannot be performed within the set time duration.\nYou need to increase the time or increase velocity / acceleration.", "Korean": "동작 시간 구속 조건 도달 실패 !\n설정된 시간 안에 해당 동작 수행이 불가능 합니다.\n시간을 늘려주거나 속도 또는 가속도를 높여야 합니다." }, 190: { "English": "This is a beta version feature. This feature is currently not available.", "Korean": "베타 버전 기능입니다. 이 기능은 현재 사용 불가능합니다." }, 191: { "English": "MU-offset value of the selected joint is re-set !!!. Whole system reboot is required for the robot arm activation.", "Korean": "선택된 관절의 MU 오프셋이 재-조정 되었습니다. 활성화를 진행하려면, 시스템 전체를 재부팅해야 합니다." }, 192: { "English": "Touch Sensing: Configured searching-speed is too fast.", "Korean": "터치센싱: 설정된 탐색 속도가 너무 빠릅니다." }, 193: { "English": "Touch Sensing: Configured searching-acceleration is too low.", "Korean": "터치센싱: 설정된 탐색 가속도가 너무 낮습니다." }, 194: { "English": "Touch Sensing: Configured searching-distance is too short or long.", "Korean": "터치센싱: 설정된 탐색 거리가 너무 짧거나 깁니다." }, 195: { "English": "Touch Sensing: Some of configuration points are too close.", "Korean": "터치센싱: 일부 설정 지점이 너무 가깝습니다." }, 196: { "English": "Touch Sensing: Check the outer/perpendicular point setting", "Korean": "터치센싱: 수직 점 설정을 확인하세요." }, 197: { "English": "Touch Sensing: Other motion or program is executing.", "Korean": "터치센싱: 다른 동작 명령이 수행 중 입니다." }, 198: { "English": "Touch Sensing: Searching should be start at the searching-start-position.", "Korean": "터치센싱: 탐색은 시작은, 설정된 탐색 시작 지점에서 시작해야 합니다." }, 199: { "English": "Touch Sensing: Sensor signal is detected. 'Get' the current posture information.", "Korean": "터치센싱: 센서 감지가 되었습니다. 가져오기를 통해서 현재 지점 정보를 획득하세요." }, 200: { "English": "Touch Sensing: Sensor signal is not detected during the searching process.", "Korean": "터치센싱: 탐색 중 센서가 감지되지 않았습니다." }, 201: { "English": "Touch Sensing: To use this function, the 'Touch-sensing configuration' has to be prioritized.", "Korean": "터치센싱: 이 기능을 사용하려면, 설정이 우선되어야 합니다." }, 202: { "English": "Touch Sensing: To use this function, the 'Touch-sensing configuration & Search' have to be prioritized.", "Korean": "터치센싱: 이 기능을 사용하려면, 설정 후 탐색이 우선되어야 합니다." }, 203: { "English": "Touch Sensing: Object movement is detected larger than the specified range.", "Korean": "터치센싱: 지정된 범위 보다 크게 대상물 움직임이 감지됩니다." }, 204: { "English": "Direct-Teaching Mode: This function is only available at Real-Robot mode", "Korean": "직접교시모드: 해당 기능은 Real-Robot 모드에서만 사용가능합니다." }, 205: { "English": "Direct-Teaching Mode: This function is for the program execution section. It is not available in the current state.", "Korean": "직접교시모드: 이 기능은 프로그램 실행 구간을 위한 기능입니다. 현 상태에서 사용 불가능합니다." }, 206: { "English": "Direct-Teaching Mode: Currently, Direct teaching mode is not available. (Robot arm is not activated or executing another command)", "Korean": "직접교시모드: 현재 직접 교시를 할 수 없는 상태 입니다. (로봇 팔 비활성화 상태 또는 다른 명령어 수행 중)" }, 207: { "English": "Direct-Teaching Mode: This function (resume or halt) cannot be performed before exiting the Direct-Teaching mode.", "Korean": "직접교시모드: 직접 교시 모드를 끝내기 전에 이 기능을 수행할 수 없습니다." }, 208: { "English": "Functions that cannot be used in the Thread (Parallel-Program) section are called.", "Korean": "쓰레드 (병렬 프로그램) 구간에서는 사용할 수 없는 기능이 호출됩니다." }, 209: { "English": "G code: Selected user coordinate system number is out of range.", "Korean": "G코드: 선택된 사용자 좌표계 번호가 지원 범위를 넘어섭니다." }, 210: { "English": "G code: Entered speed value exceeds the maximum.", "Korean": "G코드: 입력된 속도 값이 최대치를 넘어섭니다." }, 211: { "English": "G code: Selected initial plane type is out of range.", "Korean": "G코드: 선택된 시작 평면 선택 옵션이 지원 범위를 넘어섭니다." }, 212: { "English": "G code: Selected file-format is not supporting.", "Korean": "G코드: 선택된 파일 형식은 지원하지 않습니다." }, 213: { "English": "G code: Cannot run this function in non-program execution state.", "Korean": "G코드: 실행 불가능한 상태에서 이 함수가 호출됩니다." }, 214: { "English": "G code: Other motion or command is executing.", "Korean": "G코드: 다른 동작이 이미 수행 중 입니다." }, 215: { "English": "G code: Entered code file does not exist.", "Korean": "G코드: 입력된 코드 파일이 존재하지 않습니다." }, 216: { "English": "G code: Number of lines (blocks) is less than or equal to zero.", "Korean": "G코드: 라인(블럭) 개수가 0보다 같거나 작습니다." }, 217: { "English": "G code: Entered offset values are out of ranges.", "Korean": "G코드: 입력된 오프셋 값이 지원 범주를 벗어납니다." }, 218: { "English": "G code: It contains a G code format that is not supported.", "Korean": "G코드: 지원하지 않는 G코드 형식이 포함되어 있습니다." }, 219: { "English": "G code: There is an instruction part (Chunk) that is not supported.", "Korean": "G코드: 지원하지 않는 명령어 파트 (Chunk)가 존재합니다." }, 220: { "English": "G code: There is a problem performing the robot motion. It may contain unsupported grammar.", "Korean": "G코드: 동작 수행에 문제가 발생합니다. 지원되지 않는 문법이 포함되어 있을 수 있습니다." }, 221: { "English": "G code: Dummy", "Korean": "G코드: 더미" }, 222: { "English": "Safety Parameter: Save Done...!!!\nPlease double check these parameters!!", "Korean": "Safety 파라미터: 저장이 완료되었습니다.\n가져오기를 한 번 더 해서 이중 체크를 하세요!" }, 223: { "English": "Safety Parameter: Save Fail ...!!\nCross-checking process with SF board is fail ...!!!", "Korean": "Safety 파라미터: 저장에 실패하였습니다.\nSafety Board와 이중 체크에 실패하였습니다." }, 224: { "English": "Safety Parameter: Save Fail ...!!\nSome input parameter is over its bound.", "Korean": "Safety 파라미터: 저장에 실패하였습니다.\n입력한 파라미터가 설정 가능한 범주를 넘거나, 부호가 올바르지 않습니다." }, 225: { "English": "Safety Parameter: Saved parameters are updated in UI.", "Korean": "Safety 파라미터: 저장된 데이터를 불러왔습니다." }, 226: { "English": "Digital Welding: Welding Machine is not selected.<br>Select the welder in Setup menu.", "Korean": "디지털용접: 용접기가 선택되지 않았습니다.<br>Setup에서 용접기를 선택하세요." }, 227: { "English": "Digital Welding: Welder information in Setup and Command is not matching...!!!", "Korean": "디지털용접: Setup에 선택된 용접기 정보와 명령어로 선택된 용접기가 일치하지 않습니다." }, 228: { "English": "Digital Welding: Sync between welder and robot control box is not done.", "Korean": "디지털용접: 용접기와 로봇 제어박스가 동기화되지 않았습니다." }, 229: { "English": "Digital Welding: Arc generation signal time-out !!!", "Korean": "디지털용접: 용접 아크 발생 대기 시간이 초과되었습니다." }, 230: { "English": "Digital Welding: Power ready signal was not come.", "Korean": "디지털용접: 용접기의 파워 준비 신호가 들어오지 않았습니다." }, 231: { "English": "Digital Welding: Machine ready signal was not come.", "Korean": "디지털용접: 용접기의 상태 준비 신호가 들어오지 않았습니다." }, 232: { "English": "Digital Welding: Error signal is coming from the welder.", "Korean": "디지털용접: 용접기에서 에러 신호가 발생되고 있습니다." }, 233: { "English": "Digital Welding: Cannot check the welder's touch sensing mode.", "Korean": "디지털 용접: 용접기 터치 센싱 모드가 확인되지 않습니다." }, 234: { "English": "Other motion or program command is still executing...!! Cannot run this function.", "Korean": "로봇 팔 또는 프로그램이 현재 동작 중 이기 때문에, 본 기능은 사용 불가능 합니다." }, 235: { "English": "No-arc option cannot be changed during program flow or during robot operation.<br>It can be changed in stop or pause state.", "Korean": "노 아크 옵션은 프로그램 흐름 중 또는 동작 중에는 변경 불가능합니다.<br>정지 또는 일시정지 상태에서 변경 가능합니다." }, 236: { "English": "Safety Wall: Wall number is over its bound.", "Korean": "Safety Wall: 설정 Wall 번호가 범위를 벗어납니다." }, 237: { "English": "Safety Wall: Option parameter is over its bound.", "Korean": "Safety Wall: 설정 옵션 번호가 범위를 벗어납니다." }, 238: { "English": "Safety Wall: Set Normal vector size is too small.... cannot make plane.", "Korean": "Safety Wall: 설정 수직 벡터 사이즈가 너무 작습니다. 벽 생성이 불가능합니다." }, 239: { "English": "Safety Wall: Set Points are too close... cannot make plane.", "Korean": "Safety Wall: 설정 점들이 너무 가까이 있습니다. 벽 생성이 불가능합니다." }, 240: { "English": "Safety Wall: Configuration is done!", "Korean": "Safety Wall: 설정이 완료되었습니다." }, 241: { "English": "Extended Axis: Configuration information of the selected motor is not set.", "Korean": "부가축: 선택한 모터의 정보가 설정되어있지 않습니다." }, 242: { "English": "Extended Axis: Data of the selected motor is not receiving.", "Korean": "부가축: 선택한 모터의 데이터가 수신되고 있지 않습니다." }, 243: { "English": "Extended Axis: A new motion command is input to the motor that is still running.", "Korean": "부가축: 아직 동작 중인 모터에 새로운 동작 명령이 입력됩니다." }, 244: { "English": "Extended Axis: Velocity or acceleration value is too small.", "Korean": "부가축: 속도나 가속도 값이 너무 작습니다." }, 245: { "English": "Extended Axis: Velocity or acceleration value exceeds the maximum.", "Korean": "부가축: 속도나 가속도 값이 최대치를 넘어섭니다." }, 246: { "English": "Extended Axis: Target position value exceeds the maximum.", "Korean": "부가축: 목표 위치 값이 최대 범위를 벗어납니다." }, 247: { "English": "Extended Axis: Configuratioin is saved.", "Korean": "부가축: 설정 정보가 저장되었습니다." }, 248: { "English": "Music Interface: Input media-file is not loaded in the system.", "Korean": "뮤직 인터페이스: 호출하는 미디어 파일이 시스템에 존재하지 않습니다." }, 249: { "English": "Music Interface: Wrong file format is selected.", "Korean": "뮤직 인터페이스: 설정한 파일 형식은 지원하지 않습니다." }, 250: { "English": "Music Interface: Wrong setting parameters.", "Korean": "뮤직 인터페이스: 설정한 옵션 정보가 잘못되었습니다." }, 251: { "English": "Music Interface: Wrong volume setting parameter.", "Korean": "뮤직 인터페이스: 볼륨 설정에 설정 불가능한 파라미터가 들어가 있습니다." }, 252: { "English": "Today is a public holiday. Have a nice day.", "Korean": "오늘은 공휴일 입니다. 행복한 하루 보내세요." }, 253: { "English": "Check whether the Safety switches are open or closed.", "Korean": "Safety 스위치들의 개패 여부를 확인하세요." }, 254: { "English": "Check whether the Safety EMS 1 switch is open or closed.", "Korean": "Safety EMS 1 스위치의 개패 여부를 확인하세요." }, 255: { "English": "Check whether the Safety EMS 2 switch is open or closed.", "Korean": "Safety EMS 2 스위치의 개패 여부를 확인하세요." }, 256: { "English": "Check whether the Safety PRS switch is open or closed.", "Korean": "Safety PRS 스위치의 개패 여부를 확인하세요." }, 257: { "English": "Check whether the Safety HSS switch is open or closed.", "Korean": "Safety HSS 스위치의 개패 여부를 확인하세요." }, 258: { "English": "Check whether the Safety SSS switch is open or closed.", "Korean": "Safety SSS 스위치의 개패 여부를 확인하세요." }, 259: { "English": "Already using the emergency direct teach mode function.", "Korean": "이미 비상 직접 교시 모드 기능을 사용 중에 있습니다." }, 260: { "English": "Robot arm activation process is being carried out by another process.", "Korean": "로봇 팔 활성화 과정이 다른 프로세스에 의하여 수행 중 입니다." }, 261: { "English": "There is a history of the joint angle initialization process. A full system reboot is required.", "Korean": "관절 각도 초기화 과정이 수행된 이력이 있습니다. 전체 시스템 재부팅이 요구됩니다." }, 262: { "English": "Unidentified ID is detected during joint communication check process. Type 6", "Korean": "관절 통신 체크 과정 중 미확인 ID가 감지됩니다. Type 6" }, 263: { "English": "Unidentified ID is detected during joint communication check process. Type 7", "Korean": "관절 통신 체크 과정 중 미확인 ID가 감지됩니다. Type 7" }, 264: { "English": "During joint communication check process, joint 0 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 0번이 정상적으로 인식되고 있지 않습니다." }, 265: { "English": "During joint communication check process, joint 1 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 1번이 정상적으로 인식되고 있지 않습니다." }, 266: { "English": "During joint communication check process, joint 2 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 2번이 정상적으로 인식되고 있지 않습니다." }, 267: { "English": "During joint communication check process, joint 3 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 3번이 정상적으로 인식되고 있지 않습니다." }, 268: { "English": "During joint communication check process, joint 4 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 4번이 정상적으로 인식되고 있지 않습니다." }, 269: { "English": "During joint communication check process, joint 5 is not recognized normally.", "Korean": "관절 통신 체크 과정 중 관절 5번이 정상적으로 인식되고 있지 않습니다." }, 270: { "English": "Joint communication check process failed.", "Korean": "관절 통신 체크 과정 실패." }, 271: { "English": "Tool flange communication check process failed.", "Korean": "툴 플랜지 통신 체크 과정 실패." }, 272: { "English": "Joint No. 0 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 0번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 273: { "English": "Joint No. 1 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 1번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 274: { "English": "Joint No. 2 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 2번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 275: { "English": "Joint No. 3 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 3번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 276: { "English": "Joint No. 4 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 4번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 277: { "English": "Joint No. 5 requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 5번이 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 278: { "English": "Joint encoder requests the user's angle confirmation and initialization. [PVL]", "Korean": "관절 엔코더가 사용자의 각도 확인 및 초기화를 요구합니다. [PVL]" }, 279: { "English": "An unstable signal is received from the joint encoder. [NONI]", "Korean": "관절 엔코더에서 불안정한 신호가 수신됩니다. [NONI]" }, 280: { "English": "The angle of joint 0 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 0번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 281: { "English": "The angle of joint 1 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 1번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 282: { "English": "The angle of joint 2 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 2번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 283: { "English": "The angle of joint 3 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 3번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 284: { "English": "The angle of joint 4 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 4번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 285: { "English": "The angle of joint 5 is out of the maximum + range. You must manually release the brake to turn the joint in the - direction.", "Korean": "관절 5번의 각도가 최대 + 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 - 방향으로 돌려야 합니다." }, 286: { "English": "The angle of joint 0 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 0번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 287: { "English": "The angle of joint 1 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 1번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 288: { "English": "The angle of joint 2 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 2번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 289: { "English": "The angle of joint 3 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 3번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 290: { "English": "The angle of joint 4 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 4번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 291: { "English": "The angle of joint 5 is out of the maximum - range. You must manually release the brake to turn the joint in the + direction.", "Korean": "관절 5번의 각도가 최대 - 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 + 방향으로 돌려야 합니다." }, 292: { "English": "Joint angle is outside the maximum range of use. You must manually release the brakes to turn the joint into range.", "Korean": "관절 각도가 사용 최대 범주를 벗어납니다. 수동으로 브레이크를 해제하여 관절을 범주 안으로 돌려야 합니다." }, 293: { "English": "There is a problem with the joint encoder angle or installation angle setting or sensor. Angle synchronization error", "Korean": "관절 엔코더 각도 또는 설치 각도 설정 또는 센서에 이상이 있습니다. 각도 동기화 오류" }, 294: { "English": "There is a problem in the process of receiving the calibration correction value of the robot arm.", "Korean": "로봇 팔의 캘리브레이션 보정치 수신 과정에 문제가 있습니다." }, 295: { "English": "Do not press and hold the direct teach button during the robotic arm preparation process.", "Korean": "로봇 팔 준비 과정 중에는 직접교시 버튼을 누르고 있으면 안됩니다." }, 296: { "English": "Failed to change the mode of the joint motor controller.", "Korean": "관절 모터 제어기의 모드 전환에 실패하였습니다." }, 297: { "English": "Ready for emergency direct teaching use. Emergency operation of the robot arm is possible by pressing the direct teaching button. Be sure to turn off the power after use.", "Korean": "비상 직접교시 사용이 준비되었습니다. 직접교시 버튼을 누르면 로봇 팔 비상운용이 가능합니다. 사용 후 반드시 전력을 꺼주세요." }, 298: { "English": "AutoTcp: Fail to calculate TCP! Check follows:\nYou shouldn't have the same posture out of the 8 setup postures.\nOf the eight setting postures, there should be no postures near the singularity/dead zone.", "Korean": "AutoTCP: 계산에 실패하였습니다. 다음과 같은 가능성을 확인하세요.\n8가지 설정 자세 중 같은 자세가 있으면 안됩니다.\n8가지 설정 자세 중 특이점/데드존 근처 자세가 있으면 안됩니다." }, 299: { "English": "The history of overcurrent or undervoltage remains in the control box SMPS power supply. A control box reboot is required. If the problem persists, contact the manufacturer.", "Korean": "제어박스 SMPS 파워서플라이에 과전류 이력 또는 저전압 이력이 남아있습니다. 제어박스 재부팅이 요구됩니다. 문제가 지속된다면 제조사에 문의하세요." }, 300: { "English": "ROS: Motion is called when the size of the received trajectory is 0.", "Korean": "ROS: 수신된 궤적의 사이즈가 0인 상태에서 동작이 호출됩니다." }, 301: { "English": "ROS: Size of the received trajectory and the size specified in the motion command do not match.", "Korean": "ROS: 수신된 궤적의 사이즈와 동작 명령어에 명시된 사이즈가 일치하지 않습니다." }, 302: { "English": "ROS: Time parameter value must always be received as a positive number.", "Korean": "ROS: 시간 파라미터 값은 항상 양수가 수신되어야 합니다." }, 303: { "English": "ROS: Time parameter must increase in ascending order.", "Korean": "ROS: 시간 파라미터는 오름차순으로 증가해야 합니다." }, 304: { "English": "ROS: The starting point of the trajectory should coincide with the last position of the robot.", "Korean": "ROS: 궤적의 시작 지점은, 로봇의 마지막 위치와 일치해야 합니다." }, 305: { "English": "Program Convert: Same operation is already being performed.", "Korean": "프로그램 전환: 이미 동일한 작업이 수행 중 입니다." }, 306: { "English": "Program Convert: Incorrect option number has been entered.", "Korean": "프로그램 전환: 잘못된 옵션 번호가 입력되었습니다." }, 307: { "English": "Program Convert: This function cannot be called while the robot is in motion.", "Korean": "프로그램 전환: 로봇 동작 중에는 이 기능을 호출할 수 없습니다." }, 308: { "English": "Program Convert: Timeout occurred in the process of confirming the end of the existing program.", "Korean": "프로그램 전환: 기존 프로그램 종료 확인 과정에서 시간 초과가 발생하였습니다." }, 309: { "English": "Program Convert: Timeout occurred while loading a new program.", "Korean": "프로그램 전환: 새로운 프로그램을 불러오는 도중 시간 초과가 발생하였습니다." }, 310: { "English": "Program Convert: Another LOAD function is already being performed.", "Korean": "프로그램 전환: 다른 불러오기 기능이 이미 수행 중 입니다." }, 311: { "English": "Program Convert: The called program does not exist or is damaged in the control box.", "Korean": "프로그램 전환: 호출된 프로그램이 제어박스에 존재하지 않거나 손상되었습니다." }, 312: { "English": "Program Convert: The called program exists in the control box, but it is damaged.", "Korean": "프로그램 전환: 호출된 프로그램이 제어박스에 존재하지만 손상되었습니다." }, 313: { "English": "CAN transmission: ID or DLC or channel is out of range.", "Korean": "CAN전송: ID 또는 DLC 또는 채널이 범위를 벗어납니다." }, 314: { "English": "External Axis: An incorrect auxiliary axis number has been received.", "Korean": "부가축: 잘못된 부가축 번호를 수신하였습니다." }, 315: { "English": "External Axis: At least 4 points of information are required for axis calibration.", "Korean": "부가축: 축 캘리브레이션을 위해서는 최소 4점 이상의 정보가 필요합니다." }, 316: { "English": "External Axis: The axis of the selected number is an unset axis. Check the Setup page.", "Korean": "부가축: 선택된 번호의 축은 설정되지 않은 축 입니다. Setup 페이지를 확인하세요." }, 317: { "English": "External Axis: During the axis calibration process, the information must be saved for the same axis.", "Korean": "부가축: 축 캘리브레이션 과정 중에는 같은 축을 대상으로 정보를 저장해야 합니다." }, 318: { "English": "External Axis: Among the saved data for axis calibration, there are duplicate data/too close data.", "Korean": "부가축: 축 캘리브리이션 저장 데이터 중, 중복된 데이터/너무 가까운 데이터가 존재합니다." }, 319: { "English": "External Axis: Information has been added to axis calibration.", "Korean": "부가축: 축 캘리브리이션에 정보가 추가되었습니다." }, 320: { "English": "External Axis: Calibration of the selected axis is complete.", "Korean": "부가축: 선택된 축의 캘리브리이션이 완료되었습니다." }, 321: { "English": "External Axis: The calibration process for the selected axis has failed. The error is more than the allowable range.", "Korean": "부가축: 선택된 축의 캘리브리이션 과정을 실패하였습니다. 오차가 허용범위 이상입니다." }, 322: { "English": "External Axis: During other operation/program operation, the corresponding function cannot be performed.", "Korean": "부가축: 다른 동작/프로그램 구동중에는 해당 기능 수행이 불가능 합니다." }, 323: { "English": "External Axis: Start Calibration ... !!!", "Korean": "부가축: 부가축 캘리브레이션을 시작하세요!" }, 324: { "English": "Robot motion speed or acceleration is outside the usable range.", "Korean": "로봇 동작 속도 또는 가속도가 사용 가능 범주 밖 입니다." }, 325: { "English": "External axis speed or acceleration is outside the usable range.", "Korean": "부가축 속도 또는 가속도가 사용 가능 범주 밖 입니다." }, 326: { "English": "External axis target value is out of the usable range.", "Korean": "부가축 목표값이 사용 가능 범주 밖 입니다." }, 327: { "English": "It is the point where the mathematical operation of the offset or shift function is impossible.", "Korean": "오프셋 또는 시프트 기능의 수학적 연산 불가능 지점 입니다." }, 328: { "English": "The program to be loaded through the input signal is not set.", "Korean": "입력 신호를 통하여 불러올 프로그램이 설정되어있지 않습니다." }, 329: { "English": "This is the name of the project (.wsl) that is not saved in the control box.", "Korean": "제어박스에 저장되어 있지 않은 프로젝트 (.wsl) 이름입니다." }, 330: { "English": "A grammatical error exists in the set project.", "Korean": "설정된 프로젝트에 문법적 오류가 존재합니다." }, 331: { "English": "The called file information does not exist in the Control box.", "Korean": "호출된 파일 정보가 제어박스에 존재하지 않습니다." }, 332: { "English": "The format of the row of the called CSV file is not supported.", "Korean": "호출된 CSV 파일의 행의 형식이 지원되지 않는 형태입니다." }, 333: { "English": "The position of the called row is outside the length of the file.", "Korean": "호출된 행의 위치가 파일의 길이를 벗어납니다." }, 334: { "English": "The position of the called column is outside the length of the file.", "Korean": "호출된 열의 위치가 파일의 길이를 벗어납니다." }, 335: { "English": "Failed to get information from the referenced index.", "Korean": "참조된 인덱스에서 정보를 획득하는데 실패하였습니다." }, 336: { "English": "Non-numeric information is stored in the called location.", "Korean": "숫자 형태가 아닌 정보가 호출된 위치에 저장되어 있습니다." }, 337: { "English": "The previously executed nutrunner command did not end.", "Korean": "기존에 수행 중이던 너트러너 명령어가 끝나지 않았습니다." }, 338: { "English": "Nutrunner instruction exit check timeout.", "Korean": "너트러너 명령어 종료 확인 시간 초과." }, 339: { "English": "The called thread is not the event thread.", "Korean": "호출된 쓰레드는 이벤트 쓰레드가 아닙니다." }, 340: { "English": "The called thread has no content.", "Korean": "호출된 쓰레드에 내용이 없습니다." }, 341: { "English": "The event thread that has not yet finished executing the command is called.", "Korean": "아직 명령어 수행이 끝나지 않은 이벤트 쓰레드가 호출됩니다." }, 342: { "English": "This function is only available during program playback.", "Korean": "해당 기능은 프로그램 재생 중에만 사용 가능합니다." }, 343: { "English": "This feature is not available in TCP/IP UI connection mode.", "Korean": "TCP/IP Ui 연결 모드에서는 이 기능을 사용할 수 없습니다." }, 344: { "English": "Joint Protection Error : Big Error 0", "Korean": "관절 보호 에러 : Big Error 0" }, 345: { "English": "Joint Protection Error : Big Error 1", "Korean": "관절 보호 에러 : Big Error 1" }, 346: { "English": "Joint Protection Error : Big Error 2", "Korean": "관절 보호 에러 : Big Error 2" }, 347: { "English": "Joint Protection Error : Big Error 3", "Korean": "관절 보호 에러 : Big Error 3" }, 348: { "English": "Joint Protection Error : Big Error 4", "Korean": "관절 보호 에러 : Big Error 4" }, 349: { "English": "Joint Protection Error : Big Error 5", "Korean": "관절 보호 에러 : Big Error 5" }, 350: { "English": "Joint Protection Error : Communication Input Error 0", "Korean": "관절 보호 에러 : Communication Input Error 0" }, 351: { "English": "Joint Protection Error : Communication Input Error 1", "Korean": "관절 보호 에러 : Communication Input Error 1" }, 352: { "English": "Joint Protection Error : Communication Input Error 2", "Korean": "관절 보호 에러 : Communication Input Error 2" }, 353: { "English": "Joint Protection Error : Communication Input Error 3", "Korean": "관절 보호 에러 : Communication Input Error 3" }, 354: { "English": "Joint Protection Error : Communication Input Error 4", "Korean": "관절 보호 에러 : Communication Input Error 4" }, 355: { "English": "Joint Protection Error : Communication Input Error 5", "Korean": "관절 보호 에러 : Communication Input Error 5" }, 356: { "English": "Joint Protection Error : Motor Rotor JAM Error 0", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 0" }, 357: { "English": "Joint Protection Error : Motor Rotor JAM Error 1", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 1" }, 358: { "English": "Joint Protection Error : Motor Rotor JAM Error 2", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 2" }, 359: { "English": "Joint Protection Error : Motor Rotor JAM Error 3", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 3" }, 360: { "English": "Joint Protection Error : Motor Rotor JAM Error 4", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 4" }, 361: { "English": "Joint Protection Error : Motor Rotor JAM Error 5", "Korean": "관절 보호 에러 : Motor Rotor JAM Error 5" }, 362: { "English": "Joint Protection Error : Motor Current Over Error 0", "Korean": "관절 보호 에러 : Motor Current Over Error 0" }, 363: { "English": "Joint Protection Error : Motor Current Over Error 1", "Korean": "관절 보호 에러 : Motor Current Over Error 1" }, 364: { "English": "Joint Protection Error : Motor Current Over Error 2", "Korean": "관절 보호 에러 : Motor Current Over Error 2" }, 365: { "English": "Joint Protection Error : Motor Current Over Error 3", "Korean": "관절 보호 에러 : Motor Current Over Error 3" }, 366: { "English": "Joint Protection Error : Motor Current Over Error 4", "Korean": "관절 보호 에러 : Motor Current Over Error 4" }, 367: { "English": "Joint Protection Error : Motor Current Over Error 5", "Korean": "관절 보호 에러 : Motor Current Over Error 5" }, 368: { "English": "Joint Protection Error : Motor Position Limit Error 0", "Korean": "관절 보호 에러 : Motor Position Limit Error 0" }, 369: { "English": "Joint Protection Error : Motor Position Limit Error 1", "Korean": "관절 보호 에러 : Motor Position Limit Error 1" }, 370: { "English": "Joint Protection Error : Motor Position Limit Error 2", "Korean": "관절 보호 에러 : Motor Position Limit Error 2" }, 371: { "English": "Joint Protection Error : Motor Position Limit Error 3", "Korean": "관절 보호 에러 : Motor Position Limit Error 3" }, 372: { "English": "Joint Protection Error : Motor Position Limit Error 4", "Korean": "관절 보호 에러 : Motor Position Limit Error 4" }, 373: { "English": "Joint Protection Error : Motor Position Limit Error 5", "Korean": "관절 보호 에러 : Motor Position Limit Error 5" }, 374: { "English": "Joint Protection Error : Board Mode Error 0", "Korean": "관절 보호 에러 : Board Mode Error 0" }, 375: { "English": "Joint Protection Error : Board Mode Error 1", "Korean": "관절 보호 에러 : Board Mode Error 1" }, 376: { "English": "Joint Protection Error : Board Mode Error 2", "Korean": "관절 보호 에러 : Board Mode Error 2" }, 377: { "English": "Joint Protection Error : Board Mode Error 3", "Korean": "관절 보호 에러 : Board Mode Error 3" }, 378: { "English": "Joint Protection Error : Board Mode Error 4", "Korean": "관절 보호 에러 : Board Mode Error 4" }, 379: { "English": "Joint Protection Error : Board Mode Error 5", "Korean": "관절 보호 에러 : Board Mode Error 5" }, 380: { "English": "Joint Protection Error : Board Temperature Error 0", "Korean": "관절 보호 에러 : Board Temperature Error 0" }, 381: { "English": "Joint Protection Error : Board Temperature Error 1", "Korean": "관절 보호 에러 : Board Temperature Error 1" }, 382: { "English": "Joint Protection Error : Board Temperature Error 2", "Korean": "관절 보호 에러 : Board Temperature Error 2" }, 383: { "English": "Joint Protection Error : Board Temperature Error 3", "Korean": "관절 보호 에러 : Board Temperature Error 3" }, 384: { "English": "Joint Protection Error : Board Temperature Error 4", "Korean": "관절 보호 에러 : Board Temperature Error 4" }, 385: { "English": "Joint Protection Error : Board Temperature Error 5", "Korean": "관절 보호 에러 : Board Temperature Error 5" }, 386: { "English": "Joint Protection Error : Tracking match Error 0", "Korean": "관절 보호 에러 : Tracking match Error 0" }, 387: { "English": "Joint Protection Error : Tracking match Error 1", "Korean": "관절 보호 에러 : Tracking match Error 1" }, 388: { "English": "Joint Protection Error : Tracking match Error 2", "Korean": "관절 보호 에러 : Tracking match Error 2" }, 389: { "English": "Joint Protection Error : Tracking match Error 3", "Korean": "관절 보호 에러 : Tracking match Error 3" }, 390: { "English": "Joint Protection Error : Tracking match Error 4", "Korean": "관절 보호 에러 : Tracking match Error 4" }, 391: { "English": "Joint Protection Error : Tracking match Error 5", "Korean": "관절 보호 에러 : Tracking match Error 5" }, 392: { "English": "This function is only available during welding.", "Korean": "이 기능은 용접 중에만 사용가능합니다." }, 393: { "English": "Referenceable index range in array information is out of range.", "Korean": "배열 정보에서 참조 가능한 인덱스 범위를 벗어 납니다. " }, 394: { "English": "Modbus Client: Failed to connect to the server.", "Korean": "모드버스 클라이언트 : 서버에 연결 실패하였습니다." }, 395: { "English": "Failed to send mail", "Korean": "메일 전송 실패" }, 396: { "English": "Shut off robot power supply: The robot base is tilted excessively.", "Korean": "로봇 전력 공급 차단: 로봇 베이스가 과도하게 기울었습니다." }, 397: { "English": "Pattern: The number of patterns available in the program is exceeded.", "Korean": "패턴: 프로그램에서 사용 가능한 패턴 개수를 넘어섭니다." }, 398: { "English": "Pattern: When configuring a pattern, at least 2 must be entered on each side.", "Korean": "패턴: 패턴 구성시, 각 변에는 최소 2 이상이 입력되어야 합니다." }, 399: { "English": "Pattern: Failed to retrieve the entered pattern ID.", "Korean": "패턴: 입력된 패턴 ID를 검색하는데 실패하였습니다." }, 400: { "English": "Pattern: There are patterns using the same pattern ID.", "Korean": "패턴: 동일한 패턴 ID를 사용하는 패턴들이 존재합니다." }, 401: { "English": "Robotus FT : RFT64SB is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "Robotus FT : 외부 F/T센서로 RFT64SB 가 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 402: { "English": "This function is only available after the robot arm is activated.", "Korean": "이 기능은 로봇 팔이 활성화 된 이후에 사용 가능합니다." }, 403: { "English": "OnRobot HEX FT : OnRobot HEX is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "OnRobot HEX FT : 외부 F/T센서로 OnRobot HEX 가 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 404: { "English": "Socket number 0 to be used in the Interface has already been set with another special function.", "Korean": "Interface에서 사용하고자 하는 소켓 0번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 405: { "English": "Socket number 1 to be used in the Interface has already been set with another special function.", "Korean": "Interface에서 사용하고자 하는 소켓 1번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 406: { "English": "Socket number 2 to be used in the Interface has already been set with another special function.", "Korean": "Interface에서 사용하고자 하는 소켓 2번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 407: { "English": "Socket number 3 to be used in the Interface has already been set with another special function.", "Korean": "Interface에서 사용하고자 하는 소켓 3번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 408: { "English": "Socket number 4 to be used in the Interface has already been set with another special function.", "Korean": "Interface에서 사용하고자 하는 소켓 4번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 409: { "English": "The socket number 0 you want to use is already set with another special function.", "Korean": "사용하고자 하는 소켓 번호 0번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 410: { "English": "The socket number 1 you want to use is already set with another special function.", "Korean": "사용하고자 하는 소켓 번호 1번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 411: { "English": "The socket number 2 you want to use is already set with another special function.", "Korean": "사용하고자 하는 소켓 번호 2번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 412: { "English": "The socket number 3 you want to use is already set with another special function.", "Korean": "사용하고자 하는 소켓 번호 3번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 413: { "English": "The socket number 4 you want to use is already set with another special function.", "Korean": "사용하고자 하는 소켓 번호 4번이 이미 다른 특수 기능으로 설정되어 있습니다." }, 414: { "English": "The program cannot be started during the robot arm activation process.", "Korean": "로봇 팔 활성화 과정 중에는 프로그램을 시작할 수 없습니다." }, 415: { "English": "The program cannot be started because the digital input special function Program Start Block signal is being received.", "Korean": "디지털 입력 특수 기능인 Program Start Block 신호가 들어오고 있어서 프로그램을 시작할 수 없습니다." }, 416: { "English": "The control box network settings have been changed. Be sure to reboot the robot control box for normal operation.", "Korean": "제이벅스 네트워크 설정이 변경되었습니다. 정상 작동을 위해서 반드시 로봇 제어박스를 재부팅하세요." }, 417: { "English": "The function definition for the jog button on the hand controller has been changed.", "Korean": "핸드 컨트롤러의 조그 버튼에 대한 기능 정의가 변경되었습니다." }, 418: { "English": "For the settings related to operation, the button functions when pressed and released are fixed for safety.", "Korean": "동작과 관련된 설정은 안전을 위하여 누를때와 뗄때의 버튼 기능이 고정됩니다." }, 419: { "English": "In order to use the interface communication function, the process of connecting and setting with the server must be preceded.", "Korean": "인터페이스 통신 기능을 사용하기 위해서는 서버와 연결 및 설정 과정이 선행되어야 합니다." }, 420: { "English": "Failed to connect to PLC-HMI-Vision server using socket 0 in the Interface.", "Korean": "인터페이스에서 소켓 0번을 사용하여 PLC-HMI-Vision 서버에 접속하는데 실패하였습니다." }, 421: { "English": "Failed to connect to PLC-HMI-Vision server using socket 1 in the Interface.", "Korean": "인터페이스에서 소켓 1번을 사용하여 PLC-HMI-Vision 서버에 접속하는데 실패하였습니다." }, 422: { "English": "Failed to connect to PLC-HMI-Vision server using socket 2 in the Interface.", "Korean": "인터페이스에서 소켓 2번을 사용하여 PLC-HMI-Vision 서버에 접속하는데 실패하였습니다." }, 423: { "English": "Failed to connect to PLC-HMI-Vision server using socket 3 in the Interface.", "Korean": "인터페이스에서 소켓 3번을 사용하여 PLC-HMI-Vision 서버에 접속하는데 실패하였습니다." }, 424: { "English": "Failed to connect to PLC-HMI-Vision server using socket 4 in the Interface.", "Korean": "인터페이스에서 소켓 4번을 사용하여 PLC-HMI-Vision 서버에 접속하는데 실패하였습니다." }, 425: { "English": "Failed to write a single variable through socket 0 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 0번을 통한 단일 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 426: { "English": "Failed to write a single variable through socket 1 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 1번을 통한 단일 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 427: { "English": "Failed to write a single variable through socket 2 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 2번을 통한 단일 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 428: { "English": "Failed to write a single variable through socket 3 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 3번을 통한 단일 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 429: { "English": "Failed to write a single variable through socket 4 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 4번을 통한 단일 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 430: { "English": "Failed to read a single variable through socket 0 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 0번을 통한 단일 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 431: { "English": "Failed to read a single variable through socket 1 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 1번을 통한 단일 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 432: { "English": "Failed to read a single variable through socket 2 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 2번을 통한 단일 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 433: { "English": "Failed to read a single variable through socket 3 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 3번을 통한 단일 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 434: { "English": "Failed to read a single variable through socket 4 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 4번을 통한 단일 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 435: { "English": "Failed to write array numbers through socket 0 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 0번을 통한 다중 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 436: { "English": "Failed to write array numbers through socket 1 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 1번을 통한 다중 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 437: { "English": "Failed to write array numbers through socket 2 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 2번을 통한 다중 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 438: { "English": "Failed to write array numbers through socket 3 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 3번을 통한 다중 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 439: { "English": "Failed to write array numbers through socket 4 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 4번을 통한 다중 변수 쓰기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 440: { "English": "Failed to read array numbers through socket 0 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 0번을 통한 다중 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 441: { "English": "Failed to read array numbers through socket 1 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 1번을 통한 다중 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 442: { "English": "Failed to read array numbers through socket 2 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 2번을 통한 다중 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 443: { "English": "Failed to read array numbers through socket 3 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 3번을 통한 다중 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 444: { "English": "Failed to read array numbers through socket 4 of the Interface. A normal ACK signal did not arrive from the server.", "Korean": "인터페이스의 소켓 4번을 통한 다중 변수 읽기에 실패하였습니다. 서버로부터 정상적인 ACK 신호가 도착하지 않았습니다." }, 445: { "English": "The temperature of the robot arm is outside the recommended operating environment. Be careful when using.", "Korean": "로봇 팔의 온도가 권장 사용 환경을 벗어납니다. 사용시 유의해세요." }, 446: { "English": "Weaving Setting Error: The axis selection is incorrect. The same axis cannot be selected.", "Korean": "위빙 설정 오류 : 축 선택이 올바르지 않습니다. 같은 축은 선택할 수 없습니다." }, 447: { "English": "Weaving Setting Error: The scale value is outside the acceptable range.", "Korean": "위빙 설정 오류 : 스캐일 값이 허용 범위를 벗어납니다." }, 448: { "English": "Weaving Setting Error: The offset value cannot be set beyond the maximum amplitude.", "Korean": "위빙 설정 오류 : 오프셋 값은 최대 진폭 크기 이상으로 설정 불가능 합니다." }, 449: { "English": "Ethernet IP Adapter On settings have been saved. A full system reboot is required for the settings to take effect.", "Korean": "Ethernet IP Adaptor On 설정이 저장되었습니다. 설정을 반영하기 위해 시스템 전체 재부팅이 필요합니다." }, 450: { "English": "Ethernet IP Adapter Off settings have been saved. A full system reboot is required for the settings to take effect.", "Korean": "Ethernet IP Adaptor Off 설정이 저장되었습니다. 설정을 반영하기 위해 시스템 전체 재부팅이 필요합니다." }, 451: { "English": "Ethernet IP Adapter module is installed.", "Korean": "Ethernet IP Adaptor 모듈이 설치되었습니다. " }, 452: { "English": "Ethernet IP Adpator module is removed.", "Korean": "Ethernet IP Adpator 모듈이 제거되었습니다. " }, 453: { "English": "Communication connection with OnRobot Compute Box failed.", "Korean": "OnRobot Compute Box와 통신 연결에 실패하였습니다." }, 454: { "English": "Failed to receive ACK for initial setup from OnRobot Compute Box.", "Korean": "OnRobot Compute Box로부터 초기 설정에 대한 ACK를 수신하지 못하였습니다." }, 455: { "English": "Failed to receive ACK for motion command from OnRobot Compute Box.", "Korean": "OnRobot Compute Box로부터 동작 명령에 대한 ACK를 수신하지 못하였습니다." }, 456: { "English": "To connect to the Onrobot Compute Box, user must first perform the gripper initial settings first.", "Korean": "OnRobot Compute Box와 연결해 사용하려면 그리퍼 초기 설정을 먼저 수행해야 합니다." }, 457: { "English": "Data reception from the Side IO Board is cut off.\nCommunication noise may be coming from outside.\nThe communication line inside the control box may be unstable.\nThe fuse of the IO Board may be broken.", "Korean": "Side IO Board로부터의 데이터 수신이 끊어졌습니다.\n외부에서 통신 노이즈가 들어오고 있을 수 있습니다.\n제어박스 내부 통신선이 불안정할 수 있습니다.\nIO Board의 Fuse가 끊어졌을 수 있습니다." }, 458: { "English": "A low voltage output of DC 48V SMPS is detected.\nCheck ACtoDC48V SMPS status.\nThere may be external AC noise.\nIf the problem persists, disconnect the AC cable for at least 15 minutes and reuse it.", "Korean": "DC 48V SMPS의 저전압 출력이 감지됩니다.\nACtoDC48V SMPS 상태를 확인하세요.\n외부 AC 노이즈가 있을 수 있습니다.\n문제가 지속된다면 AC 캐이블을 15분 이상 분리 후 재사용하세요." }, 459: { "English": "Point with the same name as a string does not exist.", "Korean": "문자열과 같은 명칭의 Point가 존재하지 않습니다." }, 460: { "English": "Joint with the same name as a string does not exist.", "Korean": "문자열과 같은 명칭의 Joint가 존재하지 않습니다." }, 461: { "English": "Control box POWER SWE error.\nThe SMPS part may be operating abnormally or the control box may not be grounded.", "Korean": "제어박스 POWER SWE 오류.\nSMPS 부품이 비정상 작동 중 이거나 제어박스에 접지가 되어있지 않았을 수 있습니다." }, 462: { "English": "Communication error: The communication of joint 0 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 0번 통신이 불안정합니다." }, 463: { "English": "Communication error: The communication of joint 1 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 1번 통신이 불안정합니다." }, 464: { "English": "Communication error: The communication of joint 2 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 2번 통신이 불안정합니다." }, 465: { "English": "Communication error: The communication of joint 3 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 3번 통신이 불안정합니다." }, 466: { "English": "Communication error: The communication of joint 4 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 4번 통신이 불안정합니다." }, 467: { "English": "Communication error: The communication of joint 5 of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 5번 통신이 불안정합니다." }, 468: { "English": "Communication error: The communication of tool flange of the robot arm is unstable.", "Korean": "통신에러 : 로봇 팔의 툴플랜지 통신이 불안정합니다." }, 469: { "English": "Extended Axis: The difference between the command position of joint 0 and the encoder position of AC servo is out of range.", "Korean": "부가축: 0번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 470: { "English": "Extended Axis: The difference between the command position of joint 1 and the encoder position of AC servo is out of range.", "Korean": "부가축: 1번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 471: { "English": "Extended Axis: The difference between the command position of joint 2 and the encoder position of AC servo is out of range.", "Korean": "부가축: 2번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 472: { "English": "Extended Axis: The difference between the command position of joint 3 and the encoder position of AC servo is out of range.", "Korean": "부가축: 3번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 473: { "English": "Extended Axis: The difference between the command position of joint 4 and the encoder position of AC servo is out of range.", "Korean": "부가축: 4번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 474: { "English": "Extended Axis: The difference between the command position of joint 5 and the encoder position of AC servo is out of range.", "Korean": "부가축: 5번 관절의 지령 위치와 AC 서보의 엔코더 위치의 차이가 범위를 벗어납니다." }, 475: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 0.", "Korean": "부가축: 0번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 476: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 1.", "Korean": "부가축: 1번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 477: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 2.", "Korean": "부가축: 2번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 478: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 3.", "Korean": "부가축: 3번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 479: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 4.", "Korean": "부가축: 4번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 480: { "English": "Extended Axis: An error is detected in the AC servo driver of joint 5.", "Korean": "부가축: 5번 관절의 AC 서보 드라이버에서 에러가 검출됩니다." }, 481: { "English": "Execution of the previous command is not finished in the selected digital output port and buffer number.", "Korean": "선택된 디지털 출력 포트와 버퍼번호에서 이전 명령어 수행이 종료되지 않았습니다." }, 482: { "English": "ProfiNet On settings have been saved. A full system reboot is required for the settings to take effect.", "Korean": "ProfiNet On 설정이 저장되었습니다. 설정을 반영하기 위해 시스템 전체 재부팅이 필요합니다." }, 483: { "English": "ProfiNet Off settings have been saved. A full system reboot is required for the settings to take effect.", "Korean": "ProfiNet Off 설정이 저장되었습니다. 설정을 반영하기 위해 시스템 전체 재부팅이 필요합니다." }, 484: { "English": "Variable with the same name as a string does not exist.", "Korean": "문자열과 같은 명칭의 Variable이 존재하지 않습니다." }, 485: { "English": "Robot arm has been powered off by the EMS 2 Safety switch.", "Korean": "EMS 2 Safety 스위치로 인하여 로봇 팔의 전원이 차단되었습니다." }, 486: { "English": "Robot arm has been powered off by the PRS Safety switch.", "Korean": "PRS Safety 스위치로 인하여 로봇 팔의 전원이 차단되었습니다." }, 487: { "English": "Robot arm has been powered off by the HSS Safety switch.", "Korean": "HSS Safety 스위치로 인하여 로봇 팔의 전원이 차단되었습니다." }, 488: { "English": "Robot arm has been powered off by the SSS Safety switch.", "Korean": "SSS Safety 스위치로 인하여 로봇 팔의 전원이 차단되었습니다." }, 489: { "English": "Music Interface: The driver required to play music is not installed.", "Korean": "뮤직 인터페이스: 뮤직 재생에 필요한 드라이버가 설치되지 않았습니다." }, 490: { "English": "The robot arm is activated in emergency mode or recovery mode. In this case, the program cannot be played.", "Korean": "긴급 모드 혹은 복구 모드로 로봇 팔이 활성화 되어 있습니다. 이 경우 프로그램을 재생할 수 없습니다." }, 491: { "English": "This function cannot be used in Tool I/O.", "Korean": "Tool 입출력에서는 해당 기능을 사용할 수 없습니다." }, 492: { "English": "Fail to get IO Board state data.\nCheck IO board cable connection state.\n24V IO Fuse may have been disconnected or broken.\nControl Box 24V SMPS may be damaged.", "Korean": "IO보드 상태 데이터 수신 실패\nIO 보드 선 연결 상태를 확인하세요.\n24V io퓨즈가 나갔을 가능성이 있습니다.\n제어박스 24V SMPS가 손상되었을 수 있습니다." }, 493: { "English": "Motion macro: Identical points exist among corner points.", "Korean": "동작 매크로: 코너 지점 중에 중복된 포인트가 존재합니다." }, 494: { "English": "Motion macro: For the number of intervals, a number greater than 1 must be entered.", "Korean": "동작 매크로: 간격 갯수는 1이상의 숫자를 입력해야 합니다." }, 495: { "English": "Motion macro: Arc fitting failed. Please check that the set point information is correct.", "Korean": "동작 매크로: 원호 피팅에 실패하였습니다. 설정 지점 정보가 올바른지 확인해주세요." }, 496: { "English": "It is out of the safety plane area. Robot arm motion is limited.", "Korean": "Safety Plane 영역을 벗어납니다. 로봇 팔 동작이 제한됩니다." }, 497: { "English": "The joint angle of the robot arm is outside the Safety Limit range. Robot arm motion is limited.", "Korean": "로봇 팔의 관절 각도가 Safety Limit 범위를 벗어납니다. 로봇 팔 동작이 제한됩니다." }, 498: { "English": "The CPU temperature inside the control box is high. Check if there is any problem with the CPU fan coupling or the control box main ventilation system.", "Korean": "제어박스 내부의 CPU 온도가 높습니다. CPU 팬의 결합 상태 혹은 제어박스 메인 환풍 시스템에 문제가 없는지 확인하세요." }, 499: { "English": "The temperature of the motherboard inside the control box is high. Make sure there are no problems with the main ventilation system.", "Korean": "제어박스 내부의 마더보드 온도가 높습니다. 메인 환풍 시스템에 문제가 없는지 확인하세요." }, 500: { "English": "The set speed value is too small.", "Korean": "설정된 속도 값이 너무 작은 값 입니다." }, 501: { "English": "The set acceleration value is too small.", "Korean": "설정된 가속도 값이 너무 작은 값 입니다." }, 502: { "English": "To run the program from the middle, you must select a line within the main program area.", "Korean": "프로그램을 중간부터 실행하려면, 메인프로그램 영역 안에서 줄을 선택해야 합니다." }, 503: { "English": "A divide by zero exists during an arithmetic operation, stopping program operation.", "Korean": "산술 연산 과정 중에 나누기 0이 존재하여 프로그램 운용을 중단합니다." }, 504: { "English": "Information stored in the system does not exist.", "Korean": "시스템에 저장된 정보가 존재하지 않습니다." }, 505: { "English": "Duplex pins can only be configured on odd-numbered pins. This function works with the pin of the previous number.", "Korean": "Duplex 핀은 홀수 번호 핀에만 설정 가능합니다. 이전 번호의 핀과 연동되는 기능입니다." }, 506: { "English": "The port defined in the IO special function cannot be assigned to the software PLC port.", "Korean": "IO 특수 기능에 정의된 포트는 Software PLC 용 포트에 지정 불가능 합니다." }, 507: { "English": "Ports used for Software PLC functions cannot be designated as IO special functions.", "Korean": "Software PLC 기능에 사용되는 포트는 IO 특수 기능으로 지정 불가능 합니다." }, 508: { "English": "The IO special function has been saved.\nIf the software PLC uses the same I/O port, be aware that unintended situations may occur.", "Korean": "IO 특수 기능이 저장되었습니다.\nSoftware PLC에서 동일한 입출력 포트를 사용하고 있다면 의도하지 않은 상황이 나타날 수 있으니 주의하세요." }, 509: { "English": "Software PLC settings have been saved.\nIf the same I/O port is used in the IO special function settings, be careful as unintended situations may occur.", "Korean": "Software PLC 설정이 저장되었습니다.\nIO 특수 기능 설정에서 동일한 입출력 포트를 사용하고 있다면 의도하지 않은 상황이 나타날 수 있으니 주의하세요." }, 510: { "English": "MUL Error. The angle of joint 0 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 0번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 511: { "English": "MUL Error. The angle of joint 1 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 1번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 512: { "English": "MUL Error. The angle of joint 2 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 2번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 513: { "English": "MUL Error. The angle of joint 3 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 3번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 514: { "English": "MUL Error. The angle of joint 4 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 4번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 515: { "English": "MUL Error. The angle of joint 5 has moved more than 90 degrees from the last used value in the no-power state. Release the brake with your hand and return the joint to its original position.", "Korean": "MUL 에러. 관절 5번의 각도가 무전원 상태에서 마지막 사용 값에서 90도 이상 움직였습니다. 손으로 브레이크를 해제해서 원래 사용하던 자세 근처로 관절을 돌려주세요. " }, 516: { "English": "Settings have been changed. Reboot the control box.", "Korean": "설정이 변경되었습니다. 제어 박스를 재부팅하세요." }, 517: { "English": "AIDIN FT : AIDIN AFT is selected for the external F/T sensor.\nRe-boot all systems", "Korean": "AIDIN FT : 외부 F/T센서로 AIDIN AFT가 선택되었습니다.\n전체 시스템을 재부팅하세요." }, 518: { "English": "The file transfer driver for the TCP IP connection method is not installed in the control box.", "Korean": "TCP IP 연결 방식을 위한 파일 전송 드라이버가 제어박스에 설치되어있지 않습니다." }, 519: { "English": "The maximum number of variables supported by the Modbus client polling function has been exceeded.", "Korean": "모드버스 클라이언트 폴링 기능에서 지원 가능한 최대 변수 갯수를 넘었습니다." }, 520: { "English": "Safety polygon area has been violated. Robotic arm movements are limited.", "Korean": "Safety 폴리곤 영역을 침범하였습니다. 로봇 팔 동작이 제한됩니다." }, 521: { "English": "Unable to set safety polygon. A minimum of 3 points is required. Each side of a polygon must not overlap.", "Korean": "안전 폴리곤을 설정할 수 없습니다. 최소 3점 이상이 필요합니다. 폴리곤의 각 변은 겹치면 안됩니다." }, 522: { "English": "There is a problem with the remaining RAM of the PC inside the control box. Check your system.", "Korean": "제어박스 내부 PC의 RAM 잔여량에 문제가 발생하였습니다. 시스템을 점검하세요." }, 523: { "English": "The temperature of the HDD inside the control box is high. Make sure there are no problems with the main ventilation system.", "Korean": "제어박스 내부의 HDD 온도가 높습니다. 메인 환풍 시스템에 문제가 없는지 확인하세요." }, 524: { "English": "Protector FLT error persists at robot arm joint 0. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 0 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 525: { "English": "Protector FLT error persists at robot arm joint 1. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 1 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 526: { "English": "Protector FLT error persists at robot arm joint 2. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 2 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 527: { "English": "Protector FLT error persists at robot arm joint 3. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 3 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 528: { "English": "Protector FLT error persists at robot arm joint 4. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 4 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 529: { "English": "Protector FLT error persists at robot arm joint 5. Problems may arise when operating the robot arm.", "Korean": "로봇 팔 관절 5 번에서 보호소자 FLT에러가 지속됩니다. 로봇 팔 운용에 문제가 생길 수 있습니다." }, 530: { "English": "Fitting: The number of input points must be 3 or more.", "Korean": "Fitting: 입력 점의 갯수는 3개 이상 이어야 합니다." }, 531: { "English": "Fitting: The number of reference points and the number of data points are different.", "Korean": "Fitting: 레퍼런스 포인트 갯수와 데이터 포인트 갯수가 다릅니다." }, 532: { "English": "Fitting: This function cannot be performed.", "Korean": "Fitting: 이 기능을 실행할 수 없는 상태 입니다." }, 533: { "English": "Fitting: A problem occurred during numerical calculation.", "Korean": "Fitting: 수치 계산 과정에서 문제가 발생하였습니다." }, 534: { "English": "Fitting: The calculated result exceeds the allowed error range.", "Korean": "Fitting: 계산된 결과가 허용된 오차 범위를 초과합니다." }, 535: { "English": "Fitting: There are points that are too close.", "Korean": "Fitting: 너무 가까운 점이 존재합니다." }, 536: { "English": "Fitting: The points used in the calculation lie on a straight line.", "Korean": "Fitting: 계산에 사용되는 점이 일직선 상에 존재합니다." }, 537: { "English": "Fitting: Calculation failed.", "Korean": "Fitting: 계산에 실패하였습니다." }, 538: { "English": "Fitting: This function cannot be performed during operation.", "Korean": "Fitting: 동작 중에는 이 기능을 실행할 수 없습니다." }, 539: { "English": "Fitting: The point spacing difference between the reference point and the data point exceeds the standard.", "Korean": "Fitting: 레퍼런스 포인트와 데이터 포인트의 점 간격 차이가 기준을 넘어섭니다." }, 540: { "English": "Communication error: The communication of joint 0 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 0번 통신이 불안정합니다. L2C 통신라인이 불안정 합니다." }, 541: { "English": "Communication error: The communication of joint 1 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 1번 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 542: { "English": "Communication error: The communication of joint 2 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 2번 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 543: { "English": "Communication error: The communication of joint 3 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 3번 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 544: { "English": "Communication error: The communication of joint 4 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 4번 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 545: { "English": "Communication error: The communication of joint 5 of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 관절 5번 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 546: { "English": "Communication error: The communication of tool flange of the robot arm is unstable. L2C communication line is unstable.", "Korean": "통신에러 : 로봇 팔의 툴플랜지 통신이 불안정합니다.  L2C 통신라인이 불안정 합니다." }, 547: { "English": "Failure to receive IO board status data due to L2C communication line instability.", "Korean": "L2C 통신라인 불안정으로 인한 IO보드 상태 데이터 수신 실패." }, 548: { "English": "The gripper initialization process timed out. No normal data was received from the gripper.", "Korean": "그리퍼 초기화 과정이 시간초과되었습니다. 그리퍼로부터 정상적인 데이터를 수신하지 못하였습니다." }, 549: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 0", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 0" }, 550: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 1", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 1" }, 551: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 2", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 2" }, 552: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 3", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 3" }, 553: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 4", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 4" }, 554: { "English": "Joint Protection Error : Motor Stator Temperature Error at Joint 5", "Korean": "관절 보호 에러 : Motor Stator Temperature Error at Joint 5" }, 555: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 0", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 0" }, 556: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 1", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 1" }, 557: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 2", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 2" }, 558: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 3", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 3" }, 559: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 4", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 4" }, 560: { "English": "Joint Protection Error : Current Sensing Biasing Error at Joint 5", "Korean": "관절 보호 에러 : Current Sensing Biasing Error at Joint 5" }, 561: { "English": "A new operation command was received at a point where the previous operation had not yet concluded.", "Korean": "이전 동작이 종료되지 않은 시점에서 새로운 동작 명령이 수신되었습니다." }, 562: { "English": "Joint angle of the target posture exceeds the specified range.", "Korean": "목표 자세의 관절 각도가 제한 범위를 벗어납니다." }, 563: { "English": "XYZ position of the target point is beyond the specified range.", "Korean": "목표 지점의 XYZ 위치값이 제한 범위를 벗어납니다." }, 564: { "English": "To utilize this feature, the high-resolution ADC mode must be configured.", "Korean": "이 기능을 사용하기 위해서는 고 해상도 ADC 모드가 설정되어 있어야합니다." }, 565: { "English": "Undefined model code number. Check the number or update the control box software to the latest.", "Korean": "정의되지 않은 모델 코드 번호 입니다. 번호를 확인하거나 제어박스 소프트웨어를 최신으로 업데이트하세요." }, 566: { "English": "Failed to create motion speed profile. Please reduce the target speed or increase the target acceleration.", "Korean": "동작 속도 프로파일 생성 실패. 목표 속도를 줄이거나 목표 가속도를 높여주세요." }, 567: { "English": "The predicted temperature of the power system of the control box is outside the threshold.", "Korean": "제어박스의 전원부 계통의 예측온도가 임계값을 벗어납니다." }, 568: { "English": "The Servo J parameters entered are outside the available range.", "Korean": "입력된 Servo J 파라미터가 사용 가능 범위를 벗어납니다." }, 569: { "English": "The Servo L parameters entered are outside the available range.", "Korean": "입력된 Servo L 파라미터가 사용 가능 범위를 벗어납니다." }, 570: { "English": "The Servo T parameters entered are outside the available range.", "Korean": "입력된 Servo T 파라미터가 사용 가능 범위를 벗어납니다." }, 571: { "English": "Collision detection motion setting : Mode to release joint torque for 0.8 seconds", "Korean": "충돌 감지 동작 모드 : 0.8 초 동안 관절 토크를 풀어주는 모드" }, 572: { "English": "Collision detection motion setting : Mode to release joint torque for 1.6 seconds", "Korean": "충돌 감지 동작 모드 : 1.6 초 동안 관절 토크를 풀어주는 모드" }, 573: { "English": "The central axis settings for circular motion are incorrect.", "Korean": "원 동작을 위한 중심 축 설정 값이 올바르지 않습니다." }, 574: { "English": "The points set for circular motion are too close. A circular trajectory cannot be created.", "Korean": "원 동작을 위해 설정된 점들이 너무 가깝습니다. 원 궤적을 생성하지 못합니다." }, 575: { "English": "Numerical problems arise during the trajectory generation stage.", "Korean": "궤적 생성 단계에서 수치적인 문제가 발생합니다." }, 576: { "English": "Because certain points exist on a straight line, it is impossible to create the desired trajectory.", "Korean": "특정 점들이 일직선 상에 존재하기 때문에 원하는 궤적 생성이 불가능합니다." }, 577: { "English": "At least two points must be set to perform the motion.", "Korean": "최소 2개 이상의 지점이 설정되어야 해당 동작을 수행할 수 있습니다." }, 578: { "English": "The set Modbus ID is outside the available range.", "Korean": "설정된 모드 버스 ID 가 사용 가능한 범위를 벗어납니다." }, 579: { "English": "The socket number entered is outside the range of available handlers.", "Korean": "입력된 소켓 번호가 사용가능한 핸들러 범위를 벗어납니다." }, 580: { "English": "The data table has been sent.", "Korean": "데이터 테이블이 전송되었습니다." }, 581: { "English": "The data table has been saved.", "Korean": "데이터 테이블이 저장되었습니다." }, 582: { "English": "The serial number has been saved.", "Korean": "시리얼 번호가 저장되었습니다." }, 583: { "English": "Failed to save serial number.", "Korean": "시리얼 번호를 저장하지 못하였습니다." }, 584: { "English": "An ID setting command has been sent. Reboot the entire system.", "Korean": "ID 설정 명령이 전송되었습니다. 전체 시스템을 재부팅하세요." }, 585: { "English": "The selected drivers have been transferred. Proceed with the installation process.", "Korean": "선택된 드라이버가 전송되었습니다. 설치 과정을 진행하세요." }, 586: { "English": "Installation of the selected driver is complete. Reboot the entire system.", "Korean": "선택된 드라이버 설치가 완료되었습니다. 전체 시스템을 재부팅하세요." }, 587: { "English": "External Axis: A mathematical problem arises during the calibration calculation process. Check the entered posture information.", "Korean": "부가축: 캘리브레이션 연산 과정에서 수학적 문제가 발생합니다. 입력된 자세 정보를 확인하세요." }, 588: { "English": "The IP address entered is not in an available range.", "Korean": "입력된 IP 주소가 사용가능한 범위가 아닙니다." }, 589: { "English": "This feature is only available in Real Robot mode.", "Korean": "이 기능은 Real Robot 모드에서만 사용 가능합니다." }, 590: { "English": "The control box time zone has been set.", "Korean": "제어박스 시간대 영역이 설정되었습니다." }, 591: { "English": "An inappropriate value was entered in the control box time zone setting.", "Korean": "제어박스 시간대 영역 설정에 부적합한 값이 입력되었습니다." }, 592: { "English": "The command has been executed. The control box will automatically reboot within a few seconds.", "Korean": "명령어가 수행되었습니다. 제어박스가 몇 초 안에 자동으로 재부팅 됩니다." }, 593: { "English": "A timeout occurred during the Modbus ASCII writing process.", "Korean": "Modbus ASCII 쓰기 과정에서 시간 초과가 발생하였습니다." }, 594: { "English": "A normal ACK signal was not received during the Modbus ASCII writing process.", "Korean": "Modbus ASCII 쓰기 과정에서 정상적인 ACK 신호를 수신하지 못하였습니다." }, 595: { "English": "A bus error occurred during the Modbus ASCII writing process.", "Korean": "Modbus ASCII 쓰기 과정에서 버스 에러가 발생하였습니다." }, 596: { "English": "A timeout occurred during the Modbus ASCII reading process.", "Korean": "Modbus ASCII 읽기 과정에서 시간 초과가 발생하였습니다." }, 597: { "English": "A normal ACK signal was not received during the Modbus ASCII reading process.", "Korean": "Modbus ASCII 읽기 과정에서 정상적인 ACK 신호를 수신하지 못하였습니다." }, 598: { "English": "A bus error occurred during the Modbus ASCII reading process.", "Korean": "Modbus ASCII 읽기 과정에서 버스 에러가 발생하였습니다." }, 599: { "English": "A format error occurred during the Modbus ASCII reading process.", "Korean": "Modbus ASCII 읽기 과정에서 포멧 에러가 발생하였습니다." }, 600: { "English": "Joint reducer protection error 0: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 0: 기어의 허용 토크 이상의 부하가 발생됩니다." }, 601: { "English": "Joint reducer protection error 1: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 1: 기어의 허용 토크 이상의 부하가 발생됩니다." }, 602: { "English": "Joint reducer protection error 2: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 2: 기어의 허용 토크 이상의 부하가 발생됩니다." }, 603: { "English": "Joint reducer protection error 3: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 3: 기어의 허용 토크 이상의 부하가 발생됩니다." }, 604: { "English": "Joint reducer protection error 4: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 4: 기어의 허용 토크 이상의 부하가 발생됩니다." }, 605: { "English": "Joint reducer protection error 5: A load exceeding the allowable torque of the gear occurs.", "Korean": "관절 감속기 보호 에러 5: 기어의 허용 토크 이상의 부하가 발생됩니다." }}
ICE_INFO_AMBI_HIGH: SystemVariable  # value = <SystemVariable.ICE_INFO_AMBI_HIGH: 264>
ICE_INFO_AMBI_LOW: SystemVariable  # value = <SystemVariable.ICE_INFO_AMBI_LOW: 263>
ICE_INFO_CONNECTED: SystemVariable  # value = <SystemVariable.ICE_INFO_CONNECTED: 255>
ICE_INFO_MODE_COMM: SystemVariable  # value = <SystemVariable.ICE_INFO_MODE_COMM: 259>
ICE_INFO_MODE_CUP: SystemVariable  # value = <SystemVariable.ICE_INFO_MODE_CUP: 260>
ICE_INFO_REQUESTING: SystemVariable  # value = <SystemVariable.ICE_INFO_REQUESTING: 256>
ICE_INFO_TIME_ICE: SystemVariable  # value = <SystemVariable.ICE_INFO_TIME_ICE: 261>
ICE_INFO_TIME_WATER: SystemVariable  # value = <SystemVariable.ICE_INFO_TIME_WATER: 262>
ICE_INFO_TMEP_AMBI: SystemVariable  # value = <SystemVariable.ICE_INFO_TMEP_AMBI: 265>
ICE_INFO_TMEP_CONDEN: SystemVariable  # value = <SystemVariable.ICE_INFO_TMEP_CONDEN: 267>
ICE_INFO_TMEP_EVAPO: SystemVariable  # value = <SystemVariable.ICE_INFO_TMEP_EVAPO: 266>
ICE_INFO_USING: SystemVariable  # value = <SystemVariable.ICE_INFO_USING: 257>
ICE_INFO_VECSIZE: SystemVariable  # value = <SystemVariable.ICE_INFO_VECSIZE: 258>
ICE_STATE_COMM_MODE: SystemVariable  # value = <SystemVariable.ICE_STATE_COMM_MODE: 274>
ICE_STATE_COMP_WORK: SystemVariable  # value = <SystemVariable.ICE_STATE_COMP_WORK: 270>
ICE_STATE_CUP_LEVEL: SystemVariable  # value = <SystemVariable.ICE_STATE_CUP_LEVEL: 273>
ICE_STATE_ERR_1: SystemVariable  # value = <SystemVariable.ICE_STATE_ERR_1: 276>
ICE_STATE_ERR_2: SystemVariable  # value = <SystemVariable.ICE_STATE_ERR_2: 277>
ICE_STATE_ERR_3: SystemVariable  # value = <SystemVariable.ICE_STATE_ERR_3: 278>
ICE_STATE_ERR_4: SystemVariable  # value = <SystemVariable.ICE_STATE_ERR_4: 279>
ICE_STATE_ERR_CODE: SystemVariable  # value = <SystemVariable.ICE_STATE_ERR_CODE: 280>
ICE_STATE_FULL_ICE: SystemVariable  # value = <SystemVariable.ICE_STATE_FULL_ICE: 275>
ICE_STATE_LAST_ICE_NO: SystemVariable  # value = <SystemVariable.ICE_STATE_LAST_ICE_NO: 268>
ICE_STATE_LAST_ICE_YES: SystemVariable  # value = <SystemVariable.ICE_STATE_LAST_ICE_YES: 269>
ICE_STATE_MOTOR_WORK: SystemVariable  # value = <SystemVariable.ICE_STATE_MOTOR_WORK: 271>
ICE_STATE_OUT_SOL: SystemVariable  # value = <SystemVariable.ICE_STATE_OUT_SOL: 272>
ICE_STATE_RD: SystemVariable  # value = <SystemVariable.ICE_STATE_RD: 281>
JRT_ENCODER: SystemVariable  # value = <SystemVariable.JRT_ENCODER: 187>
JRT_JEGB: SystemVariable  # value = <SystemVariable.JRT_JEGB: 188>
JRT_JEGG: SystemVariable  # value = <SystemVariable.JRT_JEGG: 189>
OR_2FG7_MAX_EXT: SystemVariable  # value = <SystemVariable.OR_2FG7_MAX_EXT: 121>
OR_2FG7_MAX_INT: SystemVariable  # value = <SystemVariable.OR_2FG7_MAX_INT: 123>
OR_2FG7_MIN_EXT: SystemVariable  # value = <SystemVariable.OR_2FG7_MIN_EXT: 120>
OR_2FG7_MIN_INT: SystemVariable  # value = <SystemVariable.OR_2FG7_MIN_INT: 122>
OR_2FG7_POS_EXT: SystemVariable  # value = <SystemVariable.OR_2FG7_POS_EXT: 118>
OR_2FG7_POS_INT: SystemVariable  # value = <SystemVariable.OR_2FG7_POS_INT: 119>
OR_2FG7_STATE: SystemVariable  # value = <SystemVariable.OR_2FG7_STATE: 117>
OR_3FG_BUSY: SystemVariable  # value = <SystemVariable.OR_3FG_BUSY: 137>
OR_3FG_CALIB: SystemVariable  # value = <SystemVariable.OR_3FG_CALIB: 140>
OR_3FG_FORCE: SystemVariable  # value = <SystemVariable.OR_3FG_FORCE: 136>
OR_3FG_FORCE_GRIP: SystemVariable  # value = <SystemVariable.OR_3FG_FORCE_GRIP: 139>
OR_3FG_GRIP: SystemVariable  # value = <SystemVariable.OR_3FG_GRIP: 138>
OR_3FG_MAX_D: SystemVariable  # value = <SystemVariable.OR_3FG_MAX_D: 133>
OR_3FG_MIN_D: SystemVariable  # value = <SystemVariable.OR_3FG_MIN_D: 132>
OR_3FG_RAW_D: SystemVariable  # value = <SystemVariable.OR_3FG_RAW_D: 134>
OR_3FG_REAL_D: SystemVariable  # value = <SystemVariable.OR_3FG_REAL_D: 135>
OR_EYE_COUNT: SystemVariable  # value = <SystemVariable.OR_EYE_COUNT: 178>
OR_EYE_ERROR: SystemVariable  # value = <SystemVariable.OR_EYE_ERROR: 177>
OR_EYE_INSPECT_MATCH: SystemVariable  # value = <SystemVariable.OR_EYE_INSPECT_MATCH: 180>
OR_EYE_INSPECT_RESULT: SystemVariable  # value = <SystemVariable.OR_EYE_INSPECT_RESULT: 179>
OR_EYE_POS: SystemVariable  # value = <SystemVariable.OR_EYE_POS: 176>
OR_EYE_RX: SystemVariable  # value = <SystemVariable.OR_EYE_RX: 184>
OR_EYE_RY: SystemVariable  # value = <SystemVariable.OR_EYE_RY: 185>
OR_EYE_RZ: SystemVariable  # value = <SystemVariable.OR_EYE_RZ: 186>
OR_EYE_X: SystemVariable  # value = <SystemVariable.OR_EYE_X: 181>
OR_EYE_Y: SystemVariable  # value = <SystemVariable.OR_EYE_Y: 182>
OR_EYE_Z: SystemVariable  # value = <SystemVariable.OR_EYE_Z: 183>
OR_MG10_ERROR: SystemVariable  # value = <SystemVariable.OR_MG10_ERROR: 170>
OR_MG10_STATUS: SystemVariable  # value = <SystemVariable.OR_MG10_STATUS: 169>
OR_MG10_STRENGTH: SystemVariable  # value = <SystemVariable.OR_MG10_STRENGTH: 171>
OR_RG_BUSY: SystemVariable  # value = <SystemVariable.OR_RG_BUSY: 124>
OR_RG_ERROR: SystemVariable  # value = <SystemVariable.OR_RG_ERROR: 130>
OR_RG_GRIP: SystemVariable  # value = <SystemVariable.OR_RG_GRIP: 125>
OR_RG_S1_PUSHED: SystemVariable  # value = <SystemVariable.OR_RG_S1_PUSHED: 126>
OR_RG_S1_TRIGGERED: SystemVariable  # value = <SystemVariable.OR_RG_S1_TRIGGERED: 127>
OR_RG_S2_PUSHED: SystemVariable  # value = <SystemVariable.OR_RG_S2_PUSHED: 128>
OR_RG_S2_TRIGGERED: SystemVariable  # value = <SystemVariable.OR_RG_S2_TRIGGERED: 129>
OR_RG_WIDTH: SystemVariable  # value = <SystemVariable.OR_RG_WIDTH: 131>
OR_SD_BUTTON: SystemVariable  # value = <SystemVariable.OR_SD_BUTTON: 152>
OR_SD_ERROR: SystemVariable  # value = <SystemVariable.OR_SD_ERROR: 146>
OR_SD_MOTOR_RUNNING: SystemVariable  # value = <SystemVariable.OR_SD_MOTOR_RUNNING: 149>
OR_SD_MOTOR_STOPPED: SystemVariable  # value = <SystemVariable.OR_SD_MOTOR_STOPPED: 148>
OR_SD_RAMP_DW: SystemVariable  # value = <SystemVariable.OR_SD_RAMP_DW: 151>
OR_SD_RAMP_UP: SystemVariable  # value = <SystemVariable.OR_SD_RAMP_UP: 150>
OR_SD_RPM: SystemVariable  # value = <SystemVariable.OR_SD_RPM: 143>
OR_SD_RPM_DEV: SystemVariable  # value = <SystemVariable.OR_SD_RPM_DEV: 144>
OR_SD_RPM_TAR: SystemVariable  # value = <SystemVariable.OR_SD_RPM_TAR: 147>
OR_SD_STATUS: SystemVariable  # value = <SystemVariable.OR_SD_STATUS: 141>
OR_SD_VIBRATION: SystemVariable  # value = <SystemVariable.OR_SD_VIBRATION: 145>
OR_SD_WARNING: SystemVariable  # value = <SystemVariable.OR_SD_WARNING: 142>
OR_SG_MAX_WIDTH: SystemVariable  # value = <SystemVariable.OR_SG_MAX_WIDTH: 173>
OR_SG_MIN_WIDTH: SystemVariable  # value = <SystemVariable.OR_SG_MIN_WIDTH: 174>
OR_SG_STATUS: SystemVariable  # value = <SystemVariable.OR_SG_STATUS: 175>
OR_SG_WIDTH: SystemVariable  # value = <SystemVariable.OR_SG_WIDTH: 172>
OR_VGP20_A: SystemVariable  # value = <SystemVariable.OR_VGP20_A: 155>
OR_VGP20_A_GRIP: SystemVariable  # value = <SystemVariable.OR_VGP20_A_GRIP: 159>
OR_VGP20_A_RELEASE: SystemVariable  # value = <SystemVariable.OR_VGP20_A_RELEASE: 160>
OR_VGP20_B: SystemVariable  # value = <SystemVariable.OR_VGP20_B: 156>
OR_VGP20_BUSY: SystemVariable  # value = <SystemVariable.OR_VGP20_BUSY: 167>
OR_VGP20_B_GRIP: SystemVariable  # value = <SystemVariable.OR_VGP20_B_GRIP: 161>
OR_VGP20_B_RELEASE: SystemVariable  # value = <SystemVariable.OR_VGP20_B_RELEASE: 162>
OR_VGP20_C: SystemVariable  # value = <SystemVariable.OR_VGP20_C: 157>
OR_VGP20_C_GRIP: SystemVariable  # value = <SystemVariable.OR_VGP20_C_GRIP: 163>
OR_VGP20_C_RELEASE: SystemVariable  # value = <SystemVariable.OR_VGP20_C_RELEASE: 164>
OR_VGP20_D: SystemVariable  # value = <SystemVariable.OR_VGP20_D: 158>
OR_VGP20_D_GRIP: SystemVariable  # value = <SystemVariable.OR_VGP20_D_GRIP: 165>
OR_VGP20_D_RELEASE: SystemVariable  # value = <SystemVariable.OR_VGP20_D_RELEASE: 166>
OR_VGP20_ERROR: SystemVariable  # value = <SystemVariable.OR_VGP20_ERROR: 168>
OR_VG_A: SystemVariable  # value = <SystemVariable.OR_VG_A: 153>
OR_VG_B: SystemVariable  # value = <SystemVariable.OR_VG_B: 154>
PICKIT_BUILD_BKG_CLOUD_FAILED: SystemVariable  # value = <SystemVariable.PICKIT_BUILD_BKG_CLOUD_FAILED: 221>
PICKIT_BUILD_BKG_CLOUD_OK: SystemVariable  # value = <SystemVariable.PICKIT_BUILD_BKG_CLOUD_OK: 220>
PICKIT_CONFIG_FAILED: SystemVariable  # value = <SystemVariable.PICKIT_CONFIG_FAILED: 219>
PICKIT_CONFIG_OK: SystemVariable  # value = <SystemVariable.PICKIT_CONFIG_OK: 218>
PICKIT_EMPTY_ROI: SystemVariable  # value = <SystemVariable.PICKIT_EMPTY_ROI: 215>
PICKIT_FIND_CALIB_PLATE_FAILED: SystemVariable  # value = <SystemVariable.PICKIT_FIND_CALIB_PLATE_FAILED: 223>
PICKIT_FIND_CALIB_PLATE_OK: SystemVariable  # value = <SystemVariable.PICKIT_FIND_CALIB_PLATE_OK: 222>
PICKIT_GET_PICK_POINT_DATA_FAILED: SystemVariable  # value = <SystemVariable.PICKIT_GET_PICK_POINT_DATA_FAILED: 217>
PICKIT_GET_PICK_POINT_DATA_OK: SystemVariable  # value = <SystemVariable.PICKIT_GET_PICK_POINT_DATA_OK: 216>
PICKIT_IDLE_MODE: SystemVariable  # value = <SystemVariable.PICKIT_IDLE_MODE: 210>
PICKIT_IMAGE_CAPTURED: SystemVariable  # value = <SystemVariable.PICKIT_IMAGE_CAPTURED: 213>
PICKIT_M0: SystemVariable  # value = <SystemVariable.PICKIT_M0: 253>
PICKIT_M1: SystemVariable  # value = <SystemVariable.PICKIT_M1: 254>
PICKIT_NO_IMAGE_CAPTURED: SystemVariable  # value = <SystemVariable.PICKIT_NO_IMAGE_CAPTURED: 214>
PICKIT_NO_OBJECTS: SystemVariable  # value = <SystemVariable.PICKIT_NO_OBJECTS: 212>
PICKIT_OBJECT_FOUND: SystemVariable  # value = <SystemVariable.PICKIT_OBJECT_FOUND: 211>
PICKIT_P0: SystemVariable  # value = <SystemVariable.PICKIT_P0: 241>
PICKIT_P0F: SystemVariable  # value = <SystemVariable.PICKIT_P0F: 247>
PICKIT_P1: SystemVariable  # value = <SystemVariable.PICKIT_P1: 242>
PICKIT_P1F: SystemVariable  # value = <SystemVariable.PICKIT_P1F: 248>
PICKIT_P2: SystemVariable  # value = <SystemVariable.PICKIT_P2: 243>
PICKIT_P2F: SystemVariable  # value = <SystemVariable.PICKIT_P2F: 249>
PICKIT_P3: SystemVariable  # value = <SystemVariable.PICKIT_P3: 244>
PICKIT_P3F: SystemVariable  # value = <SystemVariable.PICKIT_P3F: 250>
PICKIT_P4: SystemVariable  # value = <SystemVariable.PICKIT_P4: 245>
PICKIT_P4F: SystemVariable  # value = <SystemVariable.PICKIT_P4F: 251>
PICKIT_P5: SystemVariable  # value = <SystemVariable.PICKIT_P5: 246>
PICKIT_P5F: SystemVariable  # value = <SystemVariable.PICKIT_P5F: 252>
PICKIT_POS: SystemVariable  # value = <SystemVariable.PICKIT_POS: 190>
PICKIT_ROBOTTYPE: SystemVariable  # value = <SystemVariable.PICKIT_ROBOTTYPE: 208>
PICKIT_ROBOT_MODE: SystemVariable  # value = <SystemVariable.PICKIT_ROBOT_MODE: 209>
PICKIT_RX: SystemVariable  # value = <SystemVariable.PICKIT_RX: 238>
PICKIT_RY: SystemVariable  # value = <SystemVariable.PICKIT_RY: 239>
PICKIT_RZ: SystemVariable  # value = <SystemVariable.PICKIT_RZ: 240>
PICKIT_SAVE_SNAPSHOT_FAILED: SystemVariable  # value = <SystemVariable.PICKIT_SAVE_SNAPSHOT_FAILED: 225>
PICKIT_SAVE_SNAPSHOT_OK: SystemVariable  # value = <SystemVariable.PICKIT_SAVE_SNAPSHOT_OK: 224>
PICKIT_STATUS: SystemVariable  # value = <SystemVariable.PICKIT_STATUS: 206>
PICKIT_TYPE_BLOB: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_BLOB: 234>
PICKIT_TYPE_CIRCLE: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_CIRCLE: 229>
PICKIT_TYPE_CYLINDER: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_CYLINDER: 231>
PICKIT_TYPE_ELLIPSE: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_ELLIPSE: 230>
PICKIT_TYPE_POINTCLOUD: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_POINTCLOUD: 233>
PICKIT_TYPE_RECTANGLE: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_RECTANGLE: 228>
PICKIT_TYPE_SPHERE: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_SPHERE: 232>
PICKIT_TYPE_SQUARE: SystemVariable  # value = <SystemVariable.PICKIT_TYPE_SQUARE: 227>
PICKIT_UNKNOWN_COMMAND: SystemVariable  # value = <SystemVariable.PICKIT_UNKNOWN_COMMAND: 226>
PICKIT_VERSION: SystemVariable  # value = <SystemVariable.PICKIT_VERSION: 207>
PICKIT_X: SystemVariable  # value = <SystemVariable.PICKIT_X: 235>
PICKIT_Y: SystemVariable  # value = <SystemVariable.PICKIT_Y: 236>
PICKIT_Z: SystemVariable  # value = <SystemVariable.PICKIT_Z: 237>
RC_PICKIT_CAPTURE_IMAGE: SystemVariable  # value = <SystemVariable.RC_PICKIT_CAPTURE_IMAGE: 193>
RC_PICKIT_CHECK_MODE: SystemVariable  # value = <SystemVariable.RC_PICKIT_CHECK_MODE: 192>
RC_PICKIT_CONFIGURE: SystemVariable  # value = <SystemVariable.RC_PICKIT_CONFIGURE: 199>
RC_PICKIT_FIND_CALIB_PLATE: SystemVariable  # value = <SystemVariable.RC_PICKIT_FIND_CALIB_PLATE: 204>
RC_PICKIT_GET_PICK_POINT_DATA: SystemVariable  # value = <SystemVariable.RC_PICKIT_GET_PICK_POINT_DATA: 198>
RC_PICKIT_LOOK_FOR_OBJECTS: SystemVariable  # value = <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS: 195>
RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES: SystemVariable  # value = <SystemVariable.RC_PICKIT_LOOK_FOR_OBJECTS_WITH_RETRIES: 196>
RC_PICKIT_NEXT_OBJECT: SystemVariable  # value = <SystemVariable.RC_PICKIT_NEXT_OBJECT: 197>
RC_PICKIT_NO_COMMAND: SystemVariable  # value = <SystemVariable.RC_PICKIT_NO_COMMAND: 191>
RC_PICKIT_PROCESS_IMAGE: SystemVariable  # value = <SystemVariable.RC_PICKIT_PROCESS_IMAGE: 194>
RC_PICKIT_SAVE_SCENE: SystemVariable  # value = <SystemVariable.RC_PICKIT_SAVE_SCENE: 205>
RC_PICKIT_SET_CYLINDER_DIM: SystemVariable  # value = <SystemVariable.RC_PICKIT_SET_CYLINDER_DIM: 200>
RC_SAVE_ACTIVE_PRODUCT: SystemVariable  # value = <SystemVariable.RC_SAVE_ACTIVE_PRODUCT: 201>
RC_SAVE_ACTIVE_SETUP: SystemVariable  # value = <SystemVariable.RC_SAVE_ACTIVE_SETUP: 202>
RC_SAVE_BUILD_BACKGROUND: SystemVariable  # value = <SystemVariable.RC_SAVE_BUILD_BACKGROUND: 203>
SD_ARM_POWER: SystemVariable  # value = <SystemVariable.SD_ARM_POWER: 93>
SD_BEGIN_J0: SystemVariable  # value = <SystemVariable.SD_BEGIN_J0: 35>
SD_BEGIN_J1: SystemVariable  # value = <SystemVariable.SD_BEGIN_J1: 36>
SD_BEGIN_J2: SystemVariable  # value = <SystemVariable.SD_BEGIN_J2: 37>
SD_BEGIN_J3: SystemVariable  # value = <SystemVariable.SD_BEGIN_J3: 38>
SD_BEGIN_J4: SystemVariable  # value = <SystemVariable.SD_BEGIN_J4: 39>
SD_BEGIN_J5: SystemVariable  # value = <SystemVariable.SD_BEGIN_J5: 40>
SD_BIT_0_11: SystemVariable  # value = <SystemVariable.SD_BIT_0_11: 115>
SD_BIT_0_15: SystemVariable  # value = <SystemVariable.SD_BIT_0_15: 116>
SD_BIT_0_3: SystemVariable  # value = <SystemVariable.SD_BIT_0_3: 110>
SD_BIT_0_7: SystemVariable  # value = <SystemVariable.SD_BIT_0_7: 114>
SD_BIT_12_15: SystemVariable  # value = <SystemVariable.SD_BIT_12_15: 113>
SD_BIT_4_7: SystemVariable  # value = <SystemVariable.SD_BIT_4_7: 111>
SD_BIT_8_11: SystemVariable  # value = <SystemVariable.SD_BIT_8_11: 112>
SD_COLLISION_DETECT_STATE: SystemVariable  # value = <SystemVariable.SD_COLLISION_DETECT_STATE: 56>
SD_CONV_POS_TICK: SystemVariable  # value = <SystemVariable.SD_CONV_POS_TICK: 305>
SD_CONV_VEL_TICK: SystemVariable  # value = <SystemVariable.SD_CONV_VEL_TICK: 306>
SD_CURRENT_DELTA: SystemVariable  # value = <SystemVariable.SD_CURRENT_DELTA: 101>
SD_DEFAULT_SPEED: SystemVariable  # value = <SystemVariable.SD_DEFAULT_SPEED: 53>
SD_DIGITAL_IN_CONFIG_0: SystemVariable  # value = <SystemVariable.SD_DIGITAL_IN_CONFIG_0: 73>
SD_DIGITAL_IN_CONFIG_1: SystemVariable  # value = <SystemVariable.SD_DIGITAL_IN_CONFIG_1: 74>
SD_DWELD_A: SystemVariable  # value = <SystemVariable.SD_DWELD_A: 301>
SD_DWELD_ARC: SystemVariable  # value = <SystemVariable.SD_DWELD_ARC: 299>
SD_DWELD_F: SystemVariable  # value = <SystemVariable.SD_DWELD_F: 303>
SD_DWELD_SET_A: SystemVariable  # value = <SystemVariable.SD_DWELD_SET_A: 304>
SD_DWELD_TOUCH: SystemVariable  # value = <SystemVariable.SD_DWELD_TOUCH: 300>
SD_DWELD_V: SystemVariable  # value = <SystemVariable.SD_DWELD_V: 302>
SD_EMG_BUTTON_STATE: SystemVariable  # value = <SystemVariable.SD_EMG_BUTTON_STATE: 103>
SD_FINISH_AT_EVENT: SystemVariable  # value = <SystemVariable.SD_FINISH_AT_EVENT: 90>
SD_FORCE_TRAVEL_DIS: SystemVariable  # value = <SystemVariable.SD_FORCE_TRAVEL_DIS: 102>
SD_HAND_TOKTOK: SystemVariable  # value = <SystemVariable.SD_HAND_TOKTOK: 89>
SD_ID_NUMBER: SystemVariable  # value = <SystemVariable.SD_ID_NUMBER: 107>
SD_INBOX_CHECK_MODE_0: SystemVariable  # value = <SystemVariable.SD_INBOX_CHECK_MODE_0: 77>
SD_INBOX_CHECK_MODE_1: SystemVariable  # value = <SystemVariable.SD_INBOX_CHECK_MODE_1: 78>
SD_INBOX_TRAP_FLAG_0: SystemVariable  # value = <SystemVariable.SD_INBOX_TRAP_FLAG_0: 75>
SD_INBOX_TRAP_FLAG_1: SystemVariable  # value = <SystemVariable.SD_INBOX_TRAP_FLAG_1: 76>
SD_INIT_ERR: SystemVariable  # value = <SystemVariable.SD_INIT_ERR: 60>
SD_INIT_STATE_INFO: SystemVariable  # value = <SystemVariable.SD_INIT_STATE_INFO: 59>
SD_IS_BEGIN: SystemVariable  # value = <SystemVariable.SD_IS_BEGIN: 106>
SD_IS_FREE_DRIVE_MODE: SystemVariable  # value = <SystemVariable.SD_IS_FREE_DRIVE_MODE: 57>
SD_IS_HOME: SystemVariable  # value = <SystemVariable.SD_IS_HOME: 105>
SD_IS_INTENDED_STOP: SystemVariable  # value = <SystemVariable.SD_IS_INTENDED_STOP: 97>
SD_IS_IN_MAIN: SystemVariable  # value = <SystemVariable.SD_IS_IN_MAIN: 104>
SD_IS_RUN_IN_MAKE: SystemVariable  # value = <SystemVariable.SD_IS_RUN_IN_MAKE: 95>
SD_IS_RUN_IN_PLAY: SystemVariable  # value = <SystemVariable.SD_IS_RUN_IN_PLAY: 96>
SD_IS_TPU_CONNECT: SystemVariable  # value = <SystemVariable.SD_IS_TPU_CONNECT: 94>
SD_J0_ANG: SystemVariable  # value = <SystemVariable.SD_J0_ANG: 17>
SD_J0_CUR: SystemVariable  # value = <SystemVariable.SD_J0_CUR: 29>
SD_J0_REF: SystemVariable  # value = <SystemVariable.SD_J0_REF: 11>
SD_J0_VEL: SystemVariable  # value = <SystemVariable.SD_J0_VEL: 23>
SD_J1_ANG: SystemVariable  # value = <SystemVariable.SD_J1_ANG: 18>
SD_J1_CUR: SystemVariable  # value = <SystemVariable.SD_J1_CUR: 30>
SD_J1_REF: SystemVariable  # value = <SystemVariable.SD_J1_REF: 12>
SD_J1_VEL: SystemVariable  # value = <SystemVariable.SD_J1_VEL: 24>
SD_J2_ANG: SystemVariable  # value = <SystemVariable.SD_J2_ANG: 19>
SD_J2_CUR: SystemVariable  # value = <SystemVariable.SD_J2_CUR: 31>
SD_J2_REF: SystemVariable  # value = <SystemVariable.SD_J2_REF: 13>
SD_J2_VEL: SystemVariable  # value = <SystemVariable.SD_J2_VEL: 25>
SD_J3_ANG: SystemVariable  # value = <SystemVariable.SD_J3_ANG: 20>
SD_J3_CUR: SystemVariable  # value = <SystemVariable.SD_J3_CUR: 32>
SD_J3_REF: SystemVariable  # value = <SystemVariable.SD_J3_REF: 14>
SD_J3_VEL: SystemVariable  # value = <SystemVariable.SD_J3_VEL: 26>
SD_J4_ANG: SystemVariable  # value = <SystemVariable.SD_J4_ANG: 21>
SD_J4_CUR: SystemVariable  # value = <SystemVariable.SD_J4_CUR: 33>
SD_J4_REF: SystemVariable  # value = <SystemVariable.SD_J4_REF: 15>
SD_J4_VEL: SystemVariable  # value = <SystemVariable.SD_J4_VEL: 27>
SD_J5_ANG: SystemVariable  # value = <SystemVariable.SD_J5_ANG: 22>
SD_J5_CUR: SystemVariable  # value = <SystemVariable.SD_J5_CUR: 34>
SD_J5_REF: SystemVariable  # value = <SystemVariable.SD_J5_REF: 16>
SD_J5_VEL: SystemVariable  # value = <SystemVariable.SD_J5_VEL: 28>
SD_MOTION_TIME: SystemVariable  # value = <SystemVariable.SD_MOTION_TIME: 92>
SD_MOVE_INDEX: SystemVariable  # value = <SystemVariable.SD_MOVE_INDEX: 98>
SD_MOVE_INDEX_F: SystemVariable  # value = <SystemVariable.SD_MOVE_INDEX_F: 99>
SD_MOVE_PROPERTY: SystemVariable  # value = <SystemVariable.SD_MOVE_PROPERTY: 100>
SD_NO_ARC_STATE: SystemVariable  # value = <SystemVariable.SD_NO_ARC_STATE: 298>
SD_OP_STAT_COLLISION_OCCUR: SystemVariable  # value = <SystemVariable.SD_OP_STAT_COLLISION_OCCUR: 68>
SD_OP_STAT_EMS_FLAG: SystemVariable  # value = <SystemVariable.SD_OP_STAT_EMS_FLAG: 72>
SD_OP_STAT_ESTOP_OCCUR: SystemVariable  # value = <SystemVariable.SD_OP_STAT_ESTOP_OCCUR: 71>
SD_OP_STAT_SELF_COLLISION: SystemVariable  # value = <SystemVariable.SD_OP_STAT_SELF_COLLISION: 70>
SD_OP_STAT_SOS_FLAG: SystemVariable  # value = <SystemVariable.SD_OP_STAT_SOS_FLAG: 69>
SD_PG_MODE: SystemVariable  # value = <SystemVariable.SD_PG_MODE: 58>
SD_POWER_STATE: SystemVariable  # value = <SystemVariable.SD_POWER_STATE: 55>
SD_ROBOT_STATE: SystemVariable  # value = <SystemVariable.SD_ROBOT_STATE: 54>
SD_SOCK_IS_OPEN_0: SystemVariable  # value = <SystemVariable.SD_SOCK_IS_OPEN_0: 79>
SD_SOCK_IS_OPEN_1: SystemVariable  # value = <SystemVariable.SD_SOCK_IS_OPEN_1: 80>
SD_SOCK_IS_OPEN_2: SystemVariable  # value = <SystemVariable.SD_SOCK_IS_OPEN_2: 81>
SD_SOCK_IS_OPEN_3: SystemVariable  # value = <SystemVariable.SD_SOCK_IS_OPEN_3: 82>
SD_SOCK_IS_OPEN_4: SystemVariable  # value = <SystemVariable.SD_SOCK_IS_OPEN_4: 83>
SD_SOCK_LAST_READ_0: SystemVariable  # value = <SystemVariable.SD_SOCK_LAST_READ_0: 84>
SD_SOCK_LAST_READ_1: SystemVariable  # value = <SystemVariable.SD_SOCK_LAST_READ_1: 85>
SD_SOCK_LAST_READ_2: SystemVariable  # value = <SystemVariable.SD_SOCK_LAST_READ_2: 86>
SD_SOCK_LAST_READ_3: SystemVariable  # value = <SystemVariable.SD_SOCK_LAST_READ_3: 87>
SD_SOCK_LAST_READ_4: SystemVariable  # value = <SystemVariable.SD_SOCK_LAST_READ_4: 88>
SD_TCP_RX: SystemVariable  # value = <SystemVariable.SD_TCP_RX: 50>
SD_TCP_RY: SystemVariable  # value = <SystemVariable.SD_TCP_RY: 51>
SD_TCP_RZ: SystemVariable  # value = <SystemVariable.SD_TCP_RZ: 52>
SD_TCP_VEL_REF: SystemVariable  # value = <SystemVariable.SD_TCP_VEL_REF: 91>
SD_TCP_X: SystemVariable  # value = <SystemVariable.SD_TCP_X: 47>
SD_TCP_Y: SystemVariable  # value = <SystemVariable.SD_TCP_Y: 48>
SD_TCP_Z: SystemVariable  # value = <SystemVariable.SD_TCP_Z: 49>
SD_TEMPERATURE_MC0: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC0: 41>
SD_TEMPERATURE_MC1: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC1: 42>
SD_TEMPERATURE_MC2: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC2: 43>
SD_TEMPERATURE_MC3: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC3: 44>
SD_TEMPERATURE_MC4: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC4: 45>
SD_TEMPERATURE_MC5: SystemVariable  # value = <SystemVariable.SD_TEMPERATURE_MC5: 46>
SD_TFB_ANALOG_IN_0: SystemVariable  # value = <SystemVariable.SD_TFB_ANALOG_IN_0: 61>
SD_TFB_ANALOG_IN_1: SystemVariable  # value = <SystemVariable.SD_TFB_ANALOG_IN_1: 62>
SD_TFB_DIGITAL_IN_0: SystemVariable  # value = <SystemVariable.SD_TFB_DIGITAL_IN_0: 63>
SD_TFB_DIGITAL_IN_1: SystemVariable  # value = <SystemVariable.SD_TFB_DIGITAL_IN_1: 64>
SD_TFB_DIGITAL_OUT_0: SystemVariable  # value = <SystemVariable.SD_TFB_DIGITAL_OUT_0: 65>
SD_TFB_DIGITAL_OUT_1: SystemVariable  # value = <SystemVariable.SD_TFB_DIGITAL_OUT_1: 66>
SD_TFB_VOLTAGE_OUT: SystemVariable  # value = <SystemVariable.SD_TFB_VOLTAGE_OUT: 67>
SD_TF_LRF_DISTANCE: SystemVariable  # value = <SystemVariable.SD_TF_LRF_DISTANCE: 108>
SD_TF_LRF_QUALITY: SystemVariable  # value = <SystemVariable.SD_TF_LRF_QUALITY: 109>
SD_TIME: SystemVariable  # value = <SystemVariable.SD_TIME: 0>
SD_TIMER_0: SystemVariable  # value = <SystemVariable.SD_TIMER_0: 1>
SD_TIMER_1: SystemVariable  # value = <SystemVariable.SD_TIMER_1: 2>
SD_TIMER_2: SystemVariable  # value = <SystemVariable.SD_TIMER_2: 3>
SD_TIMER_3: SystemVariable  # value = <SystemVariable.SD_TIMER_3: 4>
SD_TIMER_4: SystemVariable  # value = <SystemVariable.SD_TIMER_4: 5>
SD_TIMER_5: SystemVariable  # value = <SystemVariable.SD_TIMER_5: 6>
SD_TIMER_6: SystemVariable  # value = <SystemVariable.SD_TIMER_6: 7>
SD_TIMER_7: SystemVariable  # value = <SystemVariable.SD_TIMER_7: 8>
SD_TIMER_8: SystemVariable  # value = <SystemVariable.SD_TIMER_8: 9>
SD_TIMER_9: SystemVariable  # value = <SystemVariable.SD_TIMER_9: 10>
SETECH_ALM: SystemVariable  # value = <SystemVariable.SETECH_ALM: 283>
SETECH_BUSY: SystemVariable  # value = <SystemVariable.SETECH_BUSY: 284>
SETECH_COMP: SystemVariable  # value = <SystemVariable.SETECH_COMP: 285>
SETECH_NG_ANGH: SystemVariable  # value = <SystemVariable.SETECH_NG_ANGH: 289>
SETECH_NG_ANGL: SystemVariable  # value = <SystemVariable.SETECH_NG_ANGL: 290>
SETECH_NG_CH1: SystemVariable  # value = <SystemVariable.SETECH_NG_CH1: 293>
SETECH_NG_CH16: SystemVariable  # value = <SystemVariable.SETECH_NG_CH16: 297>
SETECH_NG_CH2: SystemVariable  # value = <SystemVariable.SETECH_NG_CH2: 294>
SETECH_NG_CH4: SystemVariable  # value = <SystemVariable.SETECH_NG_CH4: 295>
SETECH_NG_CH8: SystemVariable  # value = <SystemVariable.SETECH_NG_CH8: 296>
SETECH_NG_MONI: SystemVariable  # value = <SystemVariable.SETECH_NG_MONI: 292>
SETECH_NG_TIME: SystemVariable  # value = <SystemVariable.SETECH_NG_TIME: 291>
SETECH_NG_TRQH: SystemVariable  # value = <SystemVariable.SETECH_NG_TRQH: 287>
SETECH_NG_TRQL: SystemVariable  # value = <SystemVariable.SETECH_NG_TRQL: 288>
SETECH_OK: SystemVariable  # value = <SystemVariable.SETECH_OK: 286>
SETECH_RDY: SystemVariable  # value = <SystemVariable.SETECH_RDY: 282>
__version__: str = '0.16.1'
